#comet.tcl  -*- TCL -*-
#---------------------------------------------------------------------------
#This file is written in TCL lenguage 
#For more information about TCL look at: http://www.sunlabs.com/research/tcl/
#
#At least two procs must be in this file:
#
#    InitGIDProject dir - Will be called whenever a project is begun to be used.
#           where dir is the project's directory
#    EndGIDProject - Will be called whenever a project ends to be used.
#
#For more information about GID internals, check the program scripts.
#---------------------------------------------------------------------------



proc InitGIDProject { dir } {

    global ProgramName
    set ProgramName Safir_Structural_2D
	
	global problemtype_local
	array set problemtype_local [ReadProblemtypeXml [file join $dir Safir_Structural_2d.xml] Infoproblemtype {Name Version MinimumGiDVersion SuggestedGiDVersion Description}]
	

    GidChangeDataLabel "Materials" ""
    GidChangeDataLabel "Conditions" ""
    GidChangeDataLabel "Problem Data" ""
    GidChangeDataLabel "Interval" ""
    RemoveMenuOption "Data" "Materials" "PRE"
#MB16-03-2016
    GidAddUserDataOptions "---" ""
#MB16-03-2016
    GidAddUserDataOptions Constraints "GidOpenConditions Constraints" 2
    GidAddUserDataOptions "---" "" 3
   # GidAddUserDataOptions Connections "GidOpenConditions Connections" 4
   # GidAddUserDataOptions "---" "" 5
	GidAddUserDataOptions "Loads" OpenLoadsWindow 4
    GidAddUserDataOptions "---" "" 5
    GidAddUserDataOptions "Properties" "GidOpenConditions Properties" 6
    GidAddUserDataOptions "---" "" 7
    GidAddUserDataOptions "Mass" "GidOpenConditions {Mass for Dynamic Calculation}" 8
    GidAddUserDataOptions "---" "" 9
    GidAddUserDataOptions "Problem Data" "GidOpenProblemData General" 10
    GidAddUserDataOptions "---" "" 11
    GidAddUserDataOptions "Material" "GidOpenProblemData Material" 12
	GidAddUserDataOptions "---" "" 13
	GidAddUserDataOptions "Relaxations" OpenRelaxationWindow 14

	#MB16-03-2016
#    GidAddUserDataOptions "---" "" 17
#MB16-03-2016

    global GidPriv
    set GidPriv(ProgName) $ProgramName
    ChangeWindowTitle

    UpdateMenus
#MB16-03-2016
    Safir_ChangeMenus
#MB16-03-2016
	
}

proc OpenRelaxationWindow { } { 
  #GiD_Process Mescape Geometry
  GidOpenConditions Relaxations
  GiD_Process Mescape Utilities Drawnormals Lines 1:end
  #GiD_Process Mescape Utilities Drawnormals Elements 1:end
}

proc OpenLoadsWindow { } { 
  #GiD_Process Mescape Geometry
  GidOpenConditions Loads
  #GiD_Process Mescape Utilities Drawnormals Lines 1:end
  #GiD_Process Mescape Utilities Drawnormals Elements 1:end
}

#MB16-03-2016
proc Safir_ChangeMenus { } {
            
    foreach text {Interval "Local axes"} {GidChangeDataLabel $text ""}    
    
	#add About Problem Types menu
	GiDMenu::Create "About Problem Type" PRE
	GiDMenu::InsertOption "About Problem Type" "Safir_Structural_2D" 0 PRE AboutStructural2D 

	#update the menus
    GiDMenu::UpdateMenus
}
#MB16-03-2016

proc AboutStructural2D { } {
	global problemtype_local
	
	#set name of the windoe in GiD
	set w .gid.aboutMe
	
	InitWindow $w "About Safir_Structural_2D" AboutMeWindow

	frame $w.frmAboutMe
	
	 label $w.frmAboutMe.name -text "Name"
	 entry $w.frmAboutMe.nameVal -relief sunken -width 80 -textvariable problemtype_local(Name) -state readonly
	 label $w.frmAboutMe.version -text "Version"
	 entry $w.frmAboutMe.versionVal -relief sunken -width 80 -textvariable problemtype_local(Version) -state readonly
	 label $w.frmAboutMe.minimumGiDversion -text "Minimum GiD version"
	 entry $w.frmAboutMe.minimumGiDversionVal -relief sunken -width 80 -textvariable  problemtype_local(MinimumGiDVersion) -state readonly
	 label $w.frmAboutMe.suggestedGiDversion -text "Suggested GiD version"
	 entry $w.frmAboutMe.suggestedGiDversionVal -relief sunken -width 80 -textvariable  problemtype_local(SuggestedGiDVersion) -state readonly
	 label $w.frmAboutMe.description -text "Description"
	 entry $w.frmAboutMe.descriptionVal -relief sunken -width 80 -textvariable problemtype_local(Description) -state readonly

	grid $w.frmAboutMe  -padx 5 -pady 5 -sticky ew 

    grid $w.frmAboutMe.name $w.frmAboutMe.nameVal -sticky e
	grid $w.frmAboutMe.description $w.frmAboutMe.descriptionVal -sticky e
	grid $w.frmAboutMe.version $w.frmAboutMe.versionVal -sticky e
	grid $w.frmAboutMe.minimumGiDversion $w.frmAboutMe.minimumGiDversionVal -sticky e
	grid $w.frmAboutMe.suggestedGiDversion $w.frmAboutMe.suggestedGiDversionVal -sticky e

	
	focus $w.frmAboutMe
	}


namespace eval DisconnectConditions {
    variable Identifier
}

proc DisconnectConditions::ComunicateWithGiD { op args } {
    variable Identifier
    switch $op {
	"INIT" {
	    set PARENT [lindex $args 0]
	    upvar      [lindex $args 1] ROW 
	    set GDN [lindex $args 2]
  	    set STRUCT [lindex $args 3]

	    global $GDN
	    upvar \#0 $GDN GidData

	    set cndname [lindex [split $STRUCT ,] 1]
	    switch $cndname {
		Point_disconnect_degrees {
		    set Identifier $GidData($STRUCT,VALUE,2)
		}
		Line_disconnect_Id  {
		    set Identifier $GidData($STRUCT,VALUE,1)
		}
		default {
		    if { ![info exists Identifier] } {
			set Identifier Id1
		    }
		}
	    }

	    set l [label $PARENT.l$ROW -text "Identifier:"]
	    set c [ComboBox $PARENT.c$ROW \
		    -textvariable DisconnectConditions::Identifier \
		    -values {Id1 Id2 Id3 Id4 Id5 Id6 Id7 Id8 Id9}]
	    
	    grid $l -row $ROW -column 0 -sticky e
	    grid $c -row $ROW -column 1 -sticky w -pady 3

	    if { [info exists $GDN\($STRUCT,HELP,0\)] } {
		GidHelp "$l $c" [subst $GidData($STRUCT,HELP,0)]
	    }
	    return ""
	}
	"SYNC" {
	    set GDN [lindex $args 0]
  	    set STRUCT [lindex $args 1]

	    set Identifier [string trim $Identifier]
            set ll [string length $Identifier]
	    regsub -all " \t"  $Identifier {} Identifier
	    if { $ll > 4 || ![regexp {^[a-zA-Z0-9]} $Identifier] } {
		return [list ERROR \
			"Identifier must be a name with max 4 characters that begins with a letter or number"]
	    }
	    DWLocalSetValue $GDN $STRUCT Identifier $Identifier
	    return ""
	}
    }
}

proc AfterMeshGeneration { fail } {
    if { !$fail } {
        SAFIR::TransferRelaxation
		SAFIR::TransferTrapLoad 0
		SAFIR::TransferTrapLoad 1
    }
	
    return ""
}

namespace eval SAFIR {
}
  proc SAFIR::TransferTrapLoad { globalLocalCase } {
  set tolerance 1e-15
  if  {$globalLocalCase == 0} {
   set condition_name TrapLoadGlobal
  }  else {
   set condition_name TrapLoadLocal
  }
  foreach item [GiD_Info Conditions $condition_name mesh] {
	  set element_id [lindex $item 1] ;#element id is the first field
      set line_id [lindex $item end] ;#extra FUNC#(NumEntity) field added as last question
	  
	   #set coords for the nodes for the line entities
     set xyz_line_t(0) [GiD_Info Parametric line $line_id coord 0.0]
     set xyz_line_t(1) [GiD_Info Parametric line $line_id coord 1.0]
     
	 #assign nodes to variables
     lassign [lrange [GiD_Mesh get element $element_id] 3 4] node_0 node_1 
	  
	 #set coords for the nodes for the mesh elements
     set xyz_node(0) [lrange $[GiD_Mesh get node $node_0] 1 end]
     set xyz_node(1) [lrange $[GiD_Mesh get node $node_1] 1 end]
	 
	 #set trapezoidal load values
	 set pAx [lindex [lindex [GiD_Info conditions $condition_name geometry $line_id] 0] 3]
	 set pAy [lindex [lindex [GiD_Info conditions $condition_name geometry $line_id] 0] 4]
	 set pBx [lindex [lindex [GiD_Info conditions $condition_name geometry $line_id] 0] 5]
	 set pBy [lindex [lindex [GiD_Info conditions $condition_name geometry $line_id] 0] 6]
	 
	 set func [lindex [lindex [GiD_Info conditions $condition_name geometry $line_id] 0] 7]
	 set function [lindex [lindex [GiD_Info conditions $condition_name geometry $line_id] 0] 8]
	  
	 #set total distance of the line entity and distances to the two nodes of the element
	 set dtot [MathUtils::VectorDistance $xyz_line_t(0) $xyz_line_t(1)]
	 set d0 [MathUtils::VectorDistance $xyz_line_t(0) $xyz_node(0)]
	 set d1 [MathUtils::VectorDistance $xyz_line_t(0) $xyz_node(1)]
	 
	 #calculate load values for each node of the element
	 set pAxNew [expr double( round(100 * ( $pAx + ( $pBx - $pAx ) * $d0 / $dtot)) )/ 100 ]
	 set pAyNew [expr double( round(100 * ( $pAy + ( $pBy - $pAy ) * $d0 / $dtot)) )/ 100 ]
	 set pBxNew [expr double( round(100 * ( $pAx + ( $pBx - $pAx ) * $d1 / $dtot)) )/ 100 ]
	 set pByNew [expr double( round(100 * ( $pAy + ( $pBy - $pAy ) * $d1 / $dtot)) )/ 100 ]
	 
	 #write conditions in the element
	 set vals [concat $pAxNew $pAyNew $pBxNew $pByNew $func $function $line_id]
	 GiD_AssignData condition $condition_name body_elements $vals $element_id
	  }
  } 

 proc SAFIR::TransferRelaxation { } {
  set tolerance 1e-15
  set condition_name Relax_Beam_DOF
  set elements_to_remove [list]	
  foreach item [GiD_Info Conditions $condition_name mesh] {
      set element_node0 [list]
	  set element_node1 [list]
	  set element_id [lindex $item 1] ;#element id is the first field
      set line_id [lindex $item end] ;#extra FUNC#(NumEntity) field added as last question
	 
	 #set coords for the nodes for the line entities
     set xyz_line_t(0) [GiD_Info Parametric line $line_id coord 0.0]
     set xyz_line_t(1) [GiD_Info Parametric line $line_id coord 1.0]
     
	 #assign nodes to variables
     lassign [lrange [GiD_Mesh get element $element_id] 3 4] node_0 node_1 
	  
	 #set coords for the nodes for the mesh elements
     set xyz_node(0) [lrange $[GiD_Mesh get node $node_0] 1 end]
     set xyz_node(1) [lrange $[GiD_Mesh get node $node_1] 1 end]
     
	 #find ‘by distance with tolerance’ if element nodes match the end points of the line entities
	 foreach i {0 1} {   
		set is_end($i) 0
		 set d2 [MathUtils::VectorDistance2 $xyz_line_t($i) $xyz_node($i)]
			  if {  $d2 < $tolerance } {
				set is_end($i) 1
			   #break
			  }
	     }
	 
	 #remove condition from the elements that are not at the ends
     if { !$is_end(0) && !$is_end(1)   } {
         lappend elements_to_remove $element_id
     } else {

		 #list with the question values
		 set LineCond [lrange [lindex [GiD_Info conditions $condition_name geometry $line_id] 0] 3 end]
		 
		 #if it is first end, remove the conditions regarding the second end node
		 if { $is_end(0) && !$is_end(1)   } {
		   lappend element_node0 $element_id
		   set valsNode0 [concat [lrange $LineCond 0 2] {-1 -1 -1} $line_id] ;#line_id is not passed I don't know why
		   GiD_AssignData condition $condition_name body_elements $valsNode0 $element_node0
		 }
		 
		 #if it is second end, remove the conditions regarding the first end node
		 if { !$is_end(0) && $is_end(1)  } {
		   lappend element_node1 $element_id
		   set valsNode1 [concat {-1 -1 -1} [lrange $LineCond 3 5] $line_id] ;#line_id is not passed I don't know why
		   GiD_AssignData condition $condition_name body_elements $valsNode1 $element_node1
		 }
		 
		 #if it both ends (only one element assigned to that line) do nothing
		 
		 
		 #if it doesn't have any dofs released, remove it
		 set dofsNotReleased {-1 -1 -1 -1 -1 -1}
		 set elemCond [lrange [lindex [GiD_Info conditions $condition_name mesh $element_id] 0] 3 8 ]
		 set hasNotDofsReleased [ lequal $elemCond $dofsNotReleased ]
		 if {$hasNotDofsReleased} {lappend elements_to_remove $element_id }
		 #set fd [open [file join "C:/Users/utilisateur/Dropbox/Work/Ruben/password.txt"] "a"]
		 #puts $fd $element_id
		 #puts $fd $dofsNotReleased
		 #puts $fd $elemCond
		 #puts $fd $hasNotDofsReleased
		 #close $fd
	  }
  }  
  
  #remove condition from the elements that are not at the ends
  GiD_UnAssignData condition $condition_name body_elements $elements_to_remove
}


proc lequal {l1 l2} {
    foreach elem $l1 {
        if {$elem ni $l2} {return false}
    }
    foreach elem $l2 {
        if {$elem ni $l1} {return false}
    }
    return true
}