#comet.tcl  -*- TCL -*-
#---------------------------------------------------------------------------
#This file is written in TCL lenguage 
#For more information about TCL look at: http://www.sunlabs.com/research/tcl/
#
#At least two procs must be in this file:
#
#    InitGIDProject dir - Will be called whenever a project is begun to be used.
#           where dir is the project's directory
#    EndGIDProject - Will be called whenever a project ends to be used.
#
#For more information about GID internals, check the program scripts.
#---------------------------------------------------------------------------

###### GiD-events implemented (procedures called automatically by GiD)

proc InitGIDProject { dir } {
    set ::GidPriv(ProgName) Safir_Structural_3D
    ChangeWindowTitle
	
	global problemtype_local
	array set problemtype_local [ReadProblemtypeXml [file join $dir Safir_Structural_3d.xml] Infoproblemtype {Name Version MinimumGiDVersion SuggestedGiDVersion Description}]
	
    SafirStructural3D_ChangeMenus
}

proc ChangedLanguage { newlan } {
    #to re-modify the menu that will be rebuild if current language is changed
    SafirStructural3D_ChangeMenus
}
###### end GiD-events implemented

proc SafirStructural3D_ChangeMenus { } {
    GidChangeDataLabel "Materials" ""
    GidChangeDataLabel "Conditions" ""
    GidChangeDataLabel "Problem Data" ""
    GidChangeDataLabel "Interval" ""
    
    GidAddUserDataOptions Constraints "GidOpenConditions Constraints" 2
    GidAddUserDataOptions "---" "" 3
	GidAddUserDataOptions "Loads" OpenLoadsWindow 4
    GidAddUserDataOptions "---" "" 5
    GidAddUserDataOptions "Properties" "GidOpenConditions Properties" 6
    GidAddUserDataOptions "---" "" 7
    GidAddUserDataOptions "Mass" "GidOpenConditions {Mass for Dynamic Calculation}" 8
    GidAddUserDataOptions "---" "" 9
    GidAddUserDataOptions "Problem Data" "GidOpenProblemData General" 10
    GidAddUserDataOptions "---" "" 11
    GidAddUserDataOptions "Material" "GidOpenProblemData Material" 12
	GidAddUserDataOptions "---" "" 13
	GidAddUserDataOptions "Relaxations" OpenRelaxationWindow 14
	GidAddUserDataOptions "---" "" 15
    GiDMenu::Create Structure PRE
    GiDMenu::InsertOption Structure [list "Car Park"] 0 PRE Carpark
    
	#add About Problem Types menu
	GiDMenu::Create "About Problem Type" PRE
	GiDMenu::InsertOption "About Problem Type" "Safir_Structural_3D" 0 PRE AboutStructural3D 
	
	GiDMenu::UpdateMenus
}

proc AboutStructural3D { } {
	global problemtype_local
	
	#set name of the window in GiD
	set w .gid.aboutMe
	
	InitWindow $w "About Safir_Structural_3D" AboutMeWindow

	frame $w.frmAboutMe
	
	 label $w.frmAboutMe.name -text "Name"
	 entry $w.frmAboutMe.nameVal -relief sunken -width 80 -textvariable problemtype_local(Name) -state readonly
	 label $w.frmAboutMe.version -text "Version"
	 entry $w.frmAboutMe.versionVal -relief sunken -width 80 -textvariable problemtype_local(Version) -state readonly
	 label $w.frmAboutMe.minimumGiDversion -text "Minimum GiD version"
	 entry $w.frmAboutMe.minimumGiDversionVal -relief sunken -width 80 -textvariable  problemtype_local(MinimumGiDVersion) -state readonly
	 label $w.frmAboutMe.suggestedGiDversion -text "Suggested GiD version"
	 entry $w.frmAboutMe.suggestedGiDversionVal -relief sunken -width 80 -textvariable  problemtype_local(SuggestedGiDVersion) -state readonly
	 label $w.frmAboutMe.description -text "Description"
	 entry $w.frmAboutMe.descriptionVal -relief sunken -width 80 -textvariable problemtype_local(Description) -state readonly

	grid $w.frmAboutMe  -padx 5 -pady 5 -sticky ew 

    grid $w.frmAboutMe.name $w.frmAboutMe.nameVal -sticky e
	grid $w.frmAboutMe.description $w.frmAboutMe.descriptionVal -sticky e
	grid $w.frmAboutMe.version $w.frmAboutMe.versionVal -sticky e
	grid $w.frmAboutMe.minimumGiDversion $w.frmAboutMe.minimumGiDversionVal -sticky e
	grid $w.frmAboutMe.suggestedGiDversion $w.frmAboutMe.suggestedGiDversionVal -sticky e

	
	focus $w.frmAboutMe
	}


proc WriteMaterialData {num} {
    
    return [GiD_Info gendata]
    
}

proc OpenRelaxationWindow { } { 
  #GiD_Process Mescape Geometry
  GidOpenConditions Relaxations
  GiD_Process Mescape Utilities Drawnormals Lines 1:end
}

proc OpenLoadsWindow { } { 
  #GiD_Process Mescape Geometry
  GidOpenConditions Loads
  #GiD_Process Mescape Utilities Drawnormals Lines 1:end
}

namespace eval DisconnectConditions {
    variable Identifier
}

proc DisconnectConditions::ComunicateWithGiD { op args } {
    variable Identifier
    switch $op {
        "INIT" {
            set PARENT [lindex $args 0]
            upvar      [lindex $args 1] ROW 
            set GDN [lindex $args 2]
            set STRUCT [lindex $args 3]
            
            global $GDN
            upvar \#0 $GDN GidData
            
            set cndname [lindex [split $STRUCT ,] 1]
            switch $cndname {
                Point_disconnect_degrees - Line_disconnect_degrees {
                    set Identifier $GidData($STRUCT,VALUE,2)
                }
                Line_disconnect_Id - Surface_disconnect_Id {
                    set Identifier $GidData($STRUCT,VALUE,1)
                }
                default {
                    if { ![info exists Identifier] } {
                        set Identifier Id1
                    }
                }
            }
            
            set l [label $PARENT.l$ROW -text "Identifier:"]
            set c [ComboBox $PARENT.c$ROW \
                    -textvariable DisconnectConditions::Identifier \
                    -values {Id1 Id2 Id3 Id4 Id5 Id6 Id7 Id8 Id9}]
            
            grid $l -row $ROW -column 0 -sticky e
            grid $c -row $ROW -column 1 -sticky w -pady 3
            
            if { [info exists $GDN\($STRUCT,HELP,0\)] } {
                GidHelp "$l $c" [subst $GidData($STRUCT,HELP,0)]
            }
            return ""
        }
        "SYNC" {
            set GDN [lindex $args 0]
            set STRUCT [lindex $args 1]
            
            set Identifier [string trim $Identifier]
            set ll [string length $Identifier]
            regsub -all " \t"  $Identifier {} Identifier
            if { $ll > 4 || ![regexp {^[a-zA-Z0-9]} $Identifier] } {
                return [list ERROR \
                        "Identifier must be a name with max 4 characters that begins with a letter or number"]
            }
            DWLocalSetValue $GDN $STRUCT Identifier $Identifier
            return ""
        }
    }
}

proc Carpark { } {
    
    global ParamsCarpark
    
    global ProfNam
    
    set w .gid.carpark
    
    set ParamsCarpark(NbPostX) 0        
    set ParamsCarpark(NbPostY) 0
    set ParamsCarpark(NbBeams) [expr $ParamsCarpark(NbPostX)-1]
    set ParamsCarpark(NbJoists) [expr $ParamsCarpark(NbPostY)-1]
    
    
    
    set ParamsCarpark(BeamsLength) 0
    set ParamsCarpark(JoistsLength) 0
    
    set ParamsCarpark(NbJoistsByBeam) 1
    set ParamsCarpark(DistBetweenJoists) [expr double($ParamsCarpark(BeamsLength)/$ParamsCarpark(NbJoistsByBeam).)]
    
    set ParamsCarpark(PostsHeight) 0
    set ParamsCarpark(SlabHeight) 0
    
    set ParamsCarpark(BeamsExtACBYN) 0
    set ParamsCarpark(BeamsIntACBYN) 0
    set ParamsCarpark(JoistsExtACBYN) 0
    set ParamsCarpark(JoistsIntACBYN) 0
    
    set ParamsCarpark(BeamLoad) 7500
    set ParamsCarpark(ShellLoad) 5000
    
    set ParamsCarpark(FyBeamsExt) 3.55e8 
    set ParamsCarpark(FyBeamsInt) 3.55e8
    set ParamsCarpark(FyJoistsExt) 3.55e8
    set ParamsCarpark(FyJoistsInt) 3.55e8
    set ParamsCarpark(FyPosts) 3.55e8
    
    set ParamsCarpark(MeshBeams) 0
    set ParamsCarpark(MeshJoists) 0
    set ParamsCarpark(MeshPosts) 0
    set ParamsCarpark(MeshSize) 0.5
    
    set ParamsCarpark(BeamsExtName) "EdgePbeam.tem"
    set ParamsCarpark(BeamsIntName) "IntPbeam.tem"
    set ParamsCarpark(JoistsExtName) "EdgeSbeam.tem"
    set ParamsCarpark(JoistsIntName) "IntSbeam.tem"
    set ParamsCarpark(PostsName) "Column.tem"
    
    
    set ParamsCarpark(Hasemi) 0
    
    
    InitWindow $w "Create Car Park" ParametricWindowGeom   
    
    frame $w.frmEquations
    
    label $w.frmEquations.nbPostXl -text "# Column X (separated by primary beams) "
    label $w.frmEquations.nbPostXr -text "#"
    entry $w.frmEquations.nbPostX -relief sunken -width 5 -textvariable ParamsCarpark(NbPostX)
    label $w.frmEquations.nbPostYl -text "# Column Y (separated by secondary beams) "
    label $w.frmEquations.nbPostYr -text "#"
    entry $w.frmEquations.nbPostY -relief sunken -width 5 -textvariable ParamsCarpark(NbPostY)
    label $w.frmEquations.nbJoistsByBeamsl -text "# Secondary beams between two posts"
    label $w.frmEquations.nbJoistsByBeamsr -text "#"
    entry $w.frmEquations.nbJoistsByBeams -relief sunken -width 5 -textvariable ParamsCarpark(NbJoistsByBeam) 
    label $w.frmEquations.beamsLengthl -text "Primary Beams Length "
    label $w.frmEquations.beamsLengthr -text "m"
    entry $w.frmEquations.beamsLength -relief sunken -width 5 -textvariable ParamsCarpark(BeamsLength)
    label $w.frmEquations.beamsExtNamel -text "Edge Prim. Beams Name "
    label $w.frmEquations.beamsExtNamer -text ".tem file"
    entry $w.frmEquations.beamsExtName -relief sunken -width 13 -textvariable ParamsCarpark(BeamsExtName)
    label $w.frmEquations.fybeamsextl -text "fy Edge Prim. Beams "
    label $w.frmEquations.fybeamsextr -text "N/m2"
    ComboBox $w.frmEquations.fybeamsext -editable 1 -width 10 -textvariable ParamsCarpark(FyBeamsExt) \
        -values { "2.45e8" "3.55e8" "4.6e8" "5e8"}
    #entry $w.frmEquations.fybeamsext -relief sunken -width 10 -textvariable ParamsCarpark(FyBeamsExt)
    label $w.frmEquations.extbeamsACBynl -text "Edge Prim. Beams ACB?"
    checkbutton $w.frmEquations.extbeamsACByn -variable ParamsCarpark(BeamsExtACBYN)
    label $w.frmEquations.beamsIntNamel -text "Internal Prim. Beams Name "
    label $w.frmEquations.beamsIntNamer -text ".tem file"
    entry $w.frmEquations.beamsIntName -relief sunken -width 13 -textvariable ParamsCarpark(BeamsIntName)
    label $w.frmEquations.fybeamsintl -text "fy Int. Prim. Beams"
    label $w.frmEquations.fybeamsintr -text "N/m2"
    ComboBox $w.frmEquations.fybeamsint -editable 1 -width 10 -textvariable ParamsCarpark(FyBeamsInt) \
        -values { "2.45e8" "3.55e8" "4.6e8" "5e8"}
    #entry $w.frmEquations.fybeamsint -relief sunken -width 10 -textvariable ParamsCarpark(FyBeamsInt)
    label $w.frmEquations.intbeamsACBynl -text "Int. Prim. Beams ACB?"
    checkbutton $w.frmEquations.intbeamsACByn -variable ParamsCarpark(BeamsIntACBYN)
    label $w.frmEquations.joistsLengthl -text "Secondary Beams Length "
    label $w.frmEquations.joistsLengthr -text "m"
    entry $w.frmEquations.joistsLength -relief sunken -width 5 -textvariable ParamsCarpark(JoistsLength)
    label $w.frmEquations.joistsExtNamel -text "Edge Sec. Beams Name "
    label $w.frmEquations.joistsExtNamer -text ".tem file"
    entry $w.frmEquations.joistsExtName -relief sunken -width 13 -textvariable ParamsCarpark(JoistsExtName)
    label $w.frmEquations.fyjoistsextl -text "fy Edge Sec. Beams "
    label $w.frmEquations.fyjoistsextr -text "N/m2"
    ComboBox $w.frmEquations.fyjoistsext -editable 1 -width 10 -textvariable ParamsCarpark(FyJoistsExt) \
        -values { "2.45e8" "3.55e8" "4.6e8" "5e8"}
    #entry $w.frmEquations.fyjoistsext -relief sunken -width 10 -textvariable ParamsCarpark(FyJoistsExt)
    label $w.frmEquations.extjoistACBynl -text "Edge Sec. Beams ACB?"
    checkbutton $w.frmEquations.extjoistACByn -variable ParamsCarpark(JoistsExtACBYN)
    label $w.frmEquations.joistsIntNamel -text "Internal Sec. Beams Name "
    label $w.frmEquations.joistsIntNamer -text ".tem file"
    entry $w.frmEquations.joistsIntName -relief sunken -width 13 -textvariable ParamsCarpark(JoistsIntName)
    label $w.frmEquations.fyjoistsintl -text "fy Internal Sec. Beams "
    label $w.frmEquations.fyjoistsintr -text "N/m2"
    ComboBox $w.frmEquations.fyjoistsint -editable 1 -width 10 -textvariable ParamsCarpark(FyJoistsInt) \
        -values { "2.45e8" "3.55e8" "4.6e8" "5e8"}
    #entry $w.frmEquations.fyjoistsint -relief sunken -width 10 -textvariable ParamsCarpark(FyJoistsInt)
    label $w.frmEquations.intjoistsACBynl -text "Internal Sec. Beams ACB?"
    checkbutton $w.frmEquations.intjoistsACByn -variable ParamsCarpark(JoistsIntACBYN)
    label $w.frmEquations.postsNamel -text "Columns Name "
    label $w.frmEquations.postsNamer -text ".tem file"
    entry $w.frmEquations.postsName -relief sunken -width 13 -textvariable ParamsCarpark(PostsName)
    label $w.frmEquations.fypostsl -text "fy Columns "
    label $w.frmEquations.fypostsr -text "N/m2"
    ComboBox $w.frmEquations.fyposts -editable 1 -width 10 -textvariable ParamsCarpark(FyPosts) \
        -values { "2.45e8" "3.55e8" "4.6e8" "5e8"}
    #entry $w.frmEquations.fyposts -relief sunken -width 10 -textvariable ParamsCarpark(FyPosts)
    label $w.frmEquations.slabHeightl -text "Column Height"
    label $w.frmEquations.slabHeightr -text "m"
    entry $w.frmEquations.slabHeight -relief sunken -width 5 -textvariable ParamsCarpark(SlabHeight) 
    label $w.frmEquations.meshSizel -text "Mesh Element size"
    label $w.frmEquations.meshSizer -text "m"
    entry $w.frmEquations.meshSize -relief sunken -width 5 -textvariable ParamsCarpark(MeshSize)
    label $w.frmEquations.beamLoadl -text "Beam Load"
    label $w.frmEquations.beamLoadr -text "N/m"
    entry $w.frmEquations.beamLoad -relief sunken -width 10 -textvariable ParamsCarpark(BeamLoad)
    label $w.frmEquations.shellLoadl -text "Shell Load"
    label $w.frmEquations.shellLoadr -text "N/m2"
    entry $w.frmEquations.shellLoad -relief sunken -width 10 -textvariable ParamsCarpark(ShellLoad)
    label $w.frmEquations.fireHasemil -text "Hasemi"
    checkbutton $w.frmEquations.fireHasemi -variable ParamsCarpark(Hasemi)
    
    set def_back [$w cget -background]
    frame $w.frmResults -bg [CCColorActivo $def_back]
    label $w.frmResults.nbBeamsl -text "# Primary Beams"
    label $w.frmResults.nbBeamsr -text "#"
    entry $w.frmResults.nbBeams -relief sunken -width 5 -textvariable ParamsCarpark(NbBeams) 
    label $w.frmResults.nbJoistsl -text "# Secondary Beams"
    label $w.frmResults.nbJoistsr -text "#"
    entry $w.frmResults.nbJoists -relief sunken -width 5 -textvariable ParamsCarpark(NbJoists)
    label $w.frmResults.distBetweenJoistsl -text "Dist between joists"
    label $w.frmResults.distBetweenJoistsr -text "m"
    entry $w.frmResults.distBetweenJoists -relief sunken -width 5 -textvariable ParamsCarpark(DistBetweenJoists)
    
    $w.frmResults.distBetweenJoists configure -state disabled
    $w.frmResults.nbJoists configure -state disabled
    $w.frmResults.nbBeams configure -state disabled
    
    button $w.frmResults.btnUpdate -text "Update" \
        -command "UpdateDistBetweenJoists $w" \
        -underline 0 -width 6
    
    
    frame $w.frmButtons -bg [CCColorActivo $def_back]
    button $w.frmButtons.btnApply -text "Apply" \
        -command "DrawCarpark $w" \
        -underline 0 -width 6
    button $w.frmButtons.btnclose -text "Close" \
        -command "destroy $w" \
        -underline 0 -width 6
    
    
    grid $w.frmEquations -padx 5 -pady 5 -sticky ew    
    grid $w.frmEquations.nbPostXl $w.frmEquations.nbPostX $w.frmEquations.nbPostXr -sticky w
    grid $w.frmEquations.nbPostYl $w.frmEquations.nbPostY $w.frmEquations.nbPostYr -sticky w
    grid $w.frmEquations.beamsLengthl $w.frmEquations.beamsLength $w.frmEquations.beamsLengthr -sticky w
    grid $w.frmEquations.joistsLengthl $w.frmEquations.joistsLength $w.frmEquations.joistsLengthr -sticky w
    grid $w.frmEquations.nbJoistsByBeamsl $w.frmEquations.nbJoistsByBeams $w.frmEquations.nbJoistsByBeamsr -sticky w
    grid $w.frmEquations.beamsExtNamel $w.frmEquations.beamsExtName $w.frmEquations.beamsExtNamer -sticky w
    grid $w.frmEquations.fybeamsextl $w.frmEquations.fybeamsext $w.frmEquations.fybeamsextr -sticky w
    grid $w.frmEquations.extbeamsACBynl $w.frmEquations.extbeamsACByn -sticky w
    grid $w.frmEquations.beamsIntNamel $w.frmEquations.beamsIntName $w.frmEquations.beamsIntNamer -sticky w
    grid $w.frmEquations.fybeamsintl $w.frmEquations.fybeamsint $w.frmEquations.fybeamsintr -sticky w
    grid $w.frmEquations.intbeamsACBynl $w.frmEquations.intbeamsACByn -sticky w
    grid $w.frmEquations.joistsExtNamel $w.frmEquations.joistsExtName $w.frmEquations.joistsExtNamer -sticky w
    grid $w.frmEquations.fyjoistsextl $w.frmEquations.fyjoistsext $w.frmEquations.fyjoistsextr -sticky w
    grid $w.frmEquations.extjoistACBynl $w.frmEquations.extjoistACByn -sticky w
    grid $w.frmEquations.joistsIntNamel $w.frmEquations.joistsIntName $w.frmEquations.joistsIntNamer -sticky w
    grid $w.frmEquations.fyjoistsintl $w.frmEquations.fyjoistsint $w.frmEquations.fyjoistsintr -sticky w
    grid $w.frmEquations.intjoistsACBynl $w.frmEquations.intjoistsACByn -sticky w
    grid $w.frmEquations.postsNamel $w.frmEquations.postsName $w.frmEquations.postsNamer -sticky w
    grid $w.frmEquations.fypostsl $w.frmEquations.fyposts $w.frmEquations.fypostsr -sticky w
    grid $w.frmEquations.slabHeightl $w.frmEquations.slabHeight $w.frmEquations.slabHeightr -sticky w
    grid $w.frmEquations.meshSizel $w.frmEquations.meshSize $w.frmEquations.meshSizer -sticky w
    grid $w.frmEquations.beamLoadl $w.frmEquations.beamLoad $w.frmEquations.beamLoadr -sticky w
    grid $w.frmEquations.shellLoadl $w.frmEquations.shellLoad $w.frmEquations.shellLoadr -sticky w
    
    grid $w.frmEquations.fireHasemil $w.frmEquations.fireHasemi -sticky w
    
    
    grid $w.frmResults -padx 5 -pady 5 -sticky ew
    grid $w.frmResults.nbBeamsl $w.frmResults.nbBeams $w.frmResults.nbBeamsr -sticky w
    grid $w.frmResults.nbJoistsl $w.frmResults.nbJoists $w.frmResults.nbJoistsr $w.frmResults.btnUpdate -sticky w
    grid $w.frmResults.distBetweenJoistsl $w.frmResults.distBetweenJoists $w.frmResults.distBetweenJoistsr -sticky w
    
    grid $w.frmButtons -sticky ews -columnspan 7
    grid $w.frmButtons.btnApply $w.frmButtons.btnclose -padx 5 -pady 6
    
    grid columnconf $w "0" -weight 1
    grid rowconfigure $w "3" -weight 1
    
    focus $w.frmButtons.btnApply
    
    bind $w <Alt-c> "tkButtonInvoke $w.frmButtons.btnclose"
    bind $w <Escape> "tkButtonInvoke $w.frmButtons.btnclose"
    
}

proc UpdateDistBetweenJoists { w } {
    
    global ParamsCarpark
    
    set w .gid.carpark
    set NbJoistsByBeam [expr $ParamsCarpark(NbJoistsByBeam) +1]
    set ParamsCarpark(DistBetweenJoists) [expr double($ParamsCarpark(BeamsLength)/$NbJoistsByBeam) ]
    set ParamsCarpark(NbBeams) [expr $ParamsCarpark(NbPostX)-1]
    set ParamsCarpark(NbJoists) [expr $ParamsCarpark(NbPostY)-1]
    
}

proc DrawCarpark {w} {
    
    destroy $w
    
    GidUtils::WaitState .gid
    GidUtils::DisableGraphics
    
    global ParamsCarpark
    
    set NbPostX $ParamsCarpark(NbPostX) 
    set NbPostY $ParamsCarpark(NbPostY) 
    set NbBeams [expr $ParamsCarpark(NbPostX) -1]
    set NbJoists [expr $ParamsCarpark(NbPostY) -1]
    set NbJoistsByBeam [expr $ParamsCarpark(NbJoistsByBeam) +1]
    set DistBetweenJoists [expr $ParamsCarpark(BeamsLength)/($ParamsCarpark(NbJoistsByBeam)+1)] 
    
    set BeamsLength $ParamsCarpark(BeamsLength) 
    set JoistsLength $ParamsCarpark(JoistsLength) 
    set PostsHeight $ParamsCarpark(PostsHeight) 
    set PostsName $ParamsCarpark(PostsName) 
    set SlabHeight $ParamsCarpark(SlabHeight) 
    
    set BeamsExtACBYN  $ParamsCarpark(BeamsExtACBYN)
    set BeamsIntACBYN $ParamsCarpark(BeamsIntACBYN) 
    set JoistsExtACBYN $ParamsCarpark(JoistsExtACBYN) 
    set JoistsIntACBYN $ParamsCarpark(JoistsIntACBYN) 
    
    set BeamLoad [expr -$ParamsCarpark(BeamLoad)] 
    set ShellLoad [expr -$ParamsCarpark(ShellLoad)] 
    
    set FyBeamsInt $ParamsCarpark(FyBeamsInt) 
    set FyBeamsExt $ParamsCarpark(FyBeamsExt) 
    set FyJoistsInt $ParamsCarpark(FyJoistsInt) 
    set FyJoistsExt $ParamsCarpark(FyJoistsExt) 
    set FyPosts $ParamsCarpark(FyPosts) 
    
    set MeshBeams $ParamsCarpark(MeshBeams) 
    set MeshJoists $ParamsCarpark(MeshJoists) 
    set MeshPosts $ParamsCarpark(MeshPosts) 
    set MeshSize $ParamsCarpark(MeshSize) 
    
    set x0 0.0
    set y0 0.0
    set z0 0.0
    
    set x1 $x0
    set y1 $x0
    set z1 [expr $z0 + $SlabHeight]
    
    set x2 $x1
    set y2 $y1
    set z2 [expr $z1 + $SlabHeight]
    
    GiD_Process rotate angle 45 45 
    GiD_Process zoom frame 
    GiD_Process escape escape escape Utilities Variables CreateAlwaysNewPoint  1 
    GiD_Process escape escape escape escape 
    GiD_Process geometry create Point \
        $x0,$y0,$z0 \
        $x1,$y1,$z1 \
        $x2,$y2,$z2 \
        GiD_Process escape escape escape escape 
    
    GiD_Process escape escape escape escape geometry create line Join 1 2 3 
    GiD_Process escape escape escape escape 
    GiD_Process escape escape escape Utilities Copy Lines Duplicate MaintainLayers Mcopy \
        $NbJoists \
        Translation FNoJoin 0.0,0.0,0.0 FNoJoin 0.0,$JoistsLength,0.0  1 2
    
    GiD_Process escape escape escape escape 
    GiD_Process zoom frame
    
    set j1 2
    for {set i1 0} {$i1<=$NbJoists} {incr i1} {
        GiD_Process escape escape escape escape geometry create line Join $j1 [expr $j1+3]
        set j1 [expr $j1 + 3]
    }
    
    set NbLines [expr 2*$NbPostY+$NbJoists]
    set LinesToCopy ""
    for {set i2 1} {$i2<=$NbLines} {incr i2} {
        set LinesToCopy $LinesToCopy\ $i2
    }
    
    set cmd1 "escape escape escape escape  Utilities Copy Lines Duplicate MaintainLayers Mcopy $NbBeams Translation FJoin 1 FNoJoin $BeamsLength,0,0 $LinesToCopy"
    .central.s process $cmd1
    GiD_Process escape escape escape escape
    
    for {set k3 0} {$k3<=$NbJoists} {incr k3} {
        set NbCopy ""
        for {set i3 0} {$i3<=$NbBeams} {incr i3} { 
            set Acc3 [expr (2+(3+(3*$NbJoists))*$i3) + (3*$k3)]
            set NbCopy $NbCopy\ $Acc3
        }
        
        set cmd3 "escape escape escape escape geometry create line Join $NbCopy"
        .central.s process $cmd3
    }
    GiD_Process escape escape escape escape
    GiD_Process zoom frame
    GiD_Process escape escape escape escape
    
    set NbLines1 [expr ($NbPostX * $NbPostY) * 2 + ($NbPostX * $NbJoists)]
    set NbLines2 [expr $NbLines1 + ($NbPostY * $NbBeams)]
    #set NbJoistsByBeam  [expr ($BeamsLength-($BeamsLength % $DistBetweenJoists))/$DistBetweenJoists] 
    set NumBeams1 ""
    for {set i4 [expr $NbLines1+1]} {$i4<=$NbLines2} {incr i4} {
        set NumBeams1 $NumBeams1\ $i4
    }        
    
    set cmd4 "escape escape escape escape geometry edit DivideLine Multiple NumDivisions $NbJoistsByBeam $NumBeams1 escape escape escape escape"
    .central.s process $cmd4
    GiD_Process escape escape escape escape
    GiD_Process zoom frame
    GiD_Process escape escape escape escape
    
    set NbPoints1 [expr $NbPostX * $NbPostY * 3]
    set NbPoints2 [expr $NbPoints1 + $NbBeams * ($NbJoistsByBeam - 1) * $NbPostY]
    for {set i5 0} {$i5<= [expr $NbBeams * ($NbJoistsByBeam-1)-1] } {incr i5} {
        set NumPoints5 ""
        for {set j5 0} {$j5<=$NbJoists} {incr j5} { 
            set Acc5 [expr ($NbPoints1 + 1) + $j5 * ($NbBeams * ($NbJoistsByBeam - 1)) + $i5]
            set NumPoints5 $NumPoints5\ $Acc5
        }
        set cmd5 "escape escape escape escape geometry create line Join $NumPoints5"
        .central.s process $cmd5
        GiD_Process escape escape escape escape
    }
    
    GiD_Process zoom frame
    GiD_Process escape escape escape escape
    
    GiD_Process Utilities Collapse Points 1:
    GiD_Process escape escape escape
    
    set cmd6 "escape escape escape escape geometry create NurbsSurface Automatic 4 escape "
    .central.s process $cmd6
    GiD_Process escape escape escape escape
    
    
    set LAX1x 0
    set LAX1y [expr $NbJoists *  $JoistsLength]
    set LAX1z $SlabHeight
    set LAX2x 1
    set LAX2y $LAX1y
    set LAX2z $LAX1z
    set LAX3x 0
    set LAX3y [expr $LAX2y -1]
    set LAX3z $LAX2z
    
    set LAY1x [expr $NbBeams *  $BeamsLength]
    set LAY1y 0
    set LAY1z $SlabHeight
    set LAY2x $LAY1x
    set LAY2y 1
    set LAY2z $LAY1z
    set LAY3x [expr $LAY2x +1]
    set LAY3y 0
    set LAY3z $LAY2z
    
    set LAZ1x [expr $NbBeams *  $BeamsLength]
    set LAZ1y [expr $NbJoists *  $JoistsLength]
    set LAZ1z 0
    set LAZ2x $LAZ1x
    set LAZ2y $LAZ1y
    set LAZ2z 1
    set LAZ3x [expr $LAZ2x -1]
    set LAZ3y $LAZ2y
    set LAZ3z 0
    
    GiD_Process escape escape escape escape Data LocalAxes DefineLocAxes LAX 3PointsXZ $LAX1x,$LAX1y,$LAX1z  $LAX2x,$LAX2y,$LAX2z $LAX3x,$LAX3y,$LAX3z
    GiD_Process escape escape escape escape
    GiD_Process escape escape escape escape Data LocalAxes DefineLocAxes LAY 3PointsXZ $LAY1x,$LAY1y,$LAY1z  $LAY2x,$LAY2y,$LAY2z $LAY3x,$LAY3y,$LAY3z
    GiD_Process escape escape escape escape
    GiD_Process escape escape escape escape Data LocalAxes DefineLocAxes LAZ 3PointsXZ $LAZ1x,$LAZ1y,$LAZ1z  $LAZ2x,$LAZ2y,$LAZ2z $LAZ3x,$LAZ3y,$LAZ3z
    GiD_Process escape escape escape escape
    
    set NumPosts ""
    for {set j6 0} {$j6<=$NbBeams} {incr j6} {
        for {set i6 1} {$i6<=[expr 2*$NbPostY]} {incr i6} { 
            set Acc6 [expr $i6 + $j6 *(2*$NbPostY+$NbJoists)]
            set NumPosts $NumPosts\ $Acc6
        }
    }
    
    set NumJoists ""
    set NumJoistsExt ""
    set NumJoistsInt ""
    set NumJoistsIntBetweenPosts ""
    
    for {set j7 0} {$j7<=$NbBeams} {incr j7} {
        for {set i7 1} {$i7<=$NbJoists} {incr i7} { 
            set Acc7 [expr $i7 + ($NbPostY*2) + $j7 *(2*$NbPostY+$NbJoists)]
            set NumJoists $NumJoists\ $Acc7
        }
    }
    
    for {set j71 1} {$j71<=[expr $NbBeams-1]} {incr j71} {
        for {set i71 1} {$i71<=$NbJoists} {incr i71} { 
            set Acc71 [expr $i71 + ($NbPostY*2) + $j71 *(2*$NbPostY+$NbJoists)]
            set NumJoistsIntBetweenPosts $NumJoistsIntBetweenPosts\ $Acc71
        }
    }
    
    for {set i72 1} {$i72<=$NbJoists} {incr i72} { 
        set Acc72 [expr $i72 + ($NbPostY*2)]
        set NumJoistsExt $NumJoistsExt\ $Acc72
    }
    for {set i73 1} {$i73<=$NbJoists} {incr i73} { 
        set Acc73 [expr $i73 + ($NbPostY*2*$NbPostX)+($NbJoists*$NbBeams)]
        set NumJoistsExt $NumJoistsExt\ $Acc73
    }
    
    for {set j74 1} {$j74<=[expr $NbBeams-1]} {incr j74} {
        for {set i74 1} {$i74<=$NbJoists} {incr i74} { 
            set Acc74 [expr $i74 + ($NbPostY*2) + $j74 *(2*$NbPostY+$NbJoists)]
            set NumJoistsInt $NumJoistsInt\ $Acc74
        }
    }
    
    set NbBeamsBeforeDivision [expr ($NbPostY*2*$NbPostX) + ($NbPostX*$NbJoists) + ($NbPostX-1)*$NbPostY]
    set NbBeamsAfterDivision [expr $NbBeamsBeforeDivision + ($NbBeams*$NbJoistsByBeam*$NbPostY)]
    set NbBeamsFinal [expr $NbBeamsAfterDivision + ($NbJoistsByBeam-1)*$NbBeams*$NbJoists]
    
    for {set i8 [expr $NbBeamsAfterDivision + 1]} {$i8<=$NbBeamsFinal} {incr i8} { 
        set Acc8 $i8
        set NumJoistsInt $NumJoistsInt\ $Acc8
        set NumJoists $NumJoists\ $Acc8
    }
    
    set NumBeams ""
    set NumBeamsExt ""
    set NumBeamsInt ""
    
    for {set i9 [expr $NbBeamsBeforeDivision + 1]} {$i9<=$NbBeamsAfterDivision} {incr i9} { 
        set Acc9 $i9
        set NumBeams $NumBeams\ $Acc9
    }
    
    for {set i91 [expr $NbBeamsBeforeDivision + 1]} {$i91<=[expr $NbBeamsBeforeDivision + ($NbBeams*$NbJoistsByBeam)]} {incr i91} { 
        set Acc91 $i91
        set NumBeamsExt $NumBeamsExt\ $Acc91
    }
    for {set i92 [expr $NbBeamsAfterDivision - ($NbBeams*$NbJoistsByBeam)+1]} {$i92<=$NbBeamsAfterDivision} {incr i92} { 
        set Acc92 $i92
        set NumBeamsExt $NumBeamsExt\ $Acc92
    }
    
    for {set i93 [expr $NbBeamsBeforeDivision + 1 + ($NbBeams*$NbJoistsByBeam)]} {$i93<=[expr $NbBeamsAfterDivision - ($NbBeams*$NbJoistsByBeam)]} {incr i93} { 
        set Acc93 $i93
        set NumBeamsInt $NumBeamsInt\ $Acc93
    }
    
    set NumSurfaces ""
    set NbSurfaces [expr ($NbBeams*$NbJoistsByBeam*$NbJoists)]
    for {set i10 1} {$i10<=$NbSurfaces} {incr i10} { 
        set Acc10 $i10
        set NumSurfaces $NumSurfaces\ $Acc10
    }
    
    set NumPointsXYZ ""
    for {set i11 1} {$i11<=[expr ($NbPostY*3*$NbPostX)]} {incr i11} { 
        set Acc11 $i11
        set NumPointsXYZ $NumPointsXYZ\ $Acc11
        set i11 [expr $i11+2]
    }
    
    set NumPointsXY ""
    for {set i12 3} {$i12<=[expr ($NbPostY*3*$NbPostX)]} {incr i12} { 
        set Acc12 $i12
        set NumPointsXY $NumPointsXY\ $Acc12
        set i12 [expr $i12+2]
    }
    
    set NumJoistsBlocX ""
    for {set i13 1} {$i13<=$NbJoists} {incr i13} { 
        set Acc13 [expr $i13 + ($NbPostY*2)]
        set NumJoistsBlocX $NumJoistsBlocX\ $Acc13
    }
    
    set NumBeamsBlocY ""
    for {set i14 [expr $NbBeamsBeforeDivision + 1]} {$i14<=[expr $NbBeamsBeforeDivision + ($NbBeams*$NbJoistsByBeam)]} {incr i14} { 
        set Acc14 $i14 
        set NumBeamsBlocY $NumBeamsBlocY\ $Acc14
    }
    
    set NumBeamsFacadeLoad ""
    for {set i15 [expr $NbBeamsBeforeDivision+1 + ($NbBeams*$NbJoistsByBeam*$NbJoists)]} {$i15<=[expr $NbBeamsAfterDivision]} {incr i15} { 
        set Acc15 $i15
        set NumBeamsFacadeLoad $NumBeamsFacadeLoad\ $Acc15
    }
    
    set NumJoistsFacadeLoad ""
    for {set i16 [expr ($NbPostY*2*$NbPostX) + ($NbBeams)*$NbJoists+1]} {$i16<=[expr ($NbPostY*2*$NbPostX) + ($NbPostX)*$NbJoists +1 ]} {incr i16} { 
        set Acc16 $i16
        set NumJoistsFacadeLoad $NumJoistsFacadeLoad\ $Acc16
    }
    
    
    
    
    GiD_Process escape escape escape escape Data ProblemData Safir_Static_3D_Analysis Mesh_from_GID_Mesher PARDISO 1 RENUMGEO DYNAMIC_APPR_NR COMEBACK 1.e-5 1.0e-3 5 2 440 0 1 3 2 12 3600 36. 60 no no no no yes yes no no no 12 STEELEC3 2.1e11 0.3 $FyBeamsExt 3.0e7 0. STEEL_WPB 2.1e11 0.3 $FyBeamsExt 3.0e7 3.0e6 STEELEC3 2.1e11 0.3 $FyBeamsInt 3.0e7 3.0e6 STEEL_WPB 2.1e11 0.3 $FyBeamsInt 3.0e7 3.0e6 STEELEC3 2.1e11 0.3 $FyJoistsExt  3.0e7 3.0e6 STEEL_WPB 2.1e11 0.3 $FyJoistsExt  3.0e7 3.0e6 STEELEC3 2.1e11 0.3 $FyJoistsInt 3.0e7 3.0e6 STEEL_WPB 2.1e11 0.3 $FyJoistsInt 3.0e7 3.0e6 STEELEC3 2.1e11 0.3 $FyPosts  3.0e7 3.0e6 INSULATION 2.1e11 0.3 3.55e8 3.0e7 3.0e6 SILCONC2D 2.1e11 0.3 3.55e8 3.0e7 3.0e6 STEELEC2 2.1e11 0.3 5e8 3.0e7 3.0e6 STEELEC3 2.1e11 0.3 355000000 3.0e7 3.0e6 STEELEC3 2.1e11 0.3 355000000 3.0e7 3.0e6 STEELEC3 2.1e11 0.3 355000000 3.0e7 3.0e6 STEELEC3 2.1e11 0.3 355000000 3.0e7 3.0e6 STEELEC3 2.1e11 0.3 355000000 3.0e7 3.0e6 STEELEC3 2.1e11 0.3 355000000 3.0e7 3.0e6 STEELEC3 2.1e11 0.3 355000000 3.0e7 3.0e6 STEELEC3 2.1e11 0.3 355000000 3.0e7 3.0e6 STEELEC3 2.1e11 0.3 355000000 3.0e7 3.0e6 STEELEC3 2.1e11 0.3 355000000 3.0e7 3.0e6
    GiD_Process escape escape escape escape
    
    set cmd7 "escape escape escape escape data cond assign Point-Constraints change 1 1 1 0 0 1 $NumPointsXYZ"
    .central.s process $cmd7
    GiD_Process escape escape escape escape
    
    set cmd8 "escape escape escape escape data cond assign Point-Constraints change 1 1 0 0 0 1 $NumPointsXY"
    .central.s process $cmd8
    GiD_Process escape escape escape escape
    
    set cmd9 "data cond assign Line-Constraints change 1 0 0 0 0 0 $NumJoistsBlocX"
    .central.s process $cmd9
    GiD_Process escape escape escape escape
    
    set cmd10 "data cond assign Line-Constraints change 0 1 0 0 0 0 $NumBeamsBlocY"
    .central.s process $cmd10
    GiD_Process escape escape escape escape
    
    set cmd11 "data cond assign Global_Shell_Load Change 0.0 0.0 $ShellLoad  F1 x.fct $NumSurfaces"
    .central.s process $cmd11
    GiD_Process escape escape escape escape
    
    set cmd12 "Data Conditions AssignCond Beam-Load Change 0.0 0.0 $BeamLoad F1 x.fct $NumBeamsFacadeLoad $NumJoistsFacadeLoad"
    .central.s process $cmd12
    GiD_Process escape escape escape escape
    
    set PostsName $ParamsCarpark(PostsName)
    
    set PostHeight [expr 2 * $SlabHeight] 
    set PostMesh [expr int($PostHeight/$MeshSize)]
    set JoistsMesh [expr $JoistsLength / $MeshSize]
    set BeamsMesh [expr int($BeamsLength/($NbJoistsByBeam*$MeshSize))*$NbBeams]
    
    set JoistsExtNameAcc [expr int(($NbPostY * $PostMesh) + 1)]
    set JoistsIntNameAcc [expr int(($NbPostY * $PostMesh * 2) + ($NbJoists * $JoistsMesh) + 1)]
    set BeamsExtNameAcc [expr int(($NbPostX * $NbPostY * $PostMesh) + 1 + ($NbJoists * $JoistsMesh * $NbPostX))]
    set BeamsIntNameAcc [expr int($BeamsExtNameAcc + ($NbJoistsByBeam * $BeamsMesh))]
    
    set Hasemi $ParamsCarpark(Hasemi) 
    set BeamsExtName $ParamsCarpark(BeamsExtName) 
    set BeamsIntName $ParamsCarpark(BeamsIntName) 
    set JoistsExtName $ParamsCarpark(JoistsExtName) 
    set JoistsIntName $ParamsCarpark(JoistsIntName) 
    
    set ExtensionTem {_1.tem}
    
    if {$Hasemi == 1} {
        if {$BeamsExtNameAcc>999} {
            set BeamsExtName "b$BeamsExtNameAcc$ExtensionTem"
        } elseif {$BeamsExtNameAcc>99} {
            set BeamsExtName "b0$BeamsExtNameAcc$ExtensionTem"
        } elseif {$BeamsExtNameAcc>9} {
            set BeamsExtName "b00$BeamsExtNameAcc$ExtensionTem"
        } elseif {$BeamsExtNameAcc<10} {
            set BeamsExtName "b000$BeamsExtNameAcc$ExtensionTem"
        }
    }
    
    if {$Hasemi == 1} {
        if {$BeamsIntNameAcc>999} {
            set BeamsIntName "b$BeamsIntNameAcc$ExtensionTem"
        } elseif {$BeamsIntNameAcc>99} {
            set BeamsIntName "b0$BeamsIntNameAcc$ExtensionTem"
        } elseif {$BeamsIntNameAcc>9} {
            set BeamsIntName "b00$BeamsIntNameAcc$ExtensionTem"
        } elseif {$BeamsIntNameAcc<10} {
            set BeamsIntName "b000$BeamsIntNameAcc$ExtensionTem"
        }
    }
    
    if {$Hasemi == 1} {
        if {$JoistsExtNameAcc>999} {
            set JoistsExtName "b$JoistsExtNameAcc$ExtensionTem"
        } elseif {$JoistsExtNameAcc>99} {
            set JoistsExtName "b0$JoistsExtNameAcc$ExtensionTem"
        } elseif {$JoistsExtNameAcc>9} {
            set JoistsExtName "b00$JoistsExtNameAcc$ExtensionTem"
        } elseif {$JoistsExtNameAcc<10} {
            set JoistsExtName "b000$JoistsExtNameAcc$ExtensionTem"
        }
    }
    
    if {$Hasemi == 1} {
        if {$JoistsIntNameAcc>999} {
            set JoistsIntName "b$JoistsIntNameAcc$ExtensionTem"
        } elseif {$JoistsIntNameAcc>99} {
            set JoistsIntName "b0$JoistsIntNameAcc$ExtensionTem"
        } elseif {$JoistsIntNameAcc>9} {
            set JoistsIntName "b00$JoistsIntNameAcc$ExtensionTem"
        } elseif {$BeamsExtNameAcc<10} {
            set JoistsIntName "b000$JoistsIntNameAcc$ExtensionTem"
        } 
    }
    
    if {$BeamsExtACBYN == 0} {
        set cmd13 "data cond assign BEAM_Cross_Section change $BeamsExtName LAX 2 1 2 3 4 $NumBeamsExt"
    } else {
        set cmd13 "data cond assign BEAM_Cross_Section change $BeamsExtName LAX 3 1 10 2 4 $NumBeamsExt"
    }
    .central.s process $cmd13
    GiD_Process escape escape escape escape
    
    if {$BeamsIntACBYN == 0} {
        set cmd14 "data cond assign BEAM_Cross_Section change $BeamsIntName LAX 2 1 2 3 4 $NumBeamsInt"
    }         else {
        set cmd14 "data cond assign BEAM_Cross_Section change $BeamsIntName LAX 3 3 10 4 4 $NumBeamsInt"
    }
    .central.s process $cmd14
    GiD_Process escape escape escape escape
    
    if {$JoistsExtACBYN == 0} {
        set cmd15 "data cond assign BEAM_Cross_Section change $JoistsExtName LAY 2 1 2 3 4 $NumJoistsExt"
    }         else {
        set cmd15 "data cond assign BEAM_Cross_Section change $JoistsExtName LAY 3 5 10 6 4 $NumJoistsExt"
    }
    .central.s process $cmd15
    GiD_Process escape escape escape escape
    
    if {$JoistsIntACBYN == 0} {
        set cmd16 "data cond assign BEAM_Cross_Section change $JoistsIntName LAY 2 1 2 3 4 $NumJoistsInt"
    }         else {
        set cmd16 "data cond assign BEAM_Cross_Section change $JoistsIntName LAY 3 7 10 8 4 $NumJoistsInt"
    }
    .central.s process $cmd16
    GiD_Process escape escape escape escape
    
    set cmd17 "data cond assign BEAM_Cross_Section change $ParamsCarpark(PostsName) LAZ 1 1 2 3 4 $NumPosts"
    .central.s process $cmd17
    GiD_Process escape escape escape escape
    
    if {$Hasemi == 1} {
        set cmd18 "data cond assign SHELL_Section_property change s0001_1.tsh 2 11 12 3 $NumSurfaces"
    } else {
        set cmd18 "data cond assign SHELL_Section_property change slab.tsh 2 3 4 3 $NumSurfaces"
    }
    .central.s process $cmd18
    GiD_Process escape escape escape escape
    
    
    set cmd19 "data cond assign Mass_on_Beam change 100 2.0 $NumBeams $NumJoists $NumPosts"
    .central.s process $cmd19
    GiD_Process escape escape escape escape
    
    set cmd20 "data cond assign Mass_on_Shell change 300 $NumSurfaces"
    .central.s process $cmd20
    GiD_Process escape escape escape escape
    
    GiD_Process utilities variables ForceMeshEntities 2
    GiD_Process escape escape escape escape
    
    set cmd21 "Mescape Meshing ElemType Quadrilateral $NumSurfaces"
    .central.s process $cmd21
    GiD_Process escape escape escape escape
    
    set MeshBeams [expr int($BeamsLength/($NbJoistsByBeam*$MeshSize))]
    set cmd22 "Meshing Structured Lines $MeshBeams $NumBeams"
    .central.s process $cmd22
    GiD_Process escape escape escape escape
    
    set MeshJoists [expr $JoistsLength/$MeshSize]
    set cmd23 "Meshing Structured Lines $MeshJoists $NumJoists"
    .central.s process $cmd23
    GiD_Process escape escape escape escape
    
    set NumBeamsMesh $NumBeamsBlocY 
    set NumJoistsMesh $NumJoistsBlocX  
    set cmd24 "Meshing Structured Surfaces $NumSurfaces escape $MeshBeams $NumBeamsMesh escape $MeshJoists $NumJoistsMesh"
    .central.s process $cmd24
    GiD_Process escape escape escape escape
    
    #MB01042016
    set cmd25 "Mescape Meshing MeshCriteria Mesh Lines 1:end escape"
    GiD_Process {*}$cmd25
    #MB01042016
    
    GidUtils::EnableGraphics
    GidUtils::EndWaitState .gid
    GiD_Process rotate angle 45 45 
    GiD_Process 'Zoom Frame
    
    #MB24032016
    GiD_Process Mescape Meshing Generate $MeshSize escape
    #MB24032016
}

proc AfterMeshGeneration { fail } {
    if { !$fail } {
        SAFIR::TransferRelaxation
		SAFIR::TransferTrapLoad 0
		SAFIR::TransferTrapLoad 1
    }
    return ""
}

namespace eval SAFIR {
}
 
 #Calculate and transfer trapezoidal load from the line entities to the beam elements
  proc SAFIR::TransferTrapLoad { globalLocalCase } {
  set tolerance 1e-15
  if  {$globalLocalCase == 0} {
   set condition_name TrapLoadGlobal
  }  else {
   set condition_name TrapLoadLocal
  }
  foreach item [GiD_Info Conditions $condition_name mesh] {
	  set element_id [lindex $item 1] ;#element id is the first field
      set line_id [lindex $item end] ;#extra FUNC#(NumEntity) field added as last question
	  
	   #set coords for the nodes for the line entities
     set xyz_line_t(0) [GiD_Info Parametric line $line_id coord 0.0]
     set xyz_line_t(1) [GiD_Info Parametric line $line_id coord 1.0]
     
	 #assign nodes to variables
     lassign [lrange [GiD_Mesh get element $element_id] 3 4] node_0 node_1 
	  
	 #set coords for the nodes for the mesh elements
     set xyz_node(0) [lrange $[GiD_Mesh get node $node_0] 1 end]
     set xyz_node(1) [lrange $[GiD_Mesh get node $node_1] 1 end]
	 
	 #set trapezoidal load values
	 set pAx [lindex [lindex [GiD_Info conditions $condition_name geometry $line_id] 0] 3]
	 set pAy [lindex [lindex [GiD_Info conditions $condition_name geometry $line_id] 0] 4]
	 set pAz [lindex [lindex [GiD_Info conditions $condition_name geometry $line_id] 0] 5]
	 set pBx [lindex [lindex [GiD_Info conditions $condition_name geometry $line_id] 0] 6]
	 set pBy [lindex [lindex [GiD_Info conditions $condition_name geometry $line_id] 0] 7]
	 set pBz [lindex [lindex [GiD_Info conditions $condition_name geometry $line_id] 0] 8]
	 
	 set func [lindex [lindex [GiD_Info conditions $condition_name geometry $line_id] 0] 9]
	 set function [lindex [lindex [GiD_Info conditions $condition_name geometry $line_id] 0] 10]
	  
	 #set total distance of the line entity and distances to the two nodes of the element
	 set dtot [MathUtils::VectorDistance $xyz_line_t(0) $xyz_line_t(1)]
	 set d0 [MathUtils::VectorDistance $xyz_line_t(0) $xyz_node(0)]
	 set d1 [MathUtils::VectorDistance $xyz_line_t(0) $xyz_node(1)]
	
	 #calculate loads for each node of the element
	 set pAxNew [expr double( round(100 * ( $pAx + ( $pBx - $pAx ) * $d0 / $dtot)) )/ 100 ]
	 set pAyNew [expr double( round(100 * ( $pAy + ( $pBy - $pAy ) * $d0 / $dtot)) )/ 100 ]
	 set pAzNew [expr double( round(100 * ( $pAz + ( $pBz - $pAz ) * $d0 / $dtot)) )/ 100 ]
	 set pBxNew [expr double( round(100 * ( $pAx + ( $pBx - $pAx ) * $d1 / $dtot)) )/ 100 ]
	 set pByNew [expr double( round(100 * ( $pAy + ( $pBy - $pAy ) * $d1 / $dtot)) )/ 100 ]
	 set pBzNew [expr double( round(100 * ( $pAz + ( $pBz - $pAz ) * $d1 / $dtot)) )/ 100 ]
	 
	 #write conditions in the element
	 set vals [concat $pAxNew $pAyNew $pAzNew $pBxNew $pByNew $pBzNew $func $function $line_id]
	 GiD_AssignData condition $condition_name body_elements $vals $element_id
	  }
  }
 
 
proc SAFIR::TransferRelaxation { } {
  set tolerance 1e-15
  set condition_name Relax_Beam_DOF
  set elements_to_remove [list]	
  foreach item [GiD_Info Conditions $condition_name mesh] {
      set element_node0 [list]
	  set element_node1 [list]
	  set element_id [lindex $item 1] ;#element id is the first field
      set line_id [lindex $item end] ;#extra FUNC#(NumEntity) field added as last question
	 
	 #set coords for the nodes for the line entities
     set xyz_line_t(0) [GiD_Info Parametric line $line_id coord 0.0]
     set xyz_line_t(1) [GiD_Info Parametric line $line_id coord 1.0]
     
	 #assign nodes to variables
     lassign [lrange [GiD_Mesh get element $element_id] 3 4] node_0 node_1 
	  
	 #set coords for the nodes for the mesh elements
     set xyz_node(0) [lrange $[GiD_Mesh get node $node_0] 1 end]
     set xyz_node(1) [lrange $[GiD_Mesh get node $node_1] 1 end]
     
	 #find ‘by distance with tolerance’ if element nodes match the end points of the line entities
	 foreach i {0 1} {   
		set is_end($i) 0
		set d2 [MathUtils::VectorDistance2 $xyz_line_t($i) $xyz_node($i)]
			if {  $d2 < $tolerance } {
				set is_end($i) 1
			    #break
			}
	 }
	 
	 #remove condition from the elements that are not at the ends
     if { !$is_end(0) && !$is_end(1)   } {
         lappend elements_to_remove $element_id
     } else {
	 
		 #list with the question values
		 set LineCond [lrange [lindex [GiD_Info conditions $condition_name geometry $line_id] 0] 3 end]
		 
		 #if it is first end, remove the conditions regarding the second end node
		 if { $is_end(0) && !$is_end(1)   } {
		   lappend element_node0 $element_id
		   set valsNode0 [concat [lrange $LineCond 0 6] {-1 -1 -1 -1 -1 -1 -1} $line_id]
		   GiD_AssignData condition $condition_name body_elements $valsNode0 $element_node0
		 }
		 
		 #if it is second end, remove the conditions regarding the first end node
		if { !$is_end(0) && $is_end(1)  } {
		   lappend element_node1 $element_id
		   set valsNode1 [concat {-1 -1 -1 -1 -1 -1 -1} [lrange $LineCond 7 13] $line_id]
		   GiD_AssignData condition $condition_name body_elements $valsNode1 $element_node1
		 }
		 
		 #if it both ends (only one element assigned to that line) do nothing
		 
		 
		 #if it doesn't have any dofs released, remove it
		 set dofsNotReleased {-1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1}
		 set elemCond [lrange [lindex [GiD_Info conditions $condition_name mesh $element_id] 0] 3 16 ]
		 set hasNotDofsReleased [ lequal $elemCond $dofsNotReleased ]
		 if {$hasNotDofsReleased} {lappend elements_to_remove $element_id }
	 }
  }  
  
  #remove condition from the elements that are not at the ends
  GiD_UnAssignData condition $condition_name body_elements $elements_to_remove
}

proc lequal {l1 l2} {
    foreach elem $l1 {
        if {$elem ni $l2} {return false}
    }
    foreach elem $l2 {
        if {$elem ni $l1} {return false}
    }
    return true
}