#comet.tcl  -*- TCL -*-
#---------------------------------------------------------------------------
#This file is written in TCL lenguage 
#For more information about TCL look at: http://www.sunlabs.com/research/tcl/
#
#At least two procs must be in this file:
#
#    InitGIDProject dir - Will be called whenever a project is begun to be used.
#           where dir is the project's directory
#    EndGIDProject - Will be called whenever a project ends to be used.
#
#For more information about GID internals, check the program scripts.
#---------------------------------------------------------------------------

############ GiD-raised events (its prototype is fixed by GiD) ###########

proc InitGIDProject { dir } {
    global ProblemTypePath
    set ProblemTypePath $dir    
    
	global problemtype_local
	array set problemtype_local [ReadProblemtypeXml [file join $dir Safir_Thermal_2d.xml] Infoproblemtype {Name Version MinimumGiDVersion SuggestedGiDVersion Description}]
	
    Safir_ChangeMenus
}

#proc EndGIDProject {} {
#}

############ problemtype procedures ###########


proc Safir_ChangeMenus { } {    
    GiDMenu::Create Cross-Section PRE
    set pos 0
    foreach text {I-Profile ACB-Profile ACB-Profile-non-symetric SFB-Profile IFB-Profile CoSFB-Profile} command {Iprofile Acbprofile Acbprofilenonsym Sfbprofile Ifbprofile Cfbprofile} {
        GiDMenu::InsertOption Cross-Section $text $pos PRE $command 
        incr pos
    }      
            
    foreach text {Interval "Local axes"} {
        #RemoveMenuOption Data $text PRE 
        #Data is an special menu changed at runtime, by now must use tricky functions like GidChangeDataLabel instead of RemoveMenuOption as expecte!!
        GidChangeDataLabel $text ""
    }    
	
	#add About Problem Types menu
	GiDMenu::Create "About Problem Type" PRE
	
	# set pos 0
    # foreach text {"Safir_Thermal_2D" } command {AboutThermal2D} {
        # GiDMenu::InsertOption "About Problem Type" $text $pos PRE $command 
        # incr pos
    # }   
	
	GiDMenu::InsertOption "About Problem Type" "Safir_Thermal_2D" 0 PRE AboutThermal2D 
	
	#udpate the menus
    GiDMenu::UpdateMenus
}

proc AboutThermal2D { } {
	global problemtype_local
	
	#set name of the windoe in GiD
	set w .gid.aboutMe
	
	InitWindow $w "About Safir_Thermal_2D" AboutMeWindow

	frame $w.frmAboutMe
	
	 label $w.frmAboutMe.name -text "Name"
	 entry $w.frmAboutMe.nameVal -relief sunken -width 80 -textvariable problemtype_local(Name) -state readonly
	 label $w.frmAboutMe.version -text "Version"
	 entry $w.frmAboutMe.versionVal -relief sunken -width 80 -textvariable problemtype_local(Version) -state readonly
	 label $w.frmAboutMe.minimumGiDversion -text "Minimum GiD version"
	 entry $w.frmAboutMe.minimumGiDversionVal -relief sunken -width 80 -textvariable  problemtype_local(MinimumGiDVersion) -state readonly
	 label $w.frmAboutMe.suggestedGiDversion -text "Suggested GiD version"
	 entry $w.frmAboutMe.suggestedGiDversionVal -relief sunken -width 80 -textvariable  problemtype_local(SuggestedGiDVersion) -state readonly
	 label $w.frmAboutMe.description -text "Description"
	 entry $w.frmAboutMe.descriptionVal -relief sunken -width 80 -textvariable problemtype_local(Description) -state readonly

	grid $w.frmAboutMe  -padx 5 -pady 5 -sticky ew 

    grid $w.frmAboutMe.name $w.frmAboutMe.nameVal -sticky e
	grid $w.frmAboutMe.description $w.frmAboutMe.descriptionVal -sticky e
	grid $w.frmAboutMe.version $w.frmAboutMe.versionVal -sticky e
	grid $w.frmAboutMe.minimumGiDversion $w.frmAboutMe.minimumGiDversionVal -sticky e
	grid $w.frmAboutMe.suggestedGiDversion $w.frmAboutMe.suggestedGiDversionVal -sticky e
	
	focus $w.frmAboutMe
	}

proc Iprofile { } {

    global ParamsIprof 

    global ProfNam
    global ProfTyp
 
    set w .gid.iprofil

    set ParamsIprof(h) ""
    set ParamsIprof(b) ""
    set ParamsIprof(ts) ""
    set ParamsIprof(tg) "" 
    set ParamsIprof(r) ""
    set ParamsIprof(drawFillet) 0         
    set ParamsIprof(drawSlab) 0         
    set ParamsIprof(slabW) ""
    set ParamsIprof(slabH) ""

    InitWindow $w "Create I - Profile" ParametricWindowGeom   
 
    frame $w.frmProfType 

    label $w.frmProfType.lType -text "Type"

    set ProfTyp "HE"

    ComboBox $w.frmProfType.listOfType -editable 0 -width 15 -textvariable ProfTyp \
      -values { "IPE" "HE" "HL" "HD" "HP" "W" "USER" } \
      -modifycmd { updateProfList  $ProfTyp }

    label $w.frmProfType.lProf -text "Profile"
    label $w.frmProfType.eProf -relief sunken -width 20 -textvariable ProfNam -font FixedFont
    listbox $w.frmProfType.listOfProf -width 20 -relief raised -borderwidth 2 -selectmode single \
          -yscrollcommand " $w.frmProfType.scrollProfList set " -font FixedFont

    scrollbar $w.frmProfType.scrollProfList -command "$w.frmProfType.listOfProf yview"

    frame $w.frmEquations
 
    label $w.frmEquations.lh -text "Height(h)"
    label $w.frmEquations.lhu -text "mm"
    entry $w.frmEquations.eh -relief sunken -width 10 -textvariable ParamsIprof(h)
    label $w.frmEquations.lb -text "Width(b)"
    label $w.frmEquations.lbu -text "mm"
    entry $w.frmEquations.eb -relief sunken -width 10 -textvariable ParamsIprof(b)
    label $w.frmEquations.lts -text "Web(tw)"
    label $w.frmEquations.ltsu -text "mm"
    entry $w.frmEquations.ets -relief sunken -width 10 -textvariable ParamsIprof(ts)
    label $w.frmEquations.ltg -text "Flange(tf)"
    label $w.frmEquations.ltgu -text "mm"
    entry $w.frmEquations.etg -relief sunken -width 10 -textvariable ParamsIprof(tg)
    label $w.frmEquations.lr -text "Radius(r)"
    label $w.frmEquations.lru -text "mm"
    entry $w.frmEquations.er -relief sunken -width 10 -textvariable ParamsIprof(r)

    label $w.frmEquations.lexactShape -text "exact shape"
    checkbutton $w.frmEquations.exactShape -variable ParamsIprof(drawFillet)

    label $w.frmEquations.lConcreteSlab -text "Concrete Slab"
    checkbutton $w.frmEquations.concreteSlab -variable ParamsIprof(drawSlab) -command {
          set w .gid.iprofil
         if { $ParamsIprof(drawSlab) == 1} {
            $w.frmEquations.eSlabWidth configure -state normal
            $w.frmEquations.eSlabHight configure -state normal  
         } else {
            $w.frmEquations.eSlabWidth configure -state disabled
            $w.frmEquations.eSlabHight configure -state disabled 
            set ParamsIprof(slabW)  ""
            set ParamsIprof(slabH)  ""
         }
    }
    label $w.frmEquations.lSlabWidth -text "Slab Width"
    label $w.frmEquations.lSlabWidthu -text "mm"
    entry $w.frmEquations.eSlabWidth -relief sunken -width 10 -textvariable ParamsIprof(slabW) -state disabled
    label $w.frmEquations.lSlabHight -text "Slab Height"
    label $w.frmEquations.lSlabHightu -text "mm"
    entry $w.frmEquations.eSlabHight -relief sunken -width 10 -textvariable ParamsIprof(slabH) -state disabled

    set def_back [$w cget -background]
    frame $w.frmButtons -bg [CCColorActivo $def_back]
    button $w.frmButtons.btnApply -text "Apply" \
            -command "DrawIprofile $w" \
            -underline 0 -width 6
    button $w.frmButtons.btnclose -text "Close" \
            -command "destroy $w" \
            -underline 0 -width 6

    grid $w.frmProfType  -padx 5 -pady 5 -sticky ew 

    grid $w.frmProfType.lType $w.frmProfType.listOfType -sticky e
    grid $w.frmProfType.lProf $w.frmProfType.eProf -sticky e
    grid $w.frmProfType.scrollProfList $w.frmProfType.listOfProf -sticky ens
  
    grid $w.frmEquations -padx 5 -pady 5 -sticky ew    
    grid $w.frmEquations.lh $w.frmEquations.eh $w.frmEquations.lhu -sticky e
    grid $w.frmEquations.lb $w.frmEquations.eb $w.frmEquations.lbu -sticky e
    grid $w.frmEquations.lts $w.frmEquations.ets $w.frmEquations.ltsu -sticky e
    grid $w.frmEquations.ltg $w.frmEquations.etg $w.frmEquations.ltgu -sticky e
    grid $w.frmEquations.lr $w.frmEquations.er $w.frmEquations.lru -sticky e
    grid $w.frmEquations.lexactShape $w.frmEquations.exactShape -sticky e
    grid $w.frmEquations.lConcreteSlab $w.frmEquations.concreteSlab -sticky e
    grid $w.frmEquations.lSlabWidth $w.frmEquations.eSlabWidth $w.frmEquations.lSlabWidthu -sticky e
    grid $w.frmEquations.lSlabHight $w.frmEquations.eSlabHight $w.frmEquations.lSlabHightu -sticky e
 
    grid $w.frmButtons -sticky ews -columnspan 7
    grid $w.frmButtons.btnApply $w.frmButtons.btnclose -padx 5 -pady 6

    grid columnconf $w "0" -weight 1
    grid rowconfigure $w "3" -weight 1
    
    focus $w.frmButtons.btnApply
    
    bind $w <Alt-c> "tkButtonInvoke $w.frmButtons.btnclose"
    bind $w <Escape> "tkButtonInvoke $w.frmButtons.btnclose"

    bind $w.frmProfType.listOfProf <<ListboxSelect>> { updateProf [selection get] }

    set ProfNam  ""
    set ParamsIprof(slabW) ""
    set ParamsIprof(slabH) ""

    updateProfList  "HE"

    #wm minsize $w 140 175
}


proc updateProf { selectedProf } {

   global ProfNam
   global ParamsIprof 

   set w .gid.iprofil

   set ProfNam [string range $selectedProf 0 20]

   set profData [string range $selectedProf 21 end]
   scan $profData "%s %s %s %s %s" w1 w2 w3 w4 w5

   set ParamsIprof(h) $w1
   set ParamsIprof(b) $w2
   set ParamsIprof(ts) $w3
   set ParamsIprof(tg) $w4
   set ParamsIprof(r) $w5

}

proc updateProfList  { type } {

       variable path
       global ProblemTypePath

       global ProfNam
       global ProfTyp
       global ParamsIprof 

       set w .gid.iprofil

       $w.frmProfType.listOfProf delete 0 end

       set ProfNam  ""
       set ParamsIprof(h) ""
       set ParamsIprof(b) ""
       set ParamsIprof(ts) ""
       set ParamsIprof(tg) "" 
       set ParamsIprof(r) ""

       if { $type == "USER" } {

            $w.frmEquations.eh configure -state normal
            $w.frmEquations.eb configure -state normal
            $w.frmEquations.ets configure -state normal
            $w.frmEquations.etg configure -state normal
            $w.frmEquations.er configure -state normal

             return
       }

       $w.frmEquations.eh configure -state disabled
       $w.frmEquations.eb configure -state disabled
       $w.frmEquations.ets configure -state disabled
       $w.frmEquations.etg configure -state disabled
       $w.frmEquations.er configure -state disabled

       #set wdir "c:\\Programme\\GiD\\Gid 8.0.9\\problemtypes\\SAFIR2007_test\\Safir_Thermal_2d.gid"
       set wdir $ProblemTypePath

       set f [open $wdir\\prof.txt ]

       set listProf { }
       while { [ gets $f line ] >= 0 } {
           scan $line "%s" kw0
           if { $kw0 == $type} {
                  set profNam [string range $line 0 20]
              $w.frmProfType.listOfProf insert end $line
           }
       }

       close $f
}
 
proc DrawIprofile { w } {

    global ParamsIprof

    set scal 0.001
    set h [expr $ParamsIprof(h) * $scal]
    set b [expr $ParamsIprof(b) * $scal]
    set ts [expr $ParamsIprof(ts) * $scal]
    set tg [expr $ParamsIprof(tg) * $scal]
        

    set exactS $ParamsIprof(drawFillet)
    set drawS $ParamsIprof(drawSlab)

    #set slabW [expr $ParamsIprof(slabW) * $scal]
    #set slabH [expr $ParamsIprof(slabH) * $scal]

    if { $exactS == 1 } {
            set r [expr $ParamsIprof(r) * $scal]
    } else {
            set r [ expr $ParamsIprof(r)*0.665*$scal ] 
    }

    set x0 0.0
    set y0 0.0

    set hh [expr $h*0.5]
    set bh [expr $b*0.5]
    set tsh [expr $ts*0.5]
    set dc [expr sqrt([expr $r*$r*0.5])]

    set x1 [expr $x0 - $bh]
    set y1 [expr $y0 - $hh]

    set x2 [expr $x0 + $bh]
    set y2 [expr $y0 - $hh]

    set x3 [expr $x2]
    set y3 [expr $y2 + $tg]

    set x4 [expr $x0 + $tsh + $r]
    set y4 [expr $y3]

    set x5 [expr $x0 + $tsh]
    set y5 [expr $y4 + $r]  

    set c1x [expr $x4 - $dc]
    set c1y [expr $y5 - $dc]

    set x6 [expr $x5]
    set y6 [expr $y0 + $hh - $tg - $r]

    set x7 [expr $x5 + $r]
    set y7 [expr $y6 + $r]

    set c2x [expr $x7 - $dc]
    set c2y [expr $y6 + $dc]

    set x8 [expr $x0 + $bh]
    set y8 [expr $y0 + $hh - $tg]

    set x9 [expr $x8]
    set y9 [expr $y0 + $hh]

    set x10 [expr $x0 - $x9]
    set y10 [expr $y9]

    set x11 [expr $x0 - $x8]
    set y11 [expr $y8]

    set x12 [expr $x0 - $x7]
    set y12 [expr $y7]

    set x13 [expr $x0 - $x6]
    set y13 [expr $y6]
 
    set c3x [expr $x0 - $c2x]
    set c3y [expr $c2y]

    set x14 [expr $x0 - $x5]
    set y14 [expr $y5]

    set x15 [expr $x0 - $x4]
    set y15 [expr $y4]

    set c4x [expr $x0 - $c1x]
    set c4y [expr $c1y]

    set x16 [expr $x0 - $x3]
    set y16 [expr $y3]
	
	#----------create point for blocking one node in torsional analysis---------
	
	set tors1x [expr $x0]
    set tors1y [expr $y0 - $hh]
	set tors2x [expr $x0]
    set tors2y [expr $y0 - $hh + $tg ]
	set tors3x [expr $x0]
    set tors3y [expr $y0 + $hh - $tg ]
	set tors4x [expr $x0]
    set tors4y [expr $y0 + $hh]
	
	#---------/tors---------
    set oldvalue [GiD_Info variables CreateAlwaysNewPoint]
    GiD_Process escape escape escape Utilities Variables CreateAlwaysNewPoint  1

    GiD_Process escape escape escape escape
    GiD_Process geometry create line \
    $x1,$y1,0.0 \
	$tors1x,$tors1y,0.0 \
    $x2,$y2,0.0 \
    $x3,$y3,0.0 \
    $x4,$y4,0.0 \
    escape escape escape escape

    if { $exactS == 1 } {
            .central.s process geometry create arc \
            $x4,$y4,0.0 \
            $c1x,$c1y,0.0 \
            $x5,$y5,0.0 \
            escape escape escape escape
    } else {
       GiD_Process geometry create line \
        $x4,$y4,0.0 \
        $x5,$y5,0.0 \
        escape escape escape escape
    }

   GiD_Process geometry create line \
    $x5,$y5,0.0 \
    $x6,$y6,0.0 \
    escape escape escape escape

    if { $exactS == 1 } {
       GiD_Process geometry create arc \
        $x6,$y6,0.0 \
        $c2x,$c2y,0.0 \
        $x7,$y7,0.0 \
        escape escape escape escape
    } else {
       GiD_Process geometry create line \
        $x6,$y6,0.0 \
        $x7,$y7,0.0 \
        escape escape escape escape
    }

    GiD_Process geometry create line \
    $x7,$y7,0.0 \
    $x8,$y8,0.0 \
    $x9,$y9,0.0 \
	$tors4x,$tors4y,0.0 \
    $x10,$y10,0.0 \
    $x11,$y11,0.0 \
    $x12,$y12,0.0 \
    escape escape escape escape

    if { $exactS == 1 } {
        GiD_Process geometry create arc \
         $x12,$y12,0.0 \
         $c3x,$c3y,0.0 \
         $x13,$y13,0.0 \
         escape escape escape escape
    } else {
       GiD_Process geometry create line \
        $x12,$y12,0.0 \
        $x13,$y13,0.0 \
        escape escape escape escape
    }

   GiD_Process geometry create line \
    $x13,$y13,0.0 \
    $x14,$y14,0.0 \
    escape escape escape escape

    if { $exactS == 1 } {
        GiD_Process geometry create arc \
        $x14,$y14,0.0 \
        $c4x,$c4y,0.0 \
        $x15,$y15,0.0 \
        escape escape escape escape
    } else {
       GiD_Process geometry create line \
        $x14,$y14,0.0 \
        $x15,$y15,0.0 \
        escape escape escape escape
    }

   GiD_Process geometry create line \
    $x15,$y15,0.0 \
    $x16,$y16,0.0 \
    $x1,$y1,0.0 \
    escape escape escape escape


	   #---------torsion------------
	#add lines to have point at axis of symmetry
	GiD_Process geometry create line \
	$x15,$y15,0.0 \
	$tors2x,$tors2y,0.0 \
	$x4,$y4,0.0 \
    escape escape escape escape
	
	GiD_Process geometry create line \
	$tors2x,$tors2y,0.0 \
	$tors1x,$tors1y,0.0 \
    escape escape escape escape
	   
	GiD_Process geometry create line \
	$x12,$y12,0.0 \
	$tors3x,$tors3y,0.0 \
	$x7,$y7,0.0 \
    escape escape escape escape
	
	GiD_Process geometry create line \
	$tors3x,$tors3y,0.0 \
	$tors4x,$tors4y,0.0 \
    escape escape escape escape
	
	#add torsion constraint
	GiD_Process Data Conditions AssignCond Point_Torsion_Constraint Change 1 34\
	Mescape 
	
	#GiD_Process Mescape Geometry Delete Lines 19
	#GiD_Process escape escape escape
	
	#GiD_Process Mescape Utilities Renumber
	#GiD_Process escape escape escape
	
	#GiD_Process Mescape Geometry Delete Points 18
	#GiD_Process escape escape escape
	 #--------/torsion------------
	
	
    if { $drawS == 1 } {

       set sW [expr $ParamsIprof(slabW) * $scal]
       set sH [expr $ParamsIprof(slabH) * $scal] 

       set dsx [ expr $sW*0.5 - $b*0.5 ]

       set sl1x [ expr $x9 + $dsx ]
       set sl1y $y9

       set sl2x $sl1x
       set sl2y [ expr $sl1y + $sH ]

       set sl3x [ expr $x10 - $dsx ]
       set sl3y [ expr $y10 + $sH ]

       set sl4x $sl3x
       set sl4y [ expr $sl3y - $sH ]

       GiD_Process geometry create line \
        $x9,$y9,0.0 \
        $sl1x,$sl1y,0.0 \
        $sl2x,$sl2y,0.0 \
        $sl3x,$sl3y,0.0 \
        $sl4x,$sl4y,0.0 \
        $x10,$y10,0.0 \
            escape escape escape escape
    }

    GiD_Process escape
    GiD_Process escape escape escape Utilities Variables \
                 CreateAlwaysNewPoint $oldvalue
    GiD_Process escape escape escape
 
    GiD_Process Utilities Collapse Points 1:
    GiD_Process escape escape escape
	
 

    GiD_Process zoom frame escape escape escape escape

	#draw surfaces
    if { $exactS == 0 } {

       GiD_Process Geometry Create NurbsSurface 2 3 4 20 21\
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 1 21 19 17 18 \
       escape escape escape escape

	   GiD_Process Geometry Create NurbsSurface 19 20 5 6 7 23 22 14 15 16 \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 23 8 9 10 24  \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 13 22 24 11 12 \
       escape escape escape escape
	   
	   #GID_Process Meshing Structured Lines [number_of_finite_elements] [line1] [line2] [...]
	   
       GiD_Process Meshing Structured Lines 6 1 2 10 11 escape 5 4 8 13 17 escape 2 5 7 14 16 escape  \
       escape escape escape escape
       
     if { $drawS == 1 } {
     
       GiD_Process Geometry Create NurbsSurface 11 10 25 26 27 28 29 \
       escape escape escape escape

	   #GiD_Process Meshing ElemType Triangle 1 2 3 4 5 Escape \
       escape escape escape escape
	   
       GiD_Process Meshing ElemType Quadrilateral 6 Escape \
       escape escape escape escape

       GiD_Process Meshing Structured Surfaces 6 escape 12 29 escape 6 11  escape 6 10 escape 12 25 escape \
       5 26 escape \
       escape escape escape escape
       }
       
   } else {
   
     if { $drawS == 1 } {

		#beam profile surfaces
		GiD_Process Geometry Create NurbsSurface 2 3 4 20 21\
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 1 21 19 17 18 \
       escape escape escape escape

	   GiD_Process Geometry Create NurbsSurface 19 20 31 23 22 33 \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 23 8 9 10 24  \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 13 22 24 11 12 \
       escape escape escape escape
	   
	   GiD_Process Meshing Structured Lines 6 1 2 10 11 escape 5 4 8 13 17 escape 2 5 7 14 16 escape  \
       escape escape escape escape
	   
	   
	   #slab surfaces
	   GiD_Process Geometry Create NurbsSurface 11 10 25 26 27 28 29  \
       escape escape escape escape
	   
       GiD_Process Meshing ElemType Quadrilateral 6 Escape \
       escape escape escape escape

       GiD_Process Meshing Structured Surfaces 6 escape 12 29 escape 6 11  escape 6 10 escape 12 25 escape \
       5 26 escape \
       escape escape escape escape
	   

    } else {
       #GiD_Process Geometry Create NurbsSurface 1 2 20 8 9 10 24 16 \
       escape escape escape escapex  
	   
	   
        GiD_Process Geometry Create NurbsSurface 2 3 4 20 21\
       escape escape escape escape

	    GiD_Process Geometry Create NurbsSurface 1 21 19 17 18 \
       escape escape escape escape

	   GiD_Process Geometry Create NurbsSurface 19 20 26 23 22 28 \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 23 8 9 10 24  \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 13 22 24 11 12 \
       escape escape escape escape

   }

    }

	
    destroy $w
}

proc Acbprofile { } {

    global Paramsacbprof 

    global ProfNamacb
    global ProfTyp
 
    set w .gid.acbprofil

    set Paramsacbprof(h) ""
    set Paramsacbprof(b) ""
    set Paramsacbprof(ts) ""
    set Paramsacbprof(tg) "" 
    set Paramsacbprof(r) ""
    set Paramsacbprof(drawFillet) 0         
    set Paramsacbprof(drawSlab) 0         
    set Paramsacbprof(slabW) ""
    set Paramsacbprof(slabH) ""
    set Paramsacbprof(open) 0
    set Paramsacbprof(ht) 0

    InitWindow $w "Create ACB - Profile" ParametricWindowGeom   
 
    frame $w.frmProfType 

    label $w.frmProfType.lType -text "Type"

    set ProfTyp "HE"

    ComboBox $w.frmProfType.listOfType -editable 0 -width 15 -textvariable ProfTyp \
      -values { "IPE" "HE" "HL" "HD" "HP" "W" "USER" } \
      -modifycmd { updateProfListacb  $ProfTyp }

    label $w.frmProfType.lProf -text "Profile"
    label $w.frmProfType.eProf -relief sunken -width 20 -textvariable ProfNamacb -font FixedFont
    listbox $w.frmProfType.listOfProf -width 20 -relief raised -borderwidth 2 -selectmode single \
          -yscrollcommand " $w.frmProfType.scrollProfList set " -font FixedFont

    scrollbar $w.frmProfType.scrollProfList -command "$w.frmProfType.listOfProf yview"

    frame $w.frmEquations
 
    label $w.frmEquations.acblh -text "Height(h)"
    label $w.frmEquations.acblhu -text "mm"
    entry $w.frmEquations.acbeh -relief sunken -width 10 -textvariable Paramsacbprof(h)
    label $w.frmEquations.acblb -text "Width(b)"
    label $w.frmEquations.acblbu -text "mm"
    entry $w.frmEquations.acbeb -relief sunken -width 10 -textvariable Paramsacbprof(b)
    label $w.frmEquations.acblts -text "Web(tw)"
    label $w.frmEquations.acbltsu -text "mm"
    entry $w.frmEquations.acbets -relief sunken -width 10 -textvariable Paramsacbprof(ts)
    label $w.frmEquations.acbltg -text "Flange(tf)"
    label $w.frmEquations.acbltgu -text "mm"
    entry $w.frmEquations.acbetg -relief sunken -width 10 -textvariable Paramsacbprof(tg)
    label $w.frmEquations.acblr -text "Radius(r)"
    label $w.frmEquations.acblru -text "mm"
    entry $w.frmEquations.acber -relief sunken -width 10 -textvariable Paramsacbprof(r)
    label $w.frmEquations.acblht -text "Total Height of one tee (ht) "
    label $w.frmEquations.acblhtu -text "mm"
    entry $w.frmEquations.acbeht -relief sunken -width 10 -textvariable Paramsacbprof(ht)
    label $w.frmEquations.acbopenr -text "Opening(a0)"
    label $w.frmEquations.acbopenru -text "mm"
    entry $w.frmEquations.acbopen -relief sunken -width 10 -textvariable Paramsacbprof(open)
    
     

    label $w.frmEquations.acblexactShape -text "exact shape"
    checkbutton $w.frmEquations.acbexactShape -variable Paramsacbprof(drawFillet)

    label $w.frmEquations.acblConcreteSlab -text "Concrete Slab"
    checkbutton $w.frmEquations.acbconcreteSlab -variable Paramsacbprof(drawSlab) -command {
          set w .gid.acbprofil
         if { $Paramsacbprof(drawSlab) == 1} {
            $w.frmEquations.acbeSlabWidth configure -state normal
            $w.frmEquations.acbeSlabHight configure -state normal  
         } else {
            $w.frmEquations.acbeSlabWidth configure -state disabled
            $w.frmEquations.acbeSlabHight configure -state disabled 
            set Paramsacbprof(slabW)  ""
            set Paramsacbprof(slabH)  ""
         }
    }
    label $w.frmEquations.acblSlabWidth -text "Slab Width"
    label $w.frmEquations.acblSlabWidthu -text "mm"
    entry $w.frmEquations.acbeSlabWidth -relief sunken -width 10 -textvariable Paramsacbprof(slabW) -state disabled
    label $w.frmEquations.acblSlabHight -text "Slab Height"
    label $w.frmEquations.acblSlabHightu -text "mm"
    entry $w.frmEquations.acbeSlabHight -relief sunken -width 10 -textvariable Paramsacbprof(slabH) -state disabled

    set def_back [$w cget -background]
    frame $w.frmButtonsacb -bg [CCColorActivo $def_back]
    button $w.frmButtonsacb.btnApply -text "Apply" \
            -command "Drawacbprofile $w" \
            -underline 0 -width 6
    button $w.frmButtonsacb.btnclose -text "Close" \
            -command "destroy $w" \
            -underline 0 -width 6

    grid $w.frmProfType  -padx 5 -pady 5 -sticky ew 

    grid $w.frmProfType.lType $w.frmProfType.listOfType -sticky e
    grid $w.frmProfType.lProf $w.frmProfType.eProf -sticky e
    grid $w.frmProfType.scrollProfList $w.frmProfType.listOfProf -sticky ens
  
    grid $w.frmEquations -padx 5 -pady 5 -sticky ew    
    grid $w.frmEquations.acblh $w.frmEquations.acbeh $w.frmEquations.acblhu -sticky e
    grid $w.frmEquations.acblb $w.frmEquations.acbeb $w.frmEquations.acblbu -sticky e
    grid $w.frmEquations.acblts $w.frmEquations.acbets $w.frmEquations.acbltsu -sticky e
    grid $w.frmEquations.acbltg $w.frmEquations.acbetg $w.frmEquations.acbltgu -sticky e
    grid $w.frmEquations.acblr $w.frmEquations.acber $w.frmEquations.acblru -sticky e
    grid $w.frmEquations.acblht $w.frmEquations.acbeht $w.frmEquations.acblhtu -sticky e
    grid $w.frmEquations.acbopenr $w.frmEquations.acbopen $w.frmEquations.acbopenru -sticky e
    grid $w.frmEquations.acblexactShape $w.frmEquations.acbexactShape -sticky e
    grid $w.frmEquations.acblConcreteSlab $w.frmEquations.acbconcreteSlab -sticky e
    grid $w.frmEquations.acblSlabWidth $w.frmEquations.acbeSlabWidth $w.frmEquations.acblSlabWidthu -sticky e
    grid $w.frmEquations.acblSlabHight $w.frmEquations.acbeSlabHight $w.frmEquations.acblSlabHightu -sticky e
 
    grid $w.frmButtonsacb -sticky ews -columnspan 7
    grid $w.frmButtonsacb.btnApply $w.frmButtonsacb.btnclose -padx 5 -pady 6

    grid columnconf $w "0" -weight 1
    grid rowconfigure $w "3" -weight 1
    
    focus $w.frmButtonsacb.btnApply
    
    bind $w <Alt-c> "tkButtonInvoke $w.frmButtonsacb.btnclose"
    bind $w <Escape> "tkButtonInvoke $w.frmButtonsacb.btnclose"

    bind $w.frmProfType.listOfProf <<ListboxSelect>> { updateProfacb [selection get] }

    set ProfNamacb  ""
    set Paramsacbprof(slabW) ""
    set Paramsacbprof(slabH) ""

    updateProfListacb  "HE"

    #wm minsize $w 140 175
}

proc updateProfacb { selectedProf } {

   global ProfNamacb
   global Paramsacbprof 

   set w .gid.acbprofil

   set ProfNamacb [string range $selectedProf 0 20]

   set profData [string range $selectedProf 21 end]
   scan $profData "%s %s %s %s %s" w1 w2 w3 w4 w5

   set Paramsacbprof(h) $w1
   set Paramsacbprof(b) $w2
   set Paramsacbprof(ts) $w3
   set Paramsacbprof(tg) $w4
   set Paramsacbprof(r) $w5

}

proc updateProfListacb  { type } {

       variable path
       global ProblemTypePath

       global ProfNamacb
       global ProfTyp
       global Paramsacbprof 

       set w .gid.acbprofil

       $w.frmProfType.listOfProf delete 0 end

       set ProfNamacb  ""
       set Paramsacbprof(h) ""
       set Paramsacbprof(b) ""
       set Paramsacbprof(ts) ""
       set Paramsacbprof(tg) "" 
       set Paramsacbprof(r) ""

       if { $type == "USER" } {

            $w.frmEquations.acbeh configure -state normal
            $w.frmEquations.acbeb configure -state normal
            $w.frmEquations.acbets configure -state normal
            $w.frmEquations.acbetg configure -state normal
            $w.frmEquations.acber configure -state normal
            $w.frmEquations.acbeht configure -state normal
            $w.frmEquations.acbopen configure -state normal

             return
       }

       $w.frmEquations.acbeh configure -state disabled
       $w.frmEquations.acbeb configure -state disabled
       $w.frmEquations.acbets configure -state disabled
       $w.frmEquations.acbetg configure -state disabled
       $w.frmEquations.acber configure -state disabled
       $w.frmEquations.acbeht configure -state normal
       $w.frmEquations.acbopen configure -state normal

       #set wdir "c:\\Programme\\GiD\\Gid 8.0.9\\problemtypes\\SAFIR2007_test\\Safir_Thermal_2d.gid"
       set wdir $ProblemTypePath

       set f [open $wdir\\prof.txt ]

       set listProf { }
       while { [ gets $f line ] >= 0 } {
           scan $line "%s" kw0
           if { $kw0 == $type} {
                  set profNamacb [string range $line 0 20]
              $w.frmProfType.listOfProf insert end $line
           }
       }

       close $f
}

proc Drawacbprofile { w } {

    global Paramsacbprof

    set scal 0.001
    set h [expr $Paramsacbprof(ht) * $scal]
    set b [expr $Paramsacbprof(b) * $scal]
    set ts [expr $Paramsacbprof(ts) * $scal]
    set tg [expr $Paramsacbprof(tg) * $scal]
        set hopen [expr $Paramsacbprof(open) * $scal]

    set exactS $Paramsacbprof(drawFillet)
    set drawS $Paramsacbprof(drawSlab)

    #set slabW [expr $Paramsacbprof(slabW) * $scal]
    #set slabH [expr $Paramsacbprof(slabH) * $scal]

    if { $exactS == 1 } {
            set r [expr $Paramsacbprof(r) * $scal]
    } else {
            set r [ expr $Paramsacbprof(r)*0.665*$scal ] 
    }

    set x0 0.0
    set y0 0.0
        
        set yopen [expr $hopen*0.5]

    set hh [expr $h ]
    set bh [expr $b*0.5]
    set tsh [expr $ts*0.5]
    set dc [expr sqrt([expr $r*$r*0.5])]

    set x1 [expr $x0 - $bh]
    set y1 [expr $y0 - $hh -$hopen*0.5]

    set x2 [expr $x0 + $bh]
    set y2 [expr $y0 - $hh -$hopen*0.5]

    set x3 [expr $x2]
    set y3 [expr $y2 + $tg]

    set x4 [expr $x0 + $tsh + $r]
    set y4 [expr $y3]

    set x5 [expr $x0 + $tsh]
    set y5 [expr $y4 + $r]  

    set c1x [expr $x4 - $dc]
    set c1y [expr $y5 - $dc]

    set x6 [expr $x5]
    set y6 [expr $y0 + $hh - $tg - $r + $hopen*0.5]

    set x7 [expr $x5 + $r]
    set y7 [expr $y6 + $r]

    set c2x [expr $x7 - $dc]
    set c2y [expr $y6 + $dc]

    set x8 [expr $x0 + $bh]
    set y8 [expr $y0 + $hh - $tg + $hopen*0.5]

    set x9 [expr $x8]
    set y9 [expr $y0 + $hh + $hopen*0.5]

    set x10 [expr $x0 - $x9]
    set y10 [expr $y9]

    set x11 [expr $x0 - $x8]
    set y11 [expr $y8]

    set x12 [expr $x0 - $x7]
    set y12 [expr $y7]

    set x13 [expr $x0 - $x6]
    set y13 [expr $y6]
 
    set c3x [expr $x0 - $c2x]
    set c3y [expr $c2y]

    set x14 [expr $x0 - $x5]
    set y14 [expr $y5]

    set x15 [expr $x0 - $x4]
    set y15 [expr $y4]

    set c4x [expr $x0 - $c1x]
    set c4y [expr $c1y]

    set x16 [expr $x0 - $x3]
    set y16 [expr $y3]
        
        set xopen1 [expr $x5]
        set yopen1 [expr $y0 - $yopen]
        
        set xopen2 [expr $xopen1 - $ts]
        set yopen2 [expr $yopen1]
        
        set xopen3 [expr $xopen1]
        set yopen3 [expr $yopen1 + $hopen]
        
        set xopen4 [expr $xopen2]
        set yopen4 [expr $yopen3]
        
		#----------tors---------
	
	set tors1x [expr $x0]
    set tors1y [expr $y0 - $hh - $yopen]
	set tors2x [expr $x0]
    set tors2y [expr $y0 - $hh + $tg - $yopen]
	set tors3x [expr $x0]
    set tors3y [expr $y0 + $hh - $tg + $yopen]
	set tors4x [expr $x0]
    set tors4y [expr $y0 + $hh + $yopen]
	
	#---------/tors---------
       

    set oldvalue [GiD_Info variables CreateAlwaysNewPoint]
    GiD_Process escape escape escape Utilities Variables CreateAlwaysNewPoint  1

    GiD_Process escape escape escape escape
    GiD_Process geometry create line \
    $x1,$y1,0.0 \
	$tors1x,$tors1y,0.0 \
    $x2,$y2,0.0 \
    $x3,$y3,0.0 \
    $x4,$y4,0.0 \
    escape escape escape escape

    if { $exactS == 1 } {
            .central.s process geometry create arc \
            $x4,$y4,0.0 \
            $c1x,$c1y,0.0 \
            $x5,$y5,0.0 \
            escape escape escape escape
    } else {
       GiD_Process geometry create line \
        $x4,$y4,0.0 \
        $x5,$y5,0.0 \
        escape escape escape escape
    }

   GiD_Process geometry create line \
    $x5,$y5,0.0 \
    $xopen1,$yopen1,0.0 \
        $xopen2,$yopen2,0.0 \
        $x14,$y14,0.0 \
    escape escape escape escape
        
        if { $exactS == 1 } {
        GiD_Process geometry create arc \
         $x14,$y14,0.0 \
         $c4x,$c4y,0.0 \
         $x15,$y15,0.0 \
         escape escape escape escape
    } else {
       GiD_Process geometry create line \
        $x14,$y14,0.0 \
        $x15,$y15,0.0 \
        escape escape escape escape
    }
        
        GiD_Process geometry create line \
    $x15,$y15,0.0 \
    $x16,$y16,0.0 \
        $x1,$y1,0.0 \
    escape escape escape escape

    GiD_Process geometry create line \
    $x7,$y7,0.0 \
    $x8,$y8,0.0 \
    $x9,$y9,0.0 \
	$tors4x,$tors4y,0.0 \
    $x10,$y10,0.0 \
    $x11,$y11,0.0 \
    $x12,$y12,0.0 \
    escape escape escape escape

    if { $exactS == 1 } {
        GiD_Process geometry create arc \
        $x12,$y12,0.0 \
        $c3x,$c3y,0.0 \
        $x13,$y13,0.0 \
        escape escape escape escape
    } else {
       GiD_Process geometry create line \
        $x12,$y12,0.0 \
        $x13,$y13,0.0 \
        escape escape escape escape
    }

   GiD_Process geometry create line \
    $x13,$y13,0.0 \
    $xopen4,$yopen4,0.0 \
    $xopen3,$yopen3,0.0 \
        $x6,$y6,0.0 \
    escape escape escape escape
	
	
    if { $exactS == 1 } {
         GiD_Process geometry create arc \
         $x6,$y6,0.0 \
         $c2x,$c2y,0.0 \
         $x7,$y7,0.0 \
     escape escape escape escape
    } else {
       GiD_Process geometry create line \
        $x6,$y6,0.0 \
        $x7,$y7,0.0 \
        escape escape escape escape
    }

	#---------torsion------------
	GiD_Process geometry create line \
	$x15,$y15,0.0 \
	$tors2x,$tors2y,0.0 \
	$x4,$y4,0.0 \
    escape escape escape escape
	
	GiD_Process geometry create line \
	$tors2x,$tors2y,0.0 \
	$tors1x,$tors1y,0.0 \
    escape escape escape escape
	   
	GiD_Process geometry create line \
	$x12,$y12,0.0 \
	$tors3x,$tors3y,0.0 \
	$x7,$y7,0.0 \
    escape escape escape escape
	
	GiD_Process geometry create line \
	$tors3x,$tors3y,0.0 \
	$tors4x,$tors4y,0.0 \
    escape escape escape escape
	#---------torsion------------
	
	#add torsion constraint
	GiD_Process Data Conditions AssignCond Point_Torsion_Constraint Change 1 38 \
	Mescape 
	
    if { $drawS == 1 } {

       set sW [expr $Paramsacbprof(slabW) * $scal]
       set sH [expr $Paramsacbprof(slabH) * $scal] 

       set dsx [ expr $sW*0.5 - $b*0.5 ]

       set sl1x [ expr $x9 + $dsx ]
       set sl1y $y9

       set sl2x $sl1x
       set sl2y [ expr $sl1y + $sH ]

       set sl3x [ expr $x10 - $dsx ]
       set sl3y [ expr $y10 + $sH ]

       set sl4x $sl3x
       set sl4y [ expr $sl3y - $sH ]

       GiD_Process geometry create line \
        $x9,$y9,0.0 \
        $sl1x,$sl1y,0.0 \
        $sl2x,$sl2y,0.0 \
        $sl3x,$sl3y,0.0 \
        $sl4x,$sl4y,0.0 \
        $x10,$y10,0.0 \
            escape escape escape escape
    }


    GiD_Process escape
    GiD_Process escape escape escape Utilities Variables \
                 CreateAlwaysNewPoint $oldvalue
    GiD_Process escape escape escape
 
    GiD_Process Utilities Collapse Points 1:
    GiD_Process escape escape escape

    GiD_Process zoom frame escape escape escape escape

    if { $exactS == 0 } {

	   GiD_Process Geometry Create NurbsSurface 2 3 4 24 25\
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 1 25 23 10 11 \
       escape escape escape escape

	   GiD_Process Geometry Create NurbsSurface 23 24 5 6 7 8 9 \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 20 21 22 27 26 18 19\
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 27 12 13 14 28 \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 17 26 28 15 16 \
       escape escape escape escape
	   
	   #GID_Process Meshing Structured Lines [number_of_finite_elements] [line1] [line2] [...]
	   
       GiD_Process Meshing Structured Lines 6 1 2 14 15 escape 5 4 12 17 10 escape  \
       escape escape escape escape
	   
	   
	   
     if { $drawS == 1 } {
     
       GiD_Process Geometry Create NurbsSurface 33 15 14 29 30 31 32\
       escape escape escape escape

       GiD_Process Meshing ElemType Quadrilateral 7 Escape \
       escape escape escape escape

       GiD_Process Meshing Structured Surfaces 7 escape 12 33 escape 6 15  escape 6 14 escape 12 29 escape \
       5 30 escape \
       escape escape escape escape
       }
       
   } else {
   
     if { $drawS == 1 } {
	   
	   #beam surfaces
		 GiD_Process Geometry Create NurbsSurface 2 3 4 24 25\
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 1 25 23 10 11 \
       escape escape escape escape

	   GiD_Process Geometry Create NurbsSurface 23 24 34 7 35 \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 20 37 27 26 36 \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 27 12 13 14 28  \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 17 26 28 15 16 \
       escape escape escape escape
	   
	   
	   GiD_Process Meshing Structured Lines 6 1 2 14 15 escape 5 4 12 17 10 escape  \
       escape escape escape escape
	   
	     #slab surface
		 	   GiD_Process Geometry Create NurbsSurface 33 15 14 29 30 31 32  \
       escape escape escape escape
	   
       GiD_Process Meshing ElemType Quadrilateral 7 Escape \
       escape escape escape escape

       GiD_Process Meshing Structured Surfaces 7 escape 12 33 escape 6 15  escape 6 14 escape 12 29 escape \
       5 30 escape \
       escape escape escape escape
	 

    } else {
	
     GiD_Process Geometry Create NurbsSurface 2 3 4 24 25\
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 1 25 23 10 11 \
       escape escape escape escape

	   GiD_Process Geometry Create NurbsSurface 23 24 29 7 30 \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 20 32 27 26 31 \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 27 12 13 14 28  \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 17 26 28 15 16 \
       escape escape escape escape
	   
	     GiD_Process Meshing Structured Lines 6 1 2 14 15 escape 5 4 12 17 10 escape  \
       escape escape escape escape


   }

    }

    destroy $w
}


 proc Acbprofilenonsym { } {

    global Paramsacbnonsymnonsymprof 

    global ProfNamacbnonsym
    global ProfTyp
 
    set w .gid.acbnonsymprofil

    set Paramsacbnonsymprof(ht) ""
    set Paramsacbnonsymprof(bt) ""
    set Paramsacbnonsymprof(tst) ""
    set Paramsacbnonsymprof(tgt) "" 
    set Paramsacbnonsymprof(rt) ""
    set Paramsacbnonsymprof(httot) ""

    set Paramsacbnonsymprof(hb) ""
    set Paramsacbnonsymprof(bb) ""
    set Paramsacbnonsymprof(tsb) ""
    set Paramsacbnonsymprof(tgb) "" 
    set Paramsacbnonsymprof(rb) ""
    set Paramsacbnonsymprof(hbtot) ""
        
    set Paramsacbnonsymprof(drawFillet) 0         
    set Paramsacbnonsymprof(drawSlab) 0         
    set Paramsacbnonsymprof(slabW) ""
    set Paramsacbnonsymprof(slabH) ""
    set Paramsacbnonsymprof(open) 0
        

    InitWindow $w "Create ACB - Profile non symetric" ParametricWindowGeom   
 
    frame $w.frmProfType 
        
    label $w.frmProfType.lType -text "Type"

    set ProfTyp "HE"

    ComboBox $w.frmProfType.listOfType -editable 0 -width 15 -textvariable ProfTyp \
      -values { "IPE" "HE" "HL" "HD" "HP" "W" "USER" } \
      -modifycmd { updateProfListacbnonsym  $ProfTyp }

    label $w.frmProfType.lProf -text "Profile Top"
    label $w.frmProfType.eProf -relief sunken -width 20 -textvariable ProfNamacbnonsym -font FixedFont
    listbox $w.frmProfType.listOfProf -width 20 -relief raised -borderwidth 2 -selectmode single \
          -yscrollcommand " $w.frmProfType.scrollProfList set " -font FixedFont

    scrollbar $w.frmProfType.scrollProfList -command "$w.frmProfType.listOfProf yview"

    frame $w.frmEquations
 
    label $w.frmEquations.acbnonsymlht -text "Height(h)"
    label $w.frmEquations.acbnonsymlhut -text "mm"
    entry $w.frmEquations.acbnonsymeht -relief sunken -width 10 -textvariable Paramsacbnonsymprof(ht)
    label $w.frmEquations.acbnonsymlbt -text "Width(b)"
    label $w.frmEquations.acbnonsymlbut -text "mm"
    entry $w.frmEquations.acbnonsymebt -relief sunken -width 10 -textvariable Paramsacbnonsymprof(bt)
    label $w.frmEquations.acbnonsymltst -text "Web(tw)"
    label $w.frmEquations.acbnonsymltsut -text "mm"
    entry $w.frmEquations.acbnonsymetst -relief sunken -width 10 -textvariable Paramsacbnonsymprof(tst)
    label $w.frmEquations.acbnonsymltgt -text "Flange(tf)"
    label $w.frmEquations.acbnonsymltgut -text "mm"
    entry $w.frmEquations.acbnonsymetgt -relief sunken -width 10 -textvariable Paramsacbnonsymprof(tgt)
    label $w.frmEquations.acbnonsymlrt -text "Radius(r)"
    label $w.frmEquations.acbnonsymlrut -text "mm"
    entry $w.frmEquations.acbnonsymert -relief sunken -width 10 -textvariable Paramsacbnonsymprof(rt)
    label $w.frmEquations.acbnonsymlhttot -text "Total height top tee"
    label $w.frmEquations.acbnonsymlhttotut -text "mm"
    entry $w.frmEquations.acbnonsymehttot -relief sunken -width 10 -textvariable Paramsacbnonsymprof(httot)
    label $w.frmEquations.acbnonsymopenr -text "Opening(a0)"
    label $w.frmEquations.acbnonsymopenru -text "mm"
    entry $w.frmEquations.acbnonsymopen -relief sunken -width 10 -textvariable Paramsacbnonsymprof(open)



        frame $w.frmProfTypeBottom 
        
    label $w.frmProfTypeBottom.lType -text "Type"

    set ProfTypBottom "HE"

    ComboBox $w.frmProfTypeBottom.listOfType -editable 0 -width 15 -textvariable ProfTypBottom \
      -values { "IPE" "HE" "HL" "HD" "HP" "W" "USER" } \
      -modifycmd { updateProfListacbnonsymBottom  $ProfTypBottom }

    label $w.frmProfTypeBottom.lProf -text "Profile Bottom"
    label $w.frmProfTypeBottom.eProf -relief sunken -width 20 -textvariable ProfNamacbnonsymBottom -font FixedFont
    listbox $w.frmProfTypeBottom.listOfProf -width 20 -relief raised -borderwidth 2 -selectmode single \
          -yscrollcommand " $w.frmProfTypeBottom.scrollProfList set " -font FixedFont

    scrollbar $w.frmProfTypeBottom.scrollProfList -command "$w.frmProfTypeBottom.listOfProf yview"

    frame $w.frmEquationsBottom
 
    label $w.frmEquationsBottom.acbnonsymlhb -text "Height(h)"
    label $w.frmEquationsBottom.acbnonsymlhub -text "mm"
    entry $w.frmEquationsBottom.acbnonsymehb -relief sunken -width 10 -textvariable Paramsacbnonsymprof(hb)
    label $w.frmEquationsBottom.acbnonsymlbb -text "Width(b)"
    label $w.frmEquationsBottom.acbnonsymlbub -text "mm"
    entry $w.frmEquationsBottom.acbnonsymebb -relief sunken -width 10 -textvariable Paramsacbnonsymprof(bb)
    label $w.frmEquationsBottom.acbnonsymltsb -text "Web(tw)"
    label $w.frmEquationsBottom.acbnonsymltsub -text "mm"
    entry $w.frmEquationsBottom.acbnonsymetsb -relief sunken -width 10 -textvariable Paramsacbnonsymprof(tsb)
    label $w.frmEquationsBottom.acbnonsymltgb -text "Flange(tf)"
    label $w.frmEquationsBottom.acbnonsymltgub -text "mm"
    entry $w.frmEquationsBottom.acbnonsymetgb -relief sunken -width 10 -textvariable Paramsacbnonsymprof(tgb)
    label $w.frmEquationsBottom.acbnonsymlrb -text "Radius(r)"
    label $w.frmEquationsBottom.acbnonsymlrub -text "mm"
    entry $w.frmEquationsBottom.acbnonsymerb -relief sunken -width 10 -textvariable Paramsacbnonsymprof(rb)
    label $w.frmEquationsBottom.acbnonsymlhbtot -text "Total height bottom tee"
    label $w.frmEquationsBottom.acbnonsymlhbtotut -text "mm"
    entry $w.frmEquationsBottom.acbnonsymehbtot -relief sunken -width 10 -textvariable Paramsacbnonsymprof(hbtot)

    label $w.frmEquations.acbnonsymlexactShape -text "exact shape"
    checkbutton $w.frmEquations.acbnonsymexactShape -variable Paramsacbnonsymprof(drawFillet)

    label $w.frmEquations.acbnonsymlConcreteSlab -text "Concrete Slab"
    checkbutton $w.frmEquations.acbnonsymconcreteSlab -variable Paramsacbnonsymprof(drawSlab) -command {
          set w .gid.acbnonsymprofil
         if { $Paramsacbnonsymprof(drawSlab) == 1} {
            $w.frmEquations.acbnonsymeSlabWidth configure -state normal
            $w.frmEquations.acbnonsymeSlabHight configure -state normal  
         } else {
            $w.frmEquations.acbnonsymeSlabWidth configure -state disabled
            $w.frmEquations.acbnonsymeSlabHight configure -state disabled 
            set Paramsacbnonsymprof(slabW)  ""
            set Paramsacbnonsymprof(slabH)  ""
         }
    }
    label $w.frmEquations.acbnonsymlSlabWidth -text "Slab Width"
    label $w.frmEquations.acbnonsymlSlabWidthu -text "mm"
    entry $w.frmEquations.acbnonsymeSlabWidth -relief sunken -width 10 -textvariable Paramsacbnonsymprof(slabW) -state disabled
    label $w.frmEquations.acbnonsymlSlabHight -text "Slab Height"
    label $w.frmEquations.acbnonsymlSlabHightu -text "mm"
    entry $w.frmEquations.acbnonsymeSlabHight -relief sunken -width 10 -textvariable Paramsacbnonsymprof(slabH) -state disabled

    set def_back [$w cget -background]
    frame $w.frmButtonsacbnonsym -bg [CCColorActivo $def_back]
    button $w.frmButtonsacbnonsym.btnApply -text "Apply" \
            -command "Drawacbnonsymprofile $w" \
            -underline 0 -width 6
    button $w.frmButtonsacbnonsym.btnclose -text "Close" \
            -command "destroy $w" \
            -underline 0 -width 6

    grid $w.frmProfType  -padx 5 -pady 5  -column 0 -row 0 -sticky nwse -columnspan 3
    grid $w.frmProfType.lType $w.frmProfType.listOfType -sticky nwse
    grid $w.frmProfType.lProf $w.frmProfType.eProf -sticky nwse
    grid $w.frmProfType.scrollProfList $w.frmProfType.listOfProf -sticky nwse
  
    grid $w.frmEquations -padx 5 -pady 5 -column 0 -row 1 -sticky nwse -columnspan 3
    grid $w.frmEquations.acbnonsymlht $w.frmEquations.acbnonsymeht $w.frmEquations.acbnonsymlhut -sticky nwse
    grid $w.frmEquations.acbnonsymlbt $w.frmEquations.acbnonsymebt $w.frmEquations.acbnonsymlbut -sticky nwse
    grid $w.frmEquations.acbnonsymltst $w.frmEquations.acbnonsymetst $w.frmEquations.acbnonsymltsut -sticky nwse
    grid $w.frmEquations.acbnonsymltgt $w.frmEquations.acbnonsymetgt $w.frmEquations.acbnonsymltgut -sticky nwse
    grid $w.frmEquations.acbnonsymlrt $w.frmEquations.acbnonsymert $w.frmEquations.acbnonsymlrut -sticky nwse
    grid $w.frmEquations.acbnonsymlhttot $w.frmEquations.acbnonsymehttot $w.frmEquations.acbnonsymlhttotut -sticky nwse
        
    grid $w.frmEquations.acbnonsymopenr $w.frmEquations.acbnonsymopen $w.frmEquations.acbnonsymopenru  -columnspan 6
    grid $w.frmEquations.acbnonsymlexactShape $w.frmEquations.acbnonsymexactShape -columnspan 6
    grid $w.frmEquations.acbnonsymlConcreteSlab $w.frmEquations.acbnonsymconcreteSlab  -columnspan 6
    grid $w.frmEquations.acbnonsymlSlabWidth $w.frmEquations.acbnonsymeSlabWidth $w.frmEquations.acbnonsymlSlabWidthu -columnspan 6
    grid $w.frmEquations.acbnonsymlSlabHight $w.frmEquations.acbnonsymeSlabHight $w.frmEquations.acbnonsymlSlabHightu -columnspan 6
        
    grid $w.frmProfTypeBottom  -padx 5 -pady 5 -column 3 -row 0 -sticky nwse -columnspan 3
    grid $w.frmProfTypeBottom.lType $w.frmProfTypeBottom.listOfType -sticky nwse
    grid $w.frmProfTypeBottom.lProf $w.frmProfTypeBottom.eProf -sticky nwse
    grid $w.frmProfTypeBottom.scrollProfList $w.frmProfTypeBottom.listOfProf -sticky nwse
  
    grid $w.frmEquationsBottom -padx 5 -pady 5 -column 3 -row 1 -sticky nwse -columnspan 3
    grid $w.frmEquationsBottom.acbnonsymlhb $w.frmEquationsBottom.acbnonsymehb $w.frmEquationsBottom.acbnonsymlhub -sticky nwse
    grid $w.frmEquationsBottom.acbnonsymlbb $w.frmEquationsBottom.acbnonsymebb $w.frmEquationsBottom.acbnonsymlbub -sticky nwse
    grid $w.frmEquationsBottom.acbnonsymltsb $w.frmEquationsBottom.acbnonsymetsb $w.frmEquationsBottom.acbnonsymltsub -sticky nwse
    grid $w.frmEquationsBottom.acbnonsymltgb $w.frmEquationsBottom.acbnonsymetgb $w.frmEquationsBottom.acbnonsymltgub -sticky nwse
    grid $w.frmEquationsBottom.acbnonsymlrb $w.frmEquationsBottom.acbnonsymerb $w.frmEquationsBottom.acbnonsymlrub -sticky nwse
    grid $w.frmEquationsBottom.acbnonsymlhbtot $w.frmEquationsBottom.acbnonsymehbtot $w.frmEquationsBottom.acbnonsymlhbtotut -sticky nwse        
    
    grid $w.frmButtonsacbnonsym -columnspan 6 -sticky ns
    grid $w.frmButtonsacbnonsym.btnApply $w.frmButtonsacbnonsym.btnclose -padx 5 -pady 5 -columnspan 6

    grid columnconf $w "0" -weight 0 
    grid rowconfigure $w "3" -weight 0
    
    focus $w.frmButtonsacbnonsym.btnApply
    
    bind $w <Alt-c> "tkButtonInvoke $w.frmButtonsacbnonsym.btnclose"
    bind $w <Escape> "tkButtonInvoke $w.frmButtonsacbnonsym.btnclose"

    bind $w.frmProfType.listOfProf <<ListboxSelect>> { updateProfacbnonsym [selection get] }
    bind $w.frmProfTypeBottom.listOfProf <<ListboxSelect>> { updateProfacbnonsymBottom [selection get] }
        
    set ProfNamacbnonsym  ""
    set ProfNamacbnonsymBottom  ""
    set Paramsacbnonsymprof(slabW) ""
    set Paramsacbnonsymprof(slabH) ""
    set Paramsacbnonsymprof(open) 0

    updateProfListacbnonsym  "HE"
    updateProfListacbnonsymBottom  "HE"

    #wm minsize $w 140 175
}

proc updateProfacbnonsym { selectedProf } {

   global ProfNamacbnonsym
   global Paramsacbnonsymprof 

   set w .gid.acbnonsymprofil

   set ProfNamacbnonsym [string range $selectedProf 0 20]

   set profData [string range $selectedProf 21 end]
   scan $profData "%s %s %s %s %s" w1 w2 w3 w4 w5

   set Paramsacbnonsymprof(ht) $w1
   set Paramsacbnonsymprof(bt) $w2
   set Paramsacbnonsymprof(tst) $w3
   set Paramsacbnonsymprof(tgt) $w4
   set Paramsacbnonsymprof(rt) $w5

}

proc updateProfacbnonsymBottom { selectedProf } {

   global ProfNamacbnonsymBottom
   global Paramsacbnonsymprof 

   set w .gid.acbnonsymprofil

   set ProfNamacbnonsymBottom [string range $selectedProf 0 20]

   set profData [string range $selectedProf 21 end]
   scan $profData "%s %s %s %s %s" w1 w2 w3 w4 w5

   set Paramsacbnonsymprof(hb) $w1
   set Paramsacbnonsymprof(bb) $w2
   set Paramsacbnonsymprof(tsb) $w3
   set Paramsacbnonsymprof(tgb) $w4
   set Paramsacbnonsymprof(rb) $w5

}

proc updateProfListacbnonsym  { type } {
 variable path
       global ProblemTypePath

       global ProfNamacbnonsym
       global ProfTyp
       global Paramsacbnonsymprof 

       set w .gid.acbnonsymprofil

       $w.frmProfType.listOfProf delete 0 end

       set ProfNamacbnonsym  ""
       set Paramsacbnonsymprof(ht) ""
       set Paramsacbnonsymprof(bt) ""
       set Paramsacbnonsymprof(tst) ""
       set Paramsacbnonsymprof(tgt) "" 
       set Paramsacbnonsymprof(rt) ""

       if { $type == "USER" } {

            $w.frmEquations.acbnonsymeht configure -state normal
            $w.frmEquations.acbnonsymebt configure -state normal
            $w.frmEquations.acbnonsymetst configure -state normal
            $w.frmEquations.acbnonsymetgt configure -state normal
            $w.frmEquations.acbnonsymert configure -state normal
            $w.frmEquations.acbnonsymopen configure -state normal
            $w.frmEquations.acbnonsymehttot configure -state normal
            
            

             return
       }

       $w.frmEquations.acbnonsymeht configure -state disabled
       $w.frmEquations.acbnonsymebt configure -state disabled
       $w.frmEquations.acbnonsymetst configure -state disabled
       $w.frmEquations.acbnonsymetgt configure -state disabled
       $w.frmEquations.acbnonsymert configure -state disabled
       $w.frmEquations.acbnonsymopen configure -state normal
       $w.frmEquations.acbnonsymehttot configure -state normal

       #set wdir "c:\\Programme\\GiD\\Gid 8.0.9\\problemtypes\\SAFIR2007_test\\Safir_Thermal_2d.gid"
       set wdir $ProblemTypePath

       set f [open $wdir\\prof.txt ]

       set listProf { }
       while { [ gets $f line ] >= 0 } {
           scan $line "%s" kw0
           if { $kw0 == $type} {
                  set profNamacbnonsym [string range $line 0 20]
              $w.frmProfType.listOfProf insert end $line
           }
       }

       close $f
}

proc updateProfListacbnonsymBottom  { type } {
 variable path
       global ProblemTypePath

       global ProfNamacbnonsymBottom
       global ProfTypBottom
       global Paramsacbnonsymprof 

       set w .gid.acbnonsymprofil

       $w.frmProfTypeBottom.listOfProf delete 0 end

       set ProfNamacbnonsymBottom  ""
       set Paramsacbnonsymprof(hb) ""
       set Paramsacbnonsymprof(bb) ""
       set Paramsacbnonsymprof(tsb) ""
       set Paramsacbnonsymprof(tgb) "" 
       set Paramsacbnonsymprof(rb) ""

       if { $type == "USER" } {

            $w.frmEquationsBottom.acbnonsymehb configure -state normal
            $w.frmEquationsBottom.acbnonsymebb configure -state normal
            $w.frmEquationsBottom.acbnonsymetsb configure -state normal
            $w.frmEquationsBottom.acbnonsymetgb configure -state normal
            $w.frmEquationsBottom.acbnonsymerb configure -state normal
            $w.frmEquationsBottom.acbnonsymehbtot configure -state normal

             return
       }

       $w.frmEquationsBottom.acbnonsymehb configure -state disabled
       $w.frmEquationsBottom.acbnonsymebb configure -state disabled
       $w.frmEquationsBottom.acbnonsymetsb configure -state disabled
       $w.frmEquationsBottom.acbnonsymetgb configure -state disabled
       $w.frmEquationsBottom.acbnonsymerb configure -state disabled
       $w.frmEquationsBottom.acbnonsymehbtot configure -state normal

       #set wdir "c:\\Programme\\GiD\\Gid 8.0.9\\problemtypes\\SAFIR2007_test\\Safir_Thermal_2d.gid"
       set wdir $ProblemTypePath

       set f [open $wdir\\prof.txt ]

       set listProfBottom { }
       while { [ gets $f line ] >= 0 } {
           scan $line "%s" kw0
           if { $kw0 == $type} {
                  set profNamacbnonsymBottom [string range $line 0 20]
              $w.frmProfTypeBottom.listOfProf insert end $line
           }
       }

       close $f
}

proc Drawacbnonsymprofile { w } {

    global Paramsacbnonsymprof

    set scal 0.001
    set ht [expr $Paramsacbnonsymprof(httot) * $scal]
    set bt [expr $Paramsacbnonsymprof(bt) * $scal]
    set tst [expr $Paramsacbnonsymprof(tst) * $scal]
    set tgt [expr $Paramsacbnonsymprof(tgt) * $scal]
    set hopen [expr $Paramsacbnonsymprof(open) * $scal]
        
    set hb [expr $Paramsacbnonsymprof(hbtot) * $scal]
    set bb [expr $Paramsacbnonsymprof(bb) * $scal]
    set tsb [expr $Paramsacbnonsymprof(tsb) * $scal]
    set tgb [expr $Paramsacbnonsymprof(tgb) * $scal]


    set exactS $Paramsacbnonsymprof(drawFillet)
    set drawS $Paramsacbnonsymprof(drawSlab)

    #set slabW [expr $Paramsacbnonsymprof(slabW) * $scal]
    #set slabH [expr $Paramsacbnonsymprof(slabH) * $scal]

    if { $exactS == 1 } {
            set rt [expr $Paramsacbnonsymprof(rt) * $scal]
                set rb [expr $Paramsacbnonsymprof(rb) * $scal]
    } else {
            set rt [ expr $Paramsacbnonsymprof(rt)*0.665*$scal ]
                set rb [ expr $Paramsacbnonsymprof(rb)*0.665*$scal ] 
    }

    set x0 0.0
    set y0 0.0
        
    set yopen [expr $hopen*0.5]

    set hht [expr $ht +$yopen]
    set bht [expr $bt * 0.5]
    set tsht [expr $tst*0.5]
    set dct [expr sqrt([expr $rt*$rt*0.5])]
        
    set hhb [expr $hb+$yopen]
    set bhb [expr $bb*0.5]
    set tshb [expr $tsb*0.5]
    set dcb [expr sqrt([expr $rb*$rb*0.5])]

    set x1 [expr $x0 - $bhb]
    set y1 [expr $y0 - $hhb]

    set x2 [expr $x0 + $bhb]
    set y2 [expr $y0 - $hhb]

    set x3 [expr $x2]
    set y3 [expr $y2 + $tgb]

    set x4 [expr $x0 + $tshb + $rb]
    set y4 [expr $y3]

    set x5 [expr $x0 + $tshb]
    set y5 [expr $y4 + $rb]  

    set c1x [expr $x4 - $dcb]
    set c1y [expr $y5 - $dcb]

    set x6 [expr $x0 + $tsht]
    set y6 [expr $y0 + $hht - $tgt - $rt]

    set x7 [expr $x6 + $rt]
    set y7 [expr $y6 + $rt]

    set c2x [expr $x7 - $dct]
    set c2y [expr $y6 + $dct]

    set x8 [expr $x0 + $bht]
    set y8 [expr $y0 + $hht - $tgt]

    set x9 [expr $x8]
    set y9 [expr $y0 + $hht]

    set x10 [expr $x0 - $x9]
    set y10 [expr $y9]

    set x11 [expr $x0 - $x8]
    set y11 [expr $y8]

    set x12 [expr $x0 - $x7]
    set y12 [expr $y7]

    set x13 [expr $x0 - $x6]
    set y13 [expr $y6]
 
    set c3x [expr $x0 - $c2x]
    set c3y [expr $c2y]

    set x14 [expr $x0 - $x5]
    set y14 [expr $y5]

    set x15 [expr $x0 - $x4]
    set y15 [expr $y4]

    set c4x [expr $x0 - $c1x]
    set c4y [expr $c1y]

    set x16 [expr $x0 - $x3]
    set y16 [expr $y3]
        
        set xopen1 [expr $x5]
        set yopen1 [expr $y0 - $yopen]
        
        set xopen2 [expr $xopen1 - $tsb]
        set yopen2 [expr $yopen1]
        
        set xopen3 [expr $x6]
        set yopen3 [expr $yopen1 + $hopen]
        
        set xopen4 [expr $xopen3-$tst]
        set yopen4 [expr $yopen3]
        
       		#----------tors---------
	
	set tors1x [expr $x0]
    set tors1y [expr $y0 - $hhb]
	set tors2x [expr $x0]
    set tors2y [expr $y0 - $hhb + $tgb]
	set tors3x [expr $x0]
    set tors3y [expr $y0 + $hht - $tgt]
	set tors4x [expr $x0]
    set tors4y [expr $y0 + $hht]
	
	#---------/tors---------

    set oldvalue [GiD_Info variables CreateAlwaysNewPoint]
    GiD_Process escape escape escape Utilities Variables CreateAlwaysNewPoint  1

    GiD_Process escape escape escape escape
    GiD_Process geometry create line \
    $x1,$y1,0.0 \
	$tors1x,$tors1y,0.0 \
    $x2,$y2,0.0 \
    $x3,$y3,0.0 \
    $x4,$y4,0.0 \
    escape escape escape escape

    if { $exactS == 1 } {
            .central.s process geometry create arc \
            $x4,$y4,0.0 \
            $c1x,$c1y,0.0 \
            $x5,$y5,0.0 \
            escape escape escape escape
    } else {
       GiD_Process geometry create line \
        $x4,$y4,0.0 \
        $x5,$y5,0.0 \
        escape escape escape escape
    }

   GiD_Process geometry create line \
    $x5,$y5,0.0 \
    $xopen1,$yopen1,0.0 \
        $xopen2,$yopen2,0.0 \
        $x14,$y14,0.0 \
    escape escape escape escape
        
        if { $exactS == 1 } {
        GiD_Process geometry create arc \
         $x14,$y14,0.0 \
         $c4x,$c4y,0.0 \
         $x15,$y15,0.0 \
         escape escape escape escape
    } else {
       GiD_Process geometry create line \
        $x14,$y14,0.0 \
        $x15,$y15,0.0 \
        escape escape escape escape
    }
        
        GiD_Process geometry create line \
    $x15,$y15,0.0 \
    $x16,$y16,0.0 \
        $x1,$y1,0.0 \
    escape escape escape escape

    GiD_Process geometry create line \
    $x7,$y7,0.0 \
    $x8,$y8,0.0 \
    $x9,$y9,0.0 \
	$tors4x,$tors4y,0.0 \
    $x10,$y10,0.0 \
    $x11,$y11,0.0 \
    $x12,$y12,0.0 \
    escape escape escape escape

    if { $exactS == 1 } {
        GiD_Process geometry create arc \
        $x12,$y12,0.0 \
        $c3x,$c3y,0.0 \
        $x13,$y13,0.0 \
        escape escape escape escape
    } else {
       GiD_Process geometry create line \
        $x12,$y12,0.0 \
        $x13,$y13,0.0 \
        escape escape escape escape
    }

   GiD_Process geometry create line \
    $x13,$y13,0.0 \
    $xopen4,$yopen4,0.0 \
    $xopen3,$yopen3,0.0 \
        $x6,$y6,0.0 \
    escape escape escape escape

    if { $exactS == 1 } {
         GiD_Process geometry create arc \
         $x6,$y6,0.0 \
         $c2x,$c2y,0.0 \
         $x7,$y7,0.0 \
     escape escape escape escape
    } else {
       GiD_Process geometry create line \
        $x6,$y6,0.0 \
        $x7,$y7,0.0 \
        escape escape escape escape
    }

	#---------torsion------------
	GiD_Process geometry create line \
	$x15,$y15,0.0 \
	$tors2x,$tors2y,0.0 \
	$x4,$y4,0.0 \
    escape escape escape escape
	
	GiD_Process geometry create line \
	$tors2x,$tors2y,0.0 \
	$tors1x,$tors1y,0.0 \
    escape escape escape escape
	   
	GiD_Process geometry create line \
	$x12,$y12,0.0 \
	$tors3x,$tors3y,0.0 \
	$x7,$y7,0.0 \
    escape escape escape escape
	
	GiD_Process geometry create line \
	$tors3x,$tors3y,0.0 \
	$tors4x,$tors4y,0.0 \
    escape escape escape escape
	#---------torsion------------
	
	#add torsion constraint
	GiD_Process Data Conditions AssignCond Point_Torsion_Constraint Change 1 38 \
	Mescape 
	
    if { $drawS == 1 } {

       set sW [expr $Paramsacbnonsymprof(slabW) * $scal]
       set sH [expr $Paramsacbnonsymprof(slabH) * $scal] 

       set dsx [ expr $sW*0.5 - $bt*0.5 ]

       set sl1x [ expr $x9 + $dsx ]
       set sl1y $y9

       set sl2x $sl1x
       set sl2y [ expr $sl1y + $sH ]

       set sl3x [ expr $x10 - $dsx ]
       set sl3y [ expr $y10 + $sH ]

       set sl4x $sl3x
       set sl4y [ expr $sl3y - $sH ]

       GiD_Process geometry create line \
        $x9,$y9,0.0 \
        $sl1x,$sl1y,0.0 \
        $sl2x,$sl2y,0.0 \
        $sl3x,$sl3y,0.0 \
        $sl4x,$sl4y,0.0 \
        $x10,$y10,0.0 \
            escape escape escape escape
    }


    GiD_Process escape
    GiD_Process escape escape escape Utilities Variables \
                 CreateAlwaysNewPoint $oldvalue
    GiD_Process escape escape escape
 
    GiD_Process Utilities Collapse Points 1:
    GiD_Process escape escape escape

    GiD_Process zoom frame escape escape escape escape

    if { $exactS == 0 } {

       GiD_Process Geometry Create NurbsSurface 2 3 4 24 25\
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 1 25 23 10 11 \
       escape escape escape escape

	   GiD_Process Geometry Create NurbsSurface 23 24 5 6 7 8 9 \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 20 21 22 27 26 18 19\
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 27 12 13 14 28 \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 17 26 28 15 16 \
       escape escape escape escape
	   
	   #GID_Process Meshing Structured Lines [number_of_finite_elements] [line1] [line2] [...]
	   
       GiD_Process Meshing Structured Lines 6 1 2 14 15 escape 5 4 12 17 10 escape  \
       escape escape escape escape
       
     if { $drawS == 1 } {
     
       GiD_Process Geometry Create NurbsSurface 33 15 14 29 30 31 32\
       escape escape escape escape

       GiD_Process Meshing ElemType Quadrilateral 7 Escape \
       escape escape escape escape

       GiD_Process Meshing Structured Surfaces 7 escape 12 33 escape 6 15  escape 6 14 escape 12 29 escape \
       5 30 escape \
       escape escape escape escape
       }
       
   } else {
   
     if { $drawS == 1 } {

        #beam surfaces
		 GiD_Process Geometry Create NurbsSurface 2 3 4 24 25\
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 1 25 23 10 11 \
       escape escape escape escape

	   GiD_Process Geometry Create NurbsSurface 23 24 34 7 35 \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 20 37 27 26 36 \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 27 12 13 14 28  \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 17 26 28 15 16 \
       escape escape escape escape
	   
	   
	   GiD_Process Meshing Structured Lines 6 1 2 14 15 escape 5 4 12 17 10 escape  \
       escape escape escape escape
	   
	     #slab surface
		 	   GiD_Process Geometry Create NurbsSurface 33 15 14 29 30 31 32  \
       escape escape escape escape
	   
       GiD_Process Meshing ElemType Quadrilateral 7 Escape \
       escape escape escape escape

       GiD_Process Meshing Structured Surfaces 7 escape 12 33 escape 6 15  escape 6 14 escape 12 29 escape \
       5 30 escape \
       escape escape escape escape

    } else {
       GiD_Process Geometry Create NurbsSurface 2 3 4 24 25\
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 1 25 23 10 11 \
       escape escape escape escape

	   GiD_Process Geometry Create NurbsSurface 23 24 29 7 30 \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 20 32 27 26 31 \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 27 12 13 14 28  \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 17 26 28 15 16 \
       escape escape escape escape
	   
	     GiD_Process Meshing Structured Lines 6 1 2 14 15 escape 5 4 12 17 10 escape  \
       escape escape escape escape



   }

    }

    destroy $w
}


proc Sfbprofile { } {

    global Paramssfbprof 

    global ProfNamsfb
    global ProfTyp
 
    set w .gid.sfbprofil

    set Paramssfbprof(h) ""
    set Paramssfbprof(b) ""
    set Paramssfbprof(ts) ""
    set Paramssfbprof(tg) "" 
    set Paramssfbprof(r) ""
    set Paramssfbprof(drawFillet) 0         
    set Paramssfbprof(drawSlab) 1         
    set Paramssfbprof(slabW) ""
    set Paramssfbprof(slabH) ""
    set Paramssfbprof(plateW) ""
    set Paramssfbprof(plateH) ""

    InitWindow $w "Create SFB - Profile" ParametricWindowGeom   
 
    frame $w.frmProfType 

    label $w.frmProfType.lType -text "Type"

    set ProfTyp "HE"

    ComboBox $w.frmProfType.listOfType -editable 0 -width 15 -textvariable ProfTyp \
      -values { "IPE" "HE" "HL" "HD" "HP" "W" "USER" } \
      -modifycmd { updateProfListsfb  $ProfTyp }

    label $w.frmProfType.lProf -text "Profile"
    label $w.frmProfType.eProf -relief sunken -width 20 -textvariable ProfNamsfb -font FixedFont
    listbox $w.frmProfType.listOfProf -width 20 -relief raised -borderwidth 2 -selectmode single \
          -yscrollcommand " $w.frmProfType.scrollProfList set " -font FixedFont

    scrollbar $w.frmProfType.scrollProfList -command "$w.frmProfType.listOfProf yview"

    frame $w.frmEquations
 
    label $w.frmEquations.sfblh -text "Height(h)"
    label $w.frmEquations.sfblhu -text "mm"
    entry $w.frmEquations.sfbeh -relief sunken -width 10 -textvariable Paramssfbprof(h)
    label $w.frmEquations.sfblb -text "Width(b)"
    label $w.frmEquations.sfblbu -text "mm"
    entry $w.frmEquations.sfbeb -relief sunken -width 10 -textvariable Paramssfbprof(b)
    label $w.frmEquations.sfblts -text "Web(tw)"
    label $w.frmEquations.sfbltsu -text "mm"
    entry $w.frmEquations.sfbets -relief sunken -width 10 -textvariable Paramssfbprof(ts)
    label $w.frmEquations.sfbltg -text "Flange(tf)"
    label $w.frmEquations.sfbltgu -text "mm"
    entry $w.frmEquations.sfbetg -relief sunken -width 10 -textvariable Paramssfbprof(tg)
    label $w.frmEquations.sfblr -text "Radius(r)"
    label $w.frmEquations.sfblru -text "mm"
    entry $w.frmEquations.sfber -relief sunken -width 10 -textvariable Paramssfbprof(r)
    label $w.frmEquations.sfbplateHr -text "Plate Thickness"
    label $w.frmEquations.sfbplateHru -text "mm"
    entry $w.frmEquations.sfbplateH -relief sunken -width 10 -textvariable Paramssfbprof(plateH)
    label $w.frmEquations.sfbplateWr -text "Plate Width"
    label $w.frmEquations.sfbplateWru -text "mm"
    entry $w.frmEquations.sfbplateW -relief sunken -width 10 -textvariable Paramssfbprof(plateW)
    label $w.frmEquations.sfblSlabWidth -text "Slab Width"
    label $w.frmEquations.sfblSlabWidthu -text "mm"
    entry $w.frmEquations.sfbeSlabWidth -relief sunken -width 10 -textvariable Paramssfbprof(slabW) 
    label $w.frmEquations.sfblSlabHight -text "Concrete height over the steel profile"
    label $w.frmEquations.sfblSlabHightu -text "mm"
    entry $w.frmEquations.sfbeSlabHight -relief sunken -width 10 -textvariable Paramssfbprof(slabH)
 
    label $w.frmEquations.sfblexactShape -text "exact shape"
    checkbutton $w.frmEquations.sfbexactShape -variable Paramssfbprof(drawFillet)

    set def_back [$w cget -background]
    frame $w.frmButtonssfb -bg [CCColorActivo $def_back]
    button $w.frmButtonssfb.btnApply -text "Apply" \
            -command "Drawsfbprofile $w" \
            -underline 0 -width 6
    button $w.frmButtonssfb.btnclose -text "Close" \
            -command "destroy $w" \
            -underline 0 -width 6

    grid $w.frmProfType  -padx 5 -pady 5 -sticky ew 

    grid $w.frmProfType.lType $w.frmProfType.listOfType -sticky e
    grid $w.frmProfType.lProf $w.frmProfType.eProf -sticky e
    grid $w.frmProfType.scrollProfList $w.frmProfType.listOfProf -sticky ens
  
    grid $w.frmEquations -padx 5 -pady 5 -sticky ew    
    grid $w.frmEquations.sfblh $w.frmEquations.sfbeh $w.frmEquations.sfblhu -sticky e
    grid $w.frmEquations.sfblb $w.frmEquations.sfbeb $w.frmEquations.sfblbu -sticky e
    grid $w.frmEquations.sfblts $w.frmEquations.sfbets $w.frmEquations.sfbltsu -sticky e
    grid $w.frmEquations.sfbltg $w.frmEquations.sfbetg $w.frmEquations.sfbltgu -sticky e
    grid $w.frmEquations.sfblr $w.frmEquations.sfber $w.frmEquations.sfblru -sticky e
    grid $w.frmEquations.sfblexactShape $w.frmEquations.sfbexactShape -sticky e
    grid $w.frmEquations.sfblSlabWidth $w.frmEquations.sfbeSlabWidth $w.frmEquations.sfblSlabWidthu -sticky e
    grid $w.frmEquations.sfblSlabHight $w.frmEquations.sfbeSlabHight $w.frmEquations.sfblSlabHightu -sticky e
    grid $w.frmEquations.sfbplateWr $w.frmEquations.sfbplateW $w.frmEquations.sfbplateWru -sticky e 
    grid $w.frmEquations.sfbplateHr $w.frmEquations.sfbplateH $w.frmEquations.sfbplateHru -sticky e 
 
    grid $w.frmButtonssfb -sticky ews -columnspan 7
    grid $w.frmButtonssfb.btnApply $w.frmButtonssfb.btnclose -padx 5 -pady 6

    grid columnconf $w "0" -weight 1
    grid rowconfigure $w "3" -weight 1
    
    focus $w.frmButtonssfb.btnApply
    
    bind $w <Alt-c> "tkButtonInvoke $w.frmButtonssfb.btnclose"
    bind $w <Escape> "tkButtonInvoke $w.frmButtonssfb.btnclose"

    bind $w.frmProfType.listOfProf <<ListboxSelect>> { updateProfsfb [selection get] }

    set ProfNamsfb  ""
    set Paramssfbprof(slabW) ""
    set Paramssfbprof(slabH) ""
    set Paramssfbprof(plateW) ""
    set Paramssfbprof(plateH) ""

    updateProfListsfb  "HE"

    #wm minsize $w 140 175
}

proc updateProfsfb { selectedProf } {

   global ProfNamsfb
   global Paramssfbprof 

   set w .gid.sfbprofil

   set ProfNamsfb [string range $selectedProf 0 20]

   set profData [string range $selectedProf 21 end]
   scan $profData "%s %s %s %s %s" w1 w2 w3 w4 w5

   set Paramssfbprof(h) $w1
   set Paramssfbprof(b) $w2
   set Paramssfbprof(ts) $w3
   set Paramssfbprof(tg) $w4
   set Paramssfbprof(r) $w5

}

proc updateProfListsfb  { type } {

       variable path
       global ProblemTypePath

       global ProfNamsfb
       global ProfTyp
       global Paramssfbprof 

       set w .gid.sfbprofil

       $w.frmProfType.listOfProf delete 0 end

       set ProfNamsfb  ""
       set Paramssfbprof(h) ""
       set Paramssfbprof(b) ""
       set Paramssfbprof(ts) ""
       set Paramssfbprof(tg) "" 
       set Paramssfbprof(r) ""

       if { $type == "USER" } {

            $w.frmEquations.sfbeh configure -state normal
            $w.frmEquations.sfbeb configure -state normal
            $w.frmEquations.sfbets configure -state normal
            $w.frmEquations.sfbetg configure -state normal
            $w.frmEquations.sfber configure -state normal
            

             return
       }

       $w.frmEquations.sfbeh configure -state disabled
       $w.frmEquations.sfbeb configure -state disabled
       $w.frmEquations.sfbets configure -state disabled
       $w.frmEquations.sfbetg configure -state disabled
       $w.frmEquations.sfber configure -state disabled

       #set wdir "c:\\Programme\\GiD\\Gid 8.0.9\\problemtypes\\SAFIR2007_test\\Safir_Thermal_2d.gid"
       set wdir $ProblemTypePath

       set f [open $wdir\\prof.txt ]

       set listProf { }
       while { [ gets $f line ] >= 0 } {
           scan $line "%s" kw0
           if { $kw0 == $type} {
                  set profNamsfb [string range $line 0 20]
              $w.frmProfType.listOfProf insert end $line
           }
       }

       close $f
}

proc Drawsfbprofile { w } {

    global Paramssfbprof

    set scal 0.001
    set h [expr $Paramssfbprof(h) * $scal]
    set b [expr $Paramssfbprof(b) * $scal]
    set ts [expr $Paramssfbprof(ts) * $scal]
    set tg [expr $Paramssfbprof(tg) * $scal]
    
    set slabW [expr $Paramssfbprof(slabW) * $scal]
    set slabH [expr $Paramssfbprof(slabH) * $scal]

    set exactS $Paramssfbprof(drawFillet)

    

    if { $exactS == 1 } {
            set r [expr $Paramssfbprof(r) * $scal]
    } else {
            set r [ expr $Paramssfbprof(r)*0.665*$scal ] 
    }

    set x0 0.0
    set y0 0.0

    set hh [expr $h*0.5]
    set bh [expr $b*0.5]
    set tsh [expr $ts*0.5]
    set dc [expr sqrt([expr $r*$r*0.5])]

    set x1 [expr $x0 - $bh]
    set y1 [expr $y0 - $hh]

    set x2 [expr $x0 + $bh]
    set y2 [expr $y0 - $hh]

    set x3 [expr $x2]
    set y3 [expr $y2 + $tg]

    set x4 [expr $x0 + $tsh + $r]
    set y4 [expr $y3]

    set x5 [expr $x0 + $tsh]
    set y5 [expr $y4 + $r]  

    set c1x [expr $x4 - $dc]
    set c1y [expr $y5 - $dc]

    set x6 [expr $x5]
    set y6 [expr $y0 + $hh - $tg - $r]

    set x7 [expr $x5 + $r]
    set y7 [expr $y6 + $r]

    set c2x [expr $x7 - $dc]
    set c2y [expr $y6 + $dc]

    set x8 [expr $x0 + $bh]
    set y8 [expr $y0 + $hh - $tg]

    set x9 [expr $x8]
    set y9 [expr $y0 + $hh]

    set x10 [expr $x0 - $x9]
    set y10 [expr $y9]

    set x11 [expr $x0 - $x8]
    set y11 [expr $y8]

    set x12 [expr $x0 - $x7]
    set y12 [expr $y7]

    set x13 [expr $x0 - $x6]
    set y13 [expr $y6]
 
    set c3x [expr $x0 - $c2x]
    set c3y [expr $c2y]

    set x14 [expr $x0 - $x5]
    set y14 [expr $y5]

    set x15 [expr $x0 - $x4]
    set y15 [expr $y4]

    set c4x [expr $x0 - $c1x]
    set c4y [expr $c1y]

    set x16 [expr $x0 - $x3]
    set y16 [expr $y3]
       
	#----------tors fix---------
	
	set tors1x [expr $x0]
    set tors1y [expr $y0 - $hh]
	set tors2x [expr $x0]
    set tors2y [expr $y0 - $hh + $tg ]
	set tors3x [expr $x0]
    set tors3y [expr $y0 + $hh - $tg ]
	set tors4x [expr $x0]
    set tors4y [expr $y0 + $hh]
	
	#---------/tors---------

    set oldvalue [GiD_Info variables CreateAlwaysNewPoint]
    GiD_Process escape escape escape Utilities Variables CreateAlwaysNewPoint  1

    GiD_Process escape escape escape escape
    GiD_Process geometry create line \
    $x1,$y1,0.0 \
	$tors1x,$tors1y,0.0 \
    $x2,$y2,0.0 \
    $x3,$y3,0.0 \
    $x4,$y4,0.0 \
    escape escape escape escape

    if { $exactS == 1 } {
            .central.s process geometry create arc \
            $x4,$y4,0.0 \
            $c1x,$c1y,0.0 \
            $x5,$y5,0.0 \
            escape escape escape escape
    } else {
       GiD_Process geometry create line \
        $x4,$y4,0.0 \
        $x5,$y5,0.0 \
        escape escape escape escape
    }

   GiD_Process geometry create line \
    $x5,$y5,0.0 \
    $x6,$y6,0.0 \
    escape escape escape escape

    if { $exactS == 1 } {
       GiD_Process geometry create arc \
        $x6,$y6,0.0 \
        $c2x,$c2y,0.0 \
        $x7,$y7,0.0 \
        escape escape escape escape
    } else {
       GiD_Process geometry create line \
        $x6,$y6,0.0 \
        $x7,$y7,0.0 \
        escape escape escape escape
    }

    GiD_Process geometry create line \
    $x7,$y7,0.0 \
    $x8,$y8,0.0 \
    $x9,$y9,0.0 \
	$tors4x,$tors4y,0.0 \
    $x10,$y10,0.0 \
    $x11,$y11,0.0 \
    $x12,$y12,0.0 \
    escape escape escape escape

    if { $exactS == 1 } {
        GiD_Process geometry create arc \
         $x12,$y12,0.0 \
         $c3x,$c3y,0.0 \
         $x13,$y13,0.0 \
         escape escape escape escape
    } else {
       GiD_Process geometry create line \
        $x12,$y12,0.0 \
        $x13,$y13,0.0 \
        escape escape escape escape
    }

   GiD_Process geometry create line \
    $x13,$y13,0.0 \
    $x14,$y14,0.0 \
    escape escape escape escape
    
   if { $exactS == 1 } {
        GiD_Process geometry create arc \
        $x14,$y14,0.0 \
        $c4x,$c4y,0.0 \
        $x15,$y15,0.0 \
        escape escape escape escape
    } else {
       GiD_Process geometry create line \
        $x14,$y14,0.0 \
        $x15,$y15,0.0 \
        escape escape escape escape
    }

   GiD_Process geometry create line \
    $x15,$y15,0.0 \
    $x16,$y16,0.0 \
    $x1,$y1,0.0 \
    escape escape escape escape
	
	
	#---------torsion------------
	GiD_Process geometry create line \
	$x15,$y15,0.0 \
	$tors2x,$tors2y,0.0 \
	$x4,$y4,0.0 \
    escape escape escape escape
	
	GiD_Process geometry create line \
	$tors2x,$tors2y,0.0 \
	$tors1x,$tors1y,0.0 \
    escape escape escape escape
	   
	GiD_Process geometry create line \
	$x12,$y12,0.0 \
	$tors3x,$tors3y,0.0 \
	$x7,$y7,0.0 \
    escape escape escape escape
	
	GiD_Process geometry create line \
	$tors3x,$tors3y,0.0 \
	$tors4x,$tors4y,0.0 \
    escape escape escape escape
	#--------/torsion------------
    
	#add torsion constraint
	GiD_Process Data Conditions AssignCond Point_Torsion_Constraint Change 1 34 \
	Mescape 
	
       GiD_Process geometry create line \
    $x11,$y11,0.0 \
    $x16,$y16,0.0 \
    escape escape escape escape
    
       GiD_Process geometry create line \
    $x8,$y8,0.0 \
    $x3,$y3,0.0 \
    escape escape escape escape


   set sW [expr $Paramssfbprof(slabW) * $scal]
   set sH [expr $Paramssfbprof(slabH) * $scal] 

   set dsx [ expr $sW*0.5 - $b*0.5 ]

   set sl1x [ expr $x9 + $dsx ]
   set sl1y $y9

   set sl2x $sl1x
   set sl2y [ expr $sl1y + $sH ]

   set sl3x [ expr $x10 - $dsx ]
   set sl3y [ expr $y10 + $sH ]

   set sl4x $sl3x
   set sl4y [ expr $sl3y - $sH ]
    
   
   
   

    GiD_Process geometry create line \
     $x9,$y9,0.0 \
     $sl1x,$sl1y,0.0 \
     $sl2x,$sl2y,0.0 \
     $sl3x,$sl3y,0.0 \
     $sl4x,$sl4y,0.0 \
     $x10,$y10,0.0 \
     escape escape escape escape
   
   set pW [expr $Paramssfbprof(plateW) * $scal]
   set pH [expr $Paramssfbprof(plateH) * $scal]
   set dpx [ expr $pW*0.5 - $b*0.5 ]   
     
   set sl5x $sl4x
   set sl5y $y1
   
   set sl6x $sl1x
   set sl6y $y2
   
   set pl1x [expr $x2 + $dpx]
   set pl1y $y2 
   
   set pl2x $pl1x
   set pl2y [expr $pl1y - $pH]
   
   set pl3x [expr $pl2x - $pW]
   set pl3y $pl2y
   
   set pl4x $pl3x
   set pl4y [expr $pl3y + $pH]
   
   GiD_Process geometry create line \
   $sl1x,$sl1y,0.0 \
   $sl6x,$sl6y,0.0 \
   $pl1x,$pl1y,0.0 \
   escape escape escape escape 
   
    GiD_Process geometry create line \
   $sl4x,$sl4y,0.0 \
   $sl5x,$sl5y,0.0 \
   $pl4x,$pl4y,0.0 \
   escape escape escape escape  
   
    GiD_Process geometry create line \
   $x1,$y1,0.0 \
   $pl4x,$pl4y,0.0 \
   $pl3x,$pl3y,0.0 \
   $pl2x,$pl2y,0.0 \
   $pl1x,$pl1y,0.0 \
   $x2,$y2,0.0 \
   escape escape escape escape
     
    GiD_Process escape
    GiD_Process escape escape escape Utilities Variables \
                 CreateAlwaysNewPoint $oldvalue
    GiD_Process escape escape escape
 
    GiD_Process Utilities Collapse Points 1:
    GiD_Process escape escape escape

    GiD_Process zoom frame escape escape escape escape

	#surfaces
    if { $exactS == 1 } {

	 GiD_Process Geometry Create NurbsSurface 10 27 28 29 30 31 11\
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 2 3 4 20 21\
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 1 21 19 17 18 \
       escape escape escape escape

	   GiD_Process Geometry Create NurbsSurface 19 20 42 23 22 44 \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 23 8 9 10 24  \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 13 22 24 11 12 \
       escape escape escape escape
       
       GiD_Process Geometry Create NurbsSurface 1 2 40 39 38 37 36 \
       escape escape escape escape
       
       GiD_Process Geometry Create NurbsSurface 40 33 32 27 9 26 3\
       escape escape escape escape
	   
       GiD_Process Geometry Create NurbsSurface 4 26 8 42 \
       escape escape escape escape
       
       GiD_Process Geometry Create NurbsSurface 17 44 13 25 \
       escape escape escape escape
	   
       GiD_Process Geometry Create NurbsSurface 35 36 18 25 12 31 34 \
       escape escape escape escape
       
   } else {

	   GiD_Process Geometry Create NurbsSurface 10 27 28 29 30 31 11\
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 2 3 4 20 21\
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 1 21 19 17 18 \
       escape escape escape escape

	   GiD_Process Geometry Create NurbsSurface 19 20 5 6 7 23 22 14 15 16 \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 23 8 9 10 24  \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 13 22 24 11 12 \
       escape escape escape escape
       
       GiD_Process Geometry Create NurbsSurface 1 2 40 39 38 37 36 \
       escape escape escape escape
       
       GiD_Process Geometry Create NurbsSurface 40 33 32 27 9 26 3\
       escape escape escape escape
       
	     GiD_Process Geometry Create NurbsSurface 4 26 8 7 6 5 \
       escape escape escape escape
       
       GiD_Process Geometry Create NurbsSurface 17 16 15 14 13 25 \
       escape escape escape escape
       
       GiD_Process Geometry Create NurbsSurface 35 36 18 25 12 31 34 \
       escape escape escape escape

    }

    destroy $w
}

proc Ifbprofile { } {

    global Paramsifbprof 

    global ProfNamifb
    global ProfTyp
 
    set w .gid.ifbprofil

    set Paramsifbprof(h) ""
    set Paramsifbprof(b) ""
    set Paramsifbprof(ts) ""
    set Paramsifbprof(tg) "" 
    set Paramsifbprof(r) ""
    set Paramsifbprof(drawFillet) 0         
    set Paramsifbprof(drawSlab) 1         
    set Paramsifbprof(slabW) ""
    set Paramsifbprof(slabH) ""
    set Paramsifbprof(plateW) ""
    set Paramsifbprof(plateH) ""
    set Paramsifbprof(htot) ""

    InitWindow $w "Create IFB - Profile" ParametricWindowGeom   
 
    frame $w.frmProfType 

    label $w.frmProfType.lType -text "Type"

    set ProfTyp "HE"

    ComboBox $w.frmProfType.listOfType -editable 0 -width 15 -textvariable ProfTyp \
      -values { "IPE" "HE" "HL" "HD" "HP" "W" "USER" } \
      -modifycmd { updateProfListifb  $ProfTyp }

    label $w.frmProfType.lProf -text "Profile"
    label $w.frmProfType.eProf -relief sunken -width 20 -textvariable ProfNamifb -font FixedFont
    listbox $w.frmProfType.listOfProf -width 20 -relief raised -borderwidth 2 -selectmode single \
          -yscrollcommand " $w.frmProfType.scrollProfList set " -font FixedFont

    scrollbar $w.frmProfType.scrollProfList -command "$w.frmProfType.listOfProf yview"

    frame $w.frmEquations  
 
 
 
    label $w.frmEquations.ifblh -text "Height(h)"
    label $w.frmEquations.ifblhu -text "mm"
    entry $w.frmEquations.ifbeh -relief sunken -width 10 -textvariable Paramsifbprof(h)
    label $w.frmEquations.ifblb -text "Width(b)"
    label $w.frmEquations.ifblbu -text "mm"
    entry $w.frmEquations.ifbeb -relief sunken -width 10 -textvariable Paramsifbprof(b)
    label $w.frmEquations.ifblts -text "Web(tw)"
    label $w.frmEquations.ifbltsu -text "mm"
    entry $w.frmEquations.ifbets -relief sunken -width 10 -textvariable Paramsifbprof(ts)
    label $w.frmEquations.ifbltg -text "Flange(tf)"
    label $w.frmEquations.ifbltgu -text "mm"
    entry $w.frmEquations.ifbetg -relief sunken -width 10 -textvariable Paramsifbprof(tg)
    label $w.frmEquations.ifblr -text "Radius(r)"
    label $w.frmEquations.ifblru -text "mm"
    entry $w.frmEquations.ifber -relief sunken -width 10 -textvariable Paramsifbprof(r)
    label $w.frmEquations.ifblhtot -text "Height of cutted profile (ht)"
    label $w.frmEquations.ifblhtotu -text "mm"
    entry $w.frmEquations.ifbehtot -relief sunken -width 10 -textvariable Paramsifbprof(htot)
    label $w.frmEquations.ifbplateHr -text "Plate Thickness"
    label $w.frmEquations.ifbplateHru -text "mm"
    entry $w.frmEquations.ifbplateH -relief sunken -width 10 -textvariable Paramsifbprof(plateH)
    label $w.frmEquations.ifbplateWr -text "Plate Width"
    label $w.frmEquations.ifbplateWru -text "mm"
    entry $w.frmEquations.ifbplateW -relief sunken -width 10 -textvariable Paramsifbprof(plateW)
    label $w.frmEquations.ifblSlabWidth -text "Slab Width"
    label $w.frmEquations.ifblSlabWidthu -text "mm"
    entry $w.frmEquations.ifbeSlabWidth -relief sunken -width 10 -textvariable Paramsifbprof(slabW) 
    label $w.frmEquations.ifblSlabHight -text "Concrete height over the steel profile"
    label $w.frmEquations.ifblSlabHightu -text "mm"
    entry $w.frmEquations.ifbeSlabHight -relief sunken -width 10 -textvariable Paramsifbprof(slabH)
 
    label $w.frmEquations.ifblexactShape -text "exact shape"
    checkbutton $w.frmEquations.ifbexactShape -variable Paramsifbprof(drawFillet)

    set def_back [$w cget -background]
    frame $w.frmButtonsifb -bg [CCColorActivo $def_back]
    button $w.frmButtonsifb.btnApply -text "Apply" \
            -command "Drawifbprofile $w" \
            -underline 0 -width 6
    button $w.frmButtonsifb.btnclose -text "Close" \
            -command "destroy $w" \
            -underline 0 -width 6

    grid $w.frmProfType  -padx 5 -pady 5 -sticky ew 

    grid $w.frmProfType.lType $w.frmProfType.listOfType -sticky e
    grid $w.frmProfType.lProf $w.frmProfType.eProf -sticky e
    grid $w.frmProfType.scrollProfList $w.frmProfType.listOfProf -sticky ens
  
    grid $w.frmEquations -padx 5 -pady 5 -sticky ew    
    grid $w.frmEquations.ifblh $w.frmEquations.ifbeh $w.frmEquations.ifblhu -sticky e
    grid $w.frmEquations.ifblb $w.frmEquations.ifbeb $w.frmEquations.ifblbu -sticky e
    grid $w.frmEquations.ifblts $w.frmEquations.ifbets $w.frmEquations.ifbltsu -sticky e
    grid $w.frmEquations.ifbltg $w.frmEquations.ifbetg $w.frmEquations.ifbltgu -sticky e
    grid $w.frmEquations.ifblr $w.frmEquations.ifber $w.frmEquations.ifblru -sticky e
    grid $w.frmEquations.ifblhtot $w.frmEquations.ifbehtot $w.frmEquations.ifblhtotu -sticky e
    grid $w.frmEquations.ifblexactShape $w.frmEquations.ifbexactShape -sticky e
    grid $w.frmEquations.ifblSlabWidth $w.frmEquations.ifbeSlabWidth $w.frmEquations.ifblSlabWidthu -sticky e
    grid $w.frmEquations.ifblSlabHight $w.frmEquations.ifbeSlabHight $w.frmEquations.ifblSlabHightu -sticky e
    grid $w.frmEquations.ifbplateWr $w.frmEquations.ifbplateW $w.frmEquations.ifbplateWru -sticky e 
    grid $w.frmEquations.ifbplateHr $w.frmEquations.ifbplateH $w.frmEquations.ifbplateHru -sticky e 
 
    grid $w.frmButtonsifb -sticky ews -columnspan 7
    grid $w.frmButtonsifb.btnApply $w.frmButtonsifb.btnclose -padx 5 -pady 6

    grid columnconf $w "0" -weight 1
    grid rowconfigure $w "3" -weight 1
    
    focus $w.frmButtonsifb.btnApply
    
    bind $w <Alt-c> "tkButtonInvoke $w.frmButtonsifb.btnclose"
    bind $w <Escape> "tkButtonInvoke $w.frmButtonsifb.btnclose"

    bind $w.frmProfType.listOfProf <<ListboxSelect>> { updateProfifb [selection get] }

    set ProfNamifb  ""
    set Paramsifbprof(slabW) ""
    set Paramsifbprof(slabH) ""
    set Paramsifbprof(plateW) ""
    set Paramsifbprof(plateH) ""
    set Paramsifbprof(htot) ""

    updateProfListifb  "HE"

    #wm minsize $w 140 175
}

proc updateProfifb { selectedProf } {

   global ProfNamifb
   global Paramsifbprof 

   set w .gid.ifbprofil

   set ProfNamifb [string range $selectedProf 0 20]

   set profData [string range $selectedProf 21 end]
   scan $profData "%s %s %s %s %s" w1 w2 w3 w4 w5

   set Paramsifbprof(h) $w1
   set Paramsifbprof(b) $w2
   set Paramsifbprof(ts) $w3
   set Paramsifbprof(tg) $w4
   set Paramsifbprof(r) $w5

}

proc updateProfListifb  { type } {

       variable path
       global ProblemTypePath

       global ProfNamifb
       global ProfTyp
       global Paramsifbprof 

       set w .gid.ifbprofil

       $w.frmProfType.listOfProf delete 0 end

       set ProfNamifb  ""
       set Paramsifbprof(h) ""
       set Paramsifbprof(b) ""
       set Paramsifbprof(ts) ""
       set Paramsifbprof(tg) "" 
       set Paramsifbprof(r) ""
       set Paramsifbprof(htot) ""

       if { $type == "USER" } {

            $w.frmEquations.ifbeh configure -state normal
            $w.frmEquations.ifbeb configure -state normal
            $w.frmEquations.ifbets configure -state normal
            $w.frmEquations.ifbetg configure -state normal
            $w.frmEquations.ifber configure -state normal
            $w.frmEquations.ifbehtot configure -state normal
            

             return
       }

       $w.frmEquations.ifbeh configure -state disabled
       $w.frmEquations.ifbeb configure -state disabled
       $w.frmEquations.ifbets configure -state disabled
       $w.frmEquations.ifbetg configure -state disabled
       $w.frmEquations.ifber configure -state disabled
       $w.frmEquations.ifbehtot configure -state normal

       #set wdir "c:\\Programme\\GiD\\Gid 8.0.9\\problemtypes\\SAFIR2007_test\\Safir_Thermal_2d.gid"
       set wdir $ProblemTypePath

       set f [open $wdir\\prof.txt ]

       set listProf { }
       while { [ gets $f line ] >= 0 } {
           scan $line "%s" kw0
           if { $kw0 == $type} {
                  set profNamifb [string range $line 0 20]
              $w.frmProfType.listOfProf insert end $line
           }
       }

       close $f
}

proc Drawifbprofile { w } {

    global Paramsifbprof

    set scal 0.001
    set htot [expr $Paramsifbprof(htot) * $scal]
    set b [expr $Paramsifbprof(b) * $scal]
    set ts [expr $Paramsifbprof(ts) * $scal]
    set tg [expr $Paramsifbprof(tg) * $scal]
    
    set slabW [expr $Paramsifbprof(slabW) * $scal]
    set slabH [expr $Paramsifbprof(slabH) * $scal]

    set exactS $Paramsifbprof(drawFillet)

    

    if { $exactS == 1 } {
            set r [expr $Paramsifbprof(r) * $scal]
    } else {
            set r [ expr $Paramsifbprof(r)*0.665*$scal ] 
    }

    set x0 0.0
    set y0 0.0
        
    set hh [expr $htot - $ts]
    set bh [expr $b*0.5]
    set tsh [expr $ts*0.5]
    set dc [expr sqrt([expr $r*$r*0.5])]

    set x1 [expr $x0 + $tsh]
    set y1 $y0

    set x2 $x1
    set y2 [expr $y1 + $hh - $r ]
    
    set x3 [expr $x2 + $r]
    set y3 [expr $y2 + $r]
    
    set c1x [expr $x3 - $dc]
    set c1y [expr $y2 + $dc]
    
    set x4 [expr $x0 + $bh]
    set y4 $y3
       
    set x5 $x4
    set y5 [expr $y0 + $htot]
    
    set x6 [expr $x0 - $x5]
    set y6 $y5
    
    set x7 [expr $x0 - $x4]
    set y7 $y4
    
    set x8 [expr $x0 - $x3]
    set y8 $y3
    
    set x9 [expr $x0 - $x2]
    set y9 $y2
    
    set c2x [expr $x0 - $c1x]
    set c2y [expr $c1y]
    
    set x10 [expr $x0 - $x1]
    set y10 $y1
    
    set x11 $x7
    set y11 $y0
    
    set x12 $x4
    set y12 $y0
    

	set tors1x [expr $x0]
    set tors1y [expr $y0 + $htot ]
	set tors2x [expr $x0]
    set tors2y [expr $y0 + $hh]
	
    set oldvalue [GiD_Info variables CreateAlwaysNewPoint]
    GiD_Process escape escape escape Utilities Variables CreateAlwaysNewPoint  1

    GiD_Process escape escape escape escape
    
    GiD_Process geometry create line \
    $x1,$y1,0.0 \
    $x2,$y2,0.0 \
    escape escape escape escape

    if { $exactS == 1 } {
            .central.s process geometry create arc \
           $x2,$y2,0.0 \
            $c1x,$c1y,0.0 \
            $x3,$y3,0.0 \
            escape escape escape escape
    } else {
       GiD_Process geometry create line \
            $x2,$y2,0.0 \
        $x3,$y3,0.0 \
            escape escape escape escape
    }

 GiD_Process geometry create line \
   $x3,$y3,0.0 \
    $x4,$y4,0.0 \
    $x5,$y5,0.0 \
	$tors1x,$tors1y,0.0 \
    $x6,$y6,0.0 \
    $x7,$y7,0.0 \
    $x8,$y8,0.0 \
   escape escape escape escape
   
   
   #---------torsion------------
	GiD_Process geometry create line \
	$x8,$y8,0.0 \
	$tors2x,$tors2y,0.0 \
	$x3,$y3,0.0 \
    escape escape escape escape
	
	GiD_Process geometry create line \
	$tors2x,$tors2y,0.0 \
	$tors1x,$tors1y,0.0 \
    escape escape escape escape
	  
	#--------/torsion------------

	#add torsion constraint
	GiD_Process Data Conditions AssignCond Point_Torsion_Constraint Change 1 13 \
	Mescape 
	
    if { $exactS == 1 } {
       GiD_Process geometry create arc \
        $x8,$y8,0.0 \
        $c2x,$c2y,0.0 \
        $x9,$y9,0.0 \
        escape escape escape escape
    } else {
       GiD_Process geometry create line \
        $x8,$y8,0.0 \
        $x9,$y9,0.0 \
        escape escape escape escape
    }

    GiD_Process geometry create line \
    $x9,$y9,0.0 \
    $x10,$y10,0.0 \
    $x1,$y1,0.0 \
    escape escape escape escape

   set sW [expr $Paramsifbprof(slabW) * $scal]
   set sH [expr $Paramsifbprof(slabH) * $scal] 

   set dsx [expr $sW*0.5 - $b*0.5 ]

   set sl1x [expr $x5 + $dsx ]
   set sl1y $y0

   set sl2x $sl1x
   set sl2y [expr $sl1y + $htot]

   set sl3x $sl2x
   set sl3y [expr $sl2y + $sH ]

   set sl4x [expr $sl3x - $sW]
   set sl4y $sl3y
   
   set sl5x $sl4x
   set sl5y $sl2y 
   
   set sl6x $sl5x
   set sl6y $sl1y
   
   set pW [expr $Paramsifbprof(plateW) * $scal]
   set pH [expr $Paramsifbprof(plateH) * $scal]
   set dpx [ expr $pW*0.5 - $tsh ]   
   
   set pl1x [expr $x1 + $dpx]
   set pl1y $y0 
   
   set pl2x $pl1x
   set pl2y [expr $pl1y - $pH]
   
   set pl3x [expr $pl2x - $pW]
   set pl3y $pl2y
   
   set pl4x $pl3x
   set pl4y [expr $pl3y + $pH]
   
   
   GiD_Process geometry create line \
     $x1,$y1,0.0 \
     $x12,$y12,0.0 \
     $pl1x,$pl1y,0.0 \
     $sl1x,$sl1y,0.0 \
     $sl2x,$sl2y,0.0 \
     $sl3x,$sl3y,0.0 \
     $sl4x,$sl4y,0.0 \
     $sl5x,$sl5y,0.0 \
     $sl6x,$sl6y,0.0 \
     $pl4x,$pl4y,0.0 \
     $x11,$y11,0.0 \
     $x10,$y10,0.0 \
     escape escape escape escape
   
    GiD_Process geometry create line \
   $pl4x,$pl4y,0.0 \
   $pl3x,$pl3y,0.0 \
   $pl2x,$pl2y,0.0 \
   $pl1x,$pl1y,0.0 \
   escape escape escape escape
   
   GiD_Process geometry create line \
           $x5,$y5,0.0 \
           $sl2x,$sl2y,0.0 \
           escape escape escape escape
           
   GiD_Process geometry create line \
           $x6,$y6,0.0 \
           $sl5x,$sl5y,0.0 \
           escape escape escape escape          
   
   GiD_Process geometry create line \
           $x12,$y12,0.0 \
           $x4,$y4,0.0 \
           escape escape escape escape
           
    GiD_Process geometry create line \
           $x11,$y11,0.0 \
           $x7,$y7,0.0 \
           escape escape escape escape
     
    GiD_Process escape
    GiD_Process escape escape escape Utilities Variables \
                 CreateAlwaysNewPoint $oldvalue
    GiD_Process escape escape escape
 
    GiD_Process Utilities Collapse Points 1:
    GiD_Process escape escape escape

    GiD_Process zoom frame escape escape escape escape

    if { $exactS == 1 } {

       GiD_Process Geometry Create NurbsSurface 5 29 19 20 21 30 6\
       escape escape escape escape
       
       GiD_Process Geometry Create NurbsSurface 14 33 10 9 34\
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 10 3 4 5 11\
       escape escape escape escape
       
	   GiD_Process Geometry Create NurbsSurface 8 9 11 6 7 \
       escape escape escape escape
	   
       GiD_Process Geometry Create NurbsSurface 14 15 16 28 27 26 24 25  \
       escape escape escape escape
       
       GiD_Process Geometry Create NurbsSurface 16 17 18 29 4 31 \
       escape escape escape escape
       
       GiD_Process Geometry Create NurbsSurface 15 31 3 33 \
       escape escape escape escape
       
       GiD_Process Geometry Create NurbsSurface 8 32 25 34 \
       escape escape escape escape
       
       GiD_Process Geometry Create NurbsSurface 23 24 32 7 30 22 \
       escape escape escape escape
       
   } else {

       GiD_Process Geometry Create NurbsSurface 5 29 19 20 21 30 6\
       escape escape escape escape
       
       GiD_Process Geometry Create NurbsSurface 14 1 2 10 9 12 13\
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 10 3 4 5 11\
       escape escape escape escape
       
	   GiD_Process Geometry Create NurbsSurface 8 9 11 6 7 \
       escape escape escape escape
	   
       GiD_Process Geometry Create NurbsSurface 14 15 16 28 27 26 24 25  \
       escape escape escape escape
       
       GiD_Process Geometry Create NurbsSurface 16 17 18 29 4 31 \
       escape escape escape escape
       
       GiD_Process Geometry Create NurbsSurface 15 31 3 2 1 \
       escape escape escape escape
       
       GiD_Process Geometry Create NurbsSurface 8 32 25 13 12 \
       escape escape escape escape
       
       GiD_Process Geometry Create NurbsSurface 23 24 32 7 30 22 \
       escape escape escape escape
      
       



    }

    destroy $w
}

proc Cfbprofile { } {

    global Paramscfbprof 

    global ProfNamcfb
    global ProfTyp
 
    set w .gid.cfbprofil

    set Paramscfbprof(h) ""
    set Paramscfbprof(b) ""
    set Paramscfbprof(ts) ""
    set Paramscfbprof(tg) "" 
    set Paramscfbprof(r) ""
    set Paramscfbprof(drawFillet) 1     
    set Paramscfbprof(slabW) ""
    set Paramscfbprof(slabH) ""    
    set Paramscfbprof(plateW) ""
    set Paramscfbprof(plateH) ""
        set Paramscfbprof(prefabH) ""
        set Paramscfbprof(Appui) ""    
    set Paramscfbprof(drawWedge) 0     
        set Paramscfbprof(Wedge) ""

    InitWindow $w "Create CoSFB - Profile" ParametricWindowGeom   
 
    frame $w.frmProfType 

    label $w.frmProfType.lType -text "Type"

    set ProfTyp "HE"

    ComboBox $w.frmProfType.listOfType -editable 0 -width 15 -textvariable ProfTyp \
      -values { "IPE" "HE" "HL" "HD" "HP" "W" "USER" } \
      -modifycmd { updateProfListcfb  $ProfTyp }

    label $w.frmProfType.lProf -text "Profile"
    label $w.frmProfType.eProf -relief sunken -width 20 -textvariable ProfNamcfb -font FixedFont
    listbox $w.frmProfType.listOfProf -width 20 -relief raised -borderwidth 2 -selectmode single \
          -yscrollcommand " $w.frmProfType.scrollProfList set " -font FixedFont

    scrollbar $w.frmProfType.scrollProfList -command "$w.frmProfType.listOfProf yview"

    frame $w.frmEquations
 
    label $w.frmEquations.cfblh -text "Height(h)"
    label $w.frmEquations.cfblhu -text "mm"
    entry $w.frmEquations.cfbeh -relief sunken -width 10 -textvariable Paramscfbprof(h)
    label $w.frmEquations.cfblb -text "Width(b)"
    label $w.frmEquations.cfblbu -text "mm"
    entry $w.frmEquations.cfbeb -relief sunken -width 10 -textvariable Paramscfbprof(b)
    label $w.frmEquations.cfblts -text "Web(tw)"
    label $w.frmEquations.cfbltsu -text "mm"
    entry $w.frmEquations.cfbets -relief sunken -width 10 -textvariable Paramscfbprof(ts)
    label $w.frmEquations.cfbltg -text "Flange(tf)"
    label $w.frmEquations.cfbltgu -text "mm"
    entry $w.frmEquations.cfbetg -relief sunken -width 10 -textvariable Paramscfbprof(tg)
    label $w.frmEquations.cfblr -text "Radius(r)"
    label $w.frmEquations.cfblru -text "mm"
    entry $w.frmEquations.cfber -relief sunken -width 10 -textvariable Paramscfbprof(r)
    label $w.frmEquations.cfblSlabWidth -text "Slab Width"
    label $w.frmEquations.cfblSlabWidthu -text "mm"
    entry $w.frmEquations.cfbeSlabWidth -relief sunken -width 10 -textvariable Paramscfbprof(slabW) 
    label $w.frmEquations.cfblSlabHight -text "Concrete height over the steel profile"
    label $w.frmEquations.cfblSlabHightu -text "mm"
    entry $w.frmEquations.cfbeSlabHight -relief sunken -width 10 -textvariable Paramscfbprof(slabH)
    label $w.frmEquations.cfbplateHr -text "Plate Thickness"
    label $w.frmEquations.cfbplateHru -text "mm"
    entry $w.frmEquations.cfbplateH -relief sunken -width 10 -textvariable Paramscfbprof(plateH)
    label $w.frmEquations.cfbplateWr -text "Plate Width"
    label $w.frmEquations.cfbplateWru -text "mm"
    entry $w.frmEquations.cfbplateW -relief sunken -width 10 -textvariable Paramscfbprof(plateW)
    label $w.frmEquations.cfblPrefabHight -text "Height of the prefab slab"
    label $w.frmEquations.cfblPrefabHightu -text "mm"
    entry $w.frmEquations.cfbePrefabHight -relief sunken -width 10 -textvariable Paramscfbprof(prefabH)
        label $w.frmEquations.cfblAppui -text "Support width on plate"
    label $w.frmEquations.cfblAppuitu -text "mm"
    entry $w.frmEquations.cfbeAppui -relief sunken -width 10 -textvariable Paramscfbprof(Appui)
        
        label $w.frmEquations.cfbdrawWedger -text "Wedge"
    checkbutton $w.frmEquations.cfbDrawWedge -variable Paramscfbprof(drawWedge)
        
        label $w.frmEquations.cfbWedger -text "Wedge height"
    label $w.frmEquations.cfbWedgeru -text "mm"
    entry $w.frmEquations.cfbWedge -relief sunken -width 10 -textvariable Paramscfbprof(Wedge)
        
        label $w.frmEquations.cfblexactShape -text "exact shape"
    checkbutton $w.frmEquations.cfbexactShape -variable Paramscfbprof(drawFillet)
        
    
        
    set def_back [$w cget -background]
    frame $w.frmButtonscfb -bg [CCColorActivo $def_back]
    button $w.frmButtonscfb.btnApply -text "Apply" \
            -command "Drawcfbprofile $w" \
            -underline 0 -width 6
    button $w.frmButtonscfb.btnclose -text "Close" \
            -command "destroy $w" \
            -underline 0 -width 6

    grid $w.frmProfType  -padx 5 -pady 5 -sticky ew 

    grid $w.frmProfType.lType $w.frmProfType.listOfType -sticky e
    grid $w.frmProfType.lProf $w.frmProfType.eProf -sticky e
    grid $w.frmProfType.scrollProfList $w.frmProfType.listOfProf -sticky ens
  
    grid $w.frmEquations -padx 5 -pady 5 -sticky ew    
    grid $w.frmEquations.cfblh $w.frmEquations.cfbeh $w.frmEquations.cfblhu -sticky e
    grid $w.frmEquations.cfblb $w.frmEquations.cfbeb $w.frmEquations.cfblbu -sticky e
    grid $w.frmEquations.cfblts $w.frmEquations.cfbets $w.frmEquations.cfbltsu -sticky e
    grid $w.frmEquations.cfbltg $w.frmEquations.cfbetg $w.frmEquations.cfbltgu -sticky e
    grid $w.frmEquations.cfblr $w.frmEquations.cfber $w.frmEquations.cfblru -sticky e
    grid $w.frmEquations.cfblexactShape $w.frmEquations.cfbexactShape -sticky e
    grid $w.frmEquations.cfblSlabWidth $w.frmEquations.cfbeSlabWidth $w.frmEquations.cfblSlabWidthu -sticky e
    grid $w.frmEquations.cfblSlabHight $w.frmEquations.cfbeSlabHight $w.frmEquations.cfblSlabHightu -sticky e
    grid $w.frmEquations.cfbplateWr $w.frmEquations.cfbplateW $w.frmEquations.cfbplateWru -sticky e 
    grid $w.frmEquations.cfbplateHr $w.frmEquations.cfbplateH $w.frmEquations.cfbplateHru -sticky e 
    grid $w.frmEquations.cfblPrefabHight $w.frmEquations.cfbePrefabHight $w.frmEquations.cfblPrefabHightu -sticky e 
    grid $w.frmEquations.cfblAppui $w.frmEquations.cfbeAppui $w.frmEquations.cfblAppuitu -sticky e 
        
    grid $w.frmEquations.cfbdrawWedger $w.frmEquations.cfbDrawWedge -sticky e
        
    grid $w.frmEquations.cfbWedger $w.frmEquations.cfbWedge $w.frmEquations.cfbWedgeru -sticky e 
   
    grid $w.frmButtonscfb -sticky ews -columnspan 7
    grid $w.frmButtonscfb.btnApply $w.frmButtonscfb.btnclose -padx 5 -pady 6

    grid columnconf $w "0" -weight 1
    grid rowconfigure $w "3" -weight 1
    
    focus $w.frmButtonscfb.btnApply
    
    bind $w <Alt-c> "tkButtonInvoke $w.frmButtonscfb.btnclose"
    bind $w <Escape> "tkButtonInvoke $w.frmButtonscfb.btnclose"

    bind $w.frmProfType.listOfProf <<ListboxSelect>> { updateProfcfb [selection get] }

    set ProfNamcfb  ""
    set Paramscfbprof(slabW) ""
    set Paramscfbprof(slabH) ""
    set Paramscfbprof(plateW) ""
    set Paramscfbprof(plateH) ""
    set Paramscfbprof(prefabH) ""
        set Paramscfbprof(Appui) ""
        set Paramscfbprof(Wedge) ""
    updateProfListcfb  "HE"

    #wm minsize $w 140 175
}

proc updateProfcfb { selectedProf } {

   global ProfNamcfb
   global Paramscfbprof 

   set w .gid.cfbprofil

   set ProfNamsfb [string range $selectedProf 0 20]

   set profData [string range $selectedProf 21 end]
   scan $profData "%s %s %s %s %s" w1 w2 w3 w4 w5

   set Paramscfbprof(h) $w1
   set Paramscfbprof(b) $w2
   set Paramscfbprof(ts) $w3
   set Paramscfbprof(tg) $w4
   set Paramscfbprof(r) $w5

}

proc updateProfListcfb  { type } {

       variable path
       global ProblemTypePath

       global ProfNamcfb
       global ProfTyp
       global Paramscfbprof 

       set w .gid.cfbprofil

       $w.frmProfType.listOfProf delete 0 end

       set ProfNamcfb  ""
       set Paramscfbprof(h) ""
       set Paramscfbprof(b) ""
       set Paramscfbprof(ts) ""
       set Paramscfbprof(tg) "" 
       set Paramscfbprof(r) ""

       if { $type == "USER" } {

            $w.frmEquations.cfbeh configure -state normal
            $w.frmEquations.cfbeb configure -state normal
            $w.frmEquations.cfbets configure -state normal
            $w.frmEquations.cfbetg configure -state normal
            $w.frmEquations.cfber configure -state normal
            

             return
       }

       $w.frmEquations.cfbeh configure -state disabled
       $w.frmEquations.cfbeb configure -state disabled
       $w.frmEquations.cfbets configure -state disabled
       $w.frmEquations.cfbetg configure -state disabled
       $w.frmEquations.cfber configure -state disabled

       #set wdir "c:\\Programme\\GiD\\Gid 8.0.9\\problemtypes\\SAFIR2007_test\\Safir_Thermal_2d.gid"
       set wdir $ProblemTypePath

       set f [open $wdir\\prof.txt ]

       set listProf { }
       while { [ gets $f line ] >= 0 } {
           scan $line "%s" kw0
           if { $kw0 == $type} {
                  set profNamsfb [string range $line 0 20]
              $w.frmProfType.listOfProf insert end $line
           }
       }

       close $f
}

proc Drawcfbprofile { w } {

    global Paramscfbprof

    set scal 0.001
    set h [expr $Paramscfbprof(h) * $scal]
    set b [expr $Paramscfbprof(b) * $scal]
    set ts [expr $Paramscfbprof(ts) * $scal]
    set tg [expr $Paramscfbprof(tg) * $scal]
    
    set exactS $Paramscfbprof(drawFillet)
    if { $exactS == 1 } {
            set r [expr $Paramscfbprof(r) * $scal]
    } else {
            set r [ expr $Paramscfbprof(r)*0.665*$scal ]
    }
    
    set x0 0.0
    set y0 0.0
        
    set hh [expr $h*0.5]
    set bh [expr $b*0.5]
    set tsh [expr $ts*0.5]
    set dc [expr sqrt([expr $r*$r*0.5])]

    set x1 [expr $x0 - $bh]
    set y1 [expr $y0 - $hh]

    set x2 [expr $x0 + $bh]
    set y2 [expr $y0 - $hh]

    set x3 [expr $x2]
    set y3 [expr $y2 + $tg]

    set x4 [expr $x0 + $tsh + $r]
    set y4 [expr $y3]

    set x5 [expr $x0 + $tsh]
    set y5 [expr $y4 + $r]

    set c1x [expr $x4 - $dc]
    set c1y [expr $y5 - $dc]

    set x6 [expr $x5]
    set y6 [expr $y0 + $hh - $tg - $r]

    set x7 [expr $x5 + $r]
    set y7 [expr $y6 + $r]

    set c2x [expr $x7 - $dc]
    set c2y [expr $y6 + $dc]

    set x8 [expr $x0 + $bh]
    set y8 [expr $y0 + $hh - $tg]

    set x9 [expr $x8]
    set y9 [expr $y0 + $hh]

    set x10 [expr $x0 - $x9]
    set y10 [expr $y9]

    set x11 [expr $x0 - $x8]
    set y11 [expr $y8]

    set x12 [expr $x0 - $x7]
    set y12 [expr $y7]

    set x13 [expr $x0 - $x6]
    set y13 [expr $y6]
 
    set c3x [expr $x0 - $c2x]
    set c3y [expr $c2y]

    set x14 [expr $x0 - $x5]
    set y14 [expr $y5]

    set x15 [expr $x0 - $x4]
    set y15 [expr $y4]

    set c4x [expr $x0 - $c1x]
    set c4y [expr $c1y]

    set x16 [expr $x0 - $x3]
    set y16 [expr $y3]
       
	#----------tors---------
	
	set tors1x [expr $x0]
    set tors1y [expr $y0 - $hh]
	set tors2x [expr $x0]
    set tors2y [expr $y0 - $hh + $tg ]
	set tors3x [expr $x0]
    set tors3y [expr $y0 + $hh - $tg ]
	set tors4x [expr $x0]
    set tors4y [expr $y0 + $hh]
	
	#---------/tors---------

    set oldvalue [GiD_Info variables CreateAlwaysNewPoint]
    GiD_Process escape escape escape Utilities Variables CreateAlwaysNewPoint  1

    GiD_Process escape escape escape escape
    GiD_Process geometry create line \
    $x1,$y1,0.0 \
	$tors1x,$tors1y,0.0 \
    $x2,$y2,0.0 \
    $x3,$y3,0.0 \
    $x4,$y4,0.0 \
    escape escape escape escape

    if { $exactS == 1 } {
            .central.s process geometry create arc \
            $x4,$y4,0.0 \
            $c1x,$c1y,0.0 \
            $x5,$y5,0.0 \
            escape escape escape escape
    } else {
       GiD_Process geometry create line \
        $x4,$y4,0.0 \
        $x5,$y5,0.0 \
        escape escape escape escape
    }

   GiD_Process geometry create line \
    $x5,$y5,0.0 \
    $x6,$y6,0.0 \
    escape escape escape escape

    if { $exactS == 1 } {
       GiD_Process geometry create arc \
        $x6,$y6,0.0 \
        $c2x,$c2y,0.0 \
        $x7,$y7,0.0 \
        escape escape escape escape
    } else {
       GiD_Process geometry create line \
        $x6,$y6,0.0 \
        $x7,$y7,0.0 \
        escape escape escape escape
    }

    GiD_Process geometry create line \
    $x7,$y7,0.0 \
    $x8,$y8,0.0 \
    $x9,$y9,0.0 \
	$tors4x,$tors4y,0.0 \
    $x10,$y10,0.0 \
    $x11,$y11,0.0 \
    $x12,$y12,0.0 \
    escape escape escape escape

    if { $exactS == 1 } {
        GiD_Process geometry create arc \
         $x12,$y12,0.0 \
         $c3x,$c3y,0.0 \
         $x13,$y13,0.0 \
         escape escape escape escape
    } else {
       GiD_Process geometry create line \
        $x12,$y12,0.0 \
        $x13,$y13,0.0 \
        escape escape escape escape
    }

   GiD_Process geometry create line \
    $x13,$y13,0.0 \
    $x14,$y14,0.0 \
    escape escape escape escape
    
	
   if { $exactS == 1 } {
        GiD_Process geometry create arc \
        $x14,$y14,0.0 \
        $c4x,$c4y,0.0 \
        $x15,$y15,0.0 \
        escape escape escape escape
    } else {
       GiD_Process geometry create line \
        $x14,$y14,0.0 \
        $x15,$y15,0.0 \
        escape escape escape escape
    }

   GiD_Process geometry create line \
    $x15,$y15,0.0 \
    $x16,$y16,0.0 \
    $x1,$y1,0.0 \
    escape escape escape escape
	
	   #---------torsion------------
	GiD_Process geometry create line \
	$x15,$y15,0.0 \
	$tors2x,$tors2y,0.0 \
	$x4,$y4,0.0 \
    escape escape escape escape
	
	GiD_Process geometry create line \
	$tors2x,$tors2y,0.0 \
	$tors1x,$tors1y,0.0 \
    escape escape escape escape
	   
	GiD_Process geometry create line \
	$x12,$y12,0.0 \
	$tors3x,$tors3y,0.0 \
	$x7,$y7,0.0 \
    escape escape escape escape
	
	GiD_Process geometry create line \
	$tors3x,$tors3y,0.0 \
	$tors4x,$tors4y,0.0 \
    escape escape escape escape
	
	#GiD_Process Mescape Geometry Delete Lines 19
	#GiD_Process escape escape escape
	
	#GiD_Process Mescape Utilities Renumber
	#GiD_Process escape escape escape
	
	#GiD_Process Mescape Geometry Delete Points 18
	#GiD_Process escape escape escape
	 #--------/torsion------------
	
	#add torsion constraint
	GiD_Process Data Conditions AssignCond Point_Torsion_Constraint Change 1 34 \
	Mescape 
        
   set sW [expr $Paramscfbprof(slabW) * $scal]
   set sH [expr $Paramscfbprof(slabH) * $scal] 
   set prH [expr $Paramscfbprof(prefabH) * $scal]
   set Appui [ expr $Paramscfbprof(Appui) * $scal]
   set pW [expr $Paramscfbprof(plateW) * $scal]
   set pH [expr $Paramscfbprof(plateH) * $scal]
   
   set dpx [ expr $pW*0.5 - $b*0.5 ]
   set dsx [ expr $sW*0.5 - $b*0.5 ]
   set cale $Paramscfbprof(drawWedge)
        if { $cale == 1 } {
            set Wedge [expr $Paramscfbprof(Wedge) * $scal]
    } else {
                set Wedge 0.0
    }
         
 # ***************  perimeter of the concrete slab  points 17 to 26 *******************************
 # **************** points 17 b and 26 bwill only be used if Wedge is activated *******************  
   set x17 [ expr $x2 + $dpx ]
   set y17 $y2   
   
   set x17b $x17
   set y17b [ expr $y2 + $Wedge ]
   
   set x18 [ expr $x2 + $dpx - $Appui]
   set y18 $y17b
   
   set x19 $x18
   set y19 [ expr $y2 + $Wedge + $prH ]
   
   set x20 [ expr $x9 + $dsx ]
   set y20 $y19

   set x21 $x20
   set y21 [ expr $y9 + $sH ]

   set x22 [ expr $x10 - $dsx ]
   set y22 $y21

   set x23 $x22
   set y23 $y19
   
   set x24 [ expr $x1 - $dpx + $Appui ]
   set y24 $y19
    
   set x25 $x24
   set y25 [ expr $y1 + $Wedge ]
   
   set x26b [ expr $x1 - $dpx ]
   set y26b $y25  
   
   set x26 [ expr $x1 - $dpx ]
   set y26 $y1
   
if { $cale == 1 } {
            GiD_Process geometry create line \
     $x2,$y2,0.0 \
         $x17,$y17,0.0 \
         $x17b,$y17b,0.0 \
         $x18,$y18,0.0 \
         escape escape escape escape
         GiD_Process geometry create line \
         $x18,$y18,0.0 \
         $x19,$y19,0.0 \
     $x20,$y20,0.0 \
     $x21,$y21,0.0 \
         escape escape escape escape
         GiD_Process geometry create line \
         $x21,$y21,0.0 \
     $x22,$y22,0.0 \
     $x23,$y23,0.0 \
     $x24,$y24,0.0 \
         escape escape escape escape
         GiD_Process geometry create line \
         $x24,$y24,0.0 \
     $x25,$y25,0.0 \
         $x26b,$y26b,0.0 \
         $x26,$y26,0.0 \
         $x1,$y1,0.0 \
         escape escape escape escape
    } else {
    GiD_Process geometry create line \
     $x2,$y2,0.0 \
         $x18,$y18,0.0 \
         $x19,$y19,0.0 \
     $x20,$y20,0.0 \
         escape escape escape escape
         GiD_Process geometry create line \
         $x20,$y20,0.0 \
     $x21,$y21,0.0 \
     $x22,$y22,0.0 \
     $x23,$y23,0.0 \
         escape escape escape escape
         GiD_Process geometry create line \
         $x23,$y23,0.0 \
     $x24,$y24,0.0 \
     $x25,$y25,0.0 \
         $x1,$y1,0.0 \
         escape escape escape escape
    }

# ********* perimeter of the prefabricated element -> points 20b and 23b to be added ***********  
 
   set x23b $x23
   set y23b $y25
   
   set x20b $x20
   set y20b $y17b
   
 # ******* perimeter of the bottom plate -> points 27 and 28 to be added ******************
   
   set x27 [expr $x1 - $dpx]
   set y27 [expr $y1 - $pH]
   
   set x28 [expr $x2 + $dpx]
   set y28 [expr $y2 - $pH]
   
   if { $cale == 1 } {
            GiD_Process geometry create line \
            $x17b,$y17b,0.0 \
         $x20b,$y20b,0.0 \
         $x20,$y20,0.0 \
         escape escape escape escape
         GiD_Process geometry create line \
         $x23,$y23,0.0 \
         $x23b,$y23b,0.0 \
     $x26b,$y26b,0.0 \
         escape escape escape escape
    } else {
    GiD_Process geometry create line \
     $x18,$y18,0.0 \
         $x17,$y17,0.0 \
         $x20b,$y20b,0.0 \
     $x20,$y20,0.0 \
         escape escape escape escape
         GiD_Process geometry create line \
         $x23,$y23,0.0 \
     $x23b,$y23b,0.0 \
     $x26,$y26,0.0 \
     $x25,$y25,0.0 \
         escape escape escape escape
    }
        GiD_Process geometry create line \
         $x26,$y26,0.0 \
     $x27,$y27,0.0 \
         $x28,$y28,0.0 \
     $x17,$y17,0.0 \
         escape escape escape escape
     
    GiD_Process escape
    GiD_Process escape escape escape Utilities Variables \
                 CreateAlwaysNewPoint $oldvalue
    GiD_Process escape escape escape
 
    GiD_Process Utilities Collapse Points 1:
    GiD_Process escape escape escape

    GiD_Process zoom frame escape escape escape escape

      if { $cale == 1 } {

	   if { $exactS == 0 } {
		
		GiD_Process Geometry Create NurbsSurface 2 3 4 20 21\
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 1 21 19 17 18 \
       escape escape escape escape

	   GiD_Process Geometry Create NurbsSurface 19 20 5 6 7 23 22 14 15 16 \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 23 8 9 10 24  \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 13 22 24 11 12 \
       escape escape escape escape
           
       GiD_Process Geometry Create NurbsSurface 3 25 26 27 28 29 30 31 32 33 34 35 36 37 18 17 16 15 14 13 12 11 10 9 8 7 6 5 4 \
       escape escape escape escape
			  
       GiD_Process Geometry Create NurbsSurface 1 2 25 44 43 42 37\
       escape escape escape escape
       
       GiD_Process Geometry Create NurbsSurface 27 38 39 29 28 \
       escape escape escape escape
             
       GiD_Process Geometry Create NurbsSurface 41 35 34 33 40 \
       escape escape escape escape
		
		} else {
			GiD_Process Geometry Create NurbsSurface 2 3 4 20 21\
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 1 21 19 17 18 \
       escape escape escape escape

	   GiD_Process Geometry Create NurbsSurface 19 20 46 23 22 48 \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 23 8 9 10 24  \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 13 22 24 11 12 \
       escape escape escape escape
           
       GiD_Process Geometry Create NurbsSurface 3 25 26 27 28 29 30 31 32 33 34 35 36 37 18 17 48 13 12 11 10 9 8 46 4 \
       escape escape escape escape
			  
       GiD_Process Geometry Create NurbsSurface 1 2 25 44 43 42 37\
       escape escape escape escape
       
       GiD_Process Geometry Create NurbsSurface 27 38 39 29 28 \
       escape escape escape escape
             
       GiD_Process Geometry Create NurbsSurface 41 35 34 33 40 \
       escape escape escape escape
		
		}
     
       } else {
           
		   
		   if { $exactS == 0 } {
		   
       GiD_Process Geometry Create NurbsSurface 2 3 4 20 21\
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 1 21 19 17 18 \
       escape escape escape escape

	   GiD_Process Geometry Create NurbsSurface 19 20 5 6 7 23 22 14 15 16 \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 23 8 9 10 24  \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 13 22 24 11 12 \
       escape escape escape escape
           
       GiD_Process Geometry Create NurbsSurface 3 25 26 27 28 29 30 31 32 33 18 17 16 15 14 13 12 11 10 9 8 7 6 5 4 \
       escape escape escape escape
			  
       GiD_Process Geometry Create NurbsSurface 1 2 25 34 42 41 40 39 33\
       escape escape escape escape
       
       GiD_Process Geometry Create NurbsSurface 34 35 36 27 26 \
       escape escape escape escape
             
       GiD_Process Geometry Create NurbsSurface 38 39 32 31 37 \
       escape escape escape escape
        
       #GiD_Process Mescape Data Conditions AssignCond Frontier_constraints Change FISO - 33 32 34 27 30 escape escape escape escape escape escape escape
       #GiD_Process Mescape Data Conditions AssignCond Frontier_constraints Change F20 - 20 escape escape escape escape escape escape escape
            
			} else {
		
	   GiD_Process Geometry Create NurbsSurface 2 3 4 20 21\
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 1 21 19 17 18 \
       escape escape escape escape

	   GiD_Process Geometry Create NurbsSurface 19 20 44 23 22 46 \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 23 8 9 10 24  \
       escape escape escape escape
	   
	   GiD_Process Geometry Create NurbsSurface 13 22 24 11 12 \
       escape escape escape escape
           
       GiD_Process Geometry Create NurbsSurface 3 25 26 27 28 29 30 31 32 33 18 17 46 13 12 11 10 9 8 44 4 \
       escape escape escape escape
			  
       GiD_Process Geometry Create NurbsSurface 1 2 25 34 42 41 40 39 33\
       escape escape escape escape
       
       GiD_Process Geometry Create NurbsSurface 34 35 36 27 26 \
       escape escape escape escape
             
       GiD_Process Geometry Create NurbsSurface 38 39 32 31 37 \
       escape escape escape escape
			}
			
         }
  
           #GiD_Process escape escape escape escape data mat assign Profile Surfaces 1 escape escape escape escape escape escape escape escape escape escape escape escape
           #GiD_Process escape escape escape escape data mat assign Dalle Surfaces 2 escape escape escape escape escape escape escape escape escape escape escape escape
           #GiD_Process escape escape escape escape data mat assign Plat Surfaces 3 escape escape escape escape escape escape escape escape escape escape escape escape
           #GiD_Process escape escape escape escape data mat assign Prdalle Surfaces 4 escape escape escape escape escape escape escape escape escape escape escape escape
           #GiD_Process escape escape escape escape data mat assign Prdalle Surfaces 5 escape escape escape escape escape escape escape escape escape escape escape escape
    
	
	GiD_Process Utilities Collapse Lines 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46:
    GiD_Process escape escape escape
	   
   destroy $w
}


proc GetDirName {} {
set txt [ .central.s info Project ]
return [ file tail [ lindex $txt 1] ]

}

proc WriteMaterialData {matNam Num} {
#
# gibt den Wert des Num-ten Materialparameters zurck 
# Num entspricht der MaterialProperty Nummer, wie im .mat file
#
        set matWerte [ GiD_Info materials $matNam ]
        set i [expr $Num * 2]
        set wert [lindex $matWerte $i]
        return $wert
}